searchNodes=[{"doc":"A set of geometry types for WKT/WKB and GeoJson.","ref":"Geometry.html","title":"Geometry","type":"module"},{"doc":"Returns true if a geometry is empty. Examples iex&gt; Geometry . empty? ( Point . new ( 1 , 2 ) ) false iex&gt; Geometry . empty? ( Point . new ( ) ) true iex&gt; Geometry . empty? ( LineString . new ( [ ] ) ) true","ref":"Geometry.html#empty?/1","title":"Geometry.empty?/1","type":"function"},{"doc":"Returns an :ok tuple with the geometry from the given GeoJSON term. Otherwise returns an :error tuple. The :type option specifies which type is expected. The possible values are :z , :m , and :zm . Examples iex&gt; ~s({&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1, 2]}) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; Geometry . from_geo_json ( ) { :ok , % Point { coordinate : [ 1 , 2 ] } } iex&gt; ~s({&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1, 2, 3, 4]}) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; Geometry . from_geo_json ( type : :zm ) { :ok , % PointZM { coordinate : [ 1 , 2 , 3 , 4 ] } }","ref":"Geometry.html#from_geo_json/2","title":"Geometry.from_geo_json/2","type":"function"},{"doc":"The same as from_geo_josn/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.html#from_geo_json!/2","title":"Geometry.from_geo_json!/2","type":"function"},{"doc":"Returns an :ok tuple with the geometry from the given WKT string. Otherwise returns an :error tuple. If WKB contains an SRID the tuple is extended by the id. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . Examples iex&gt; Geometry . from_wkb ( &quot;0101000080000000000000F03F00000000000000400000000000000840&quot; , :hex ) { :ok , % PointZ { coordinate : [ 1.0 , 2.0 , 3.0 ] } } iex&gt; Geometry . from_wkb ( &quot;0020000001000012673FF00000000000004000000000000000&quot; , :hex ) { :ok , { % Point { coordinate : [ 1.0 , 2.0 ] } , 4711 } }","ref":"Geometry.html#from_wkb/2","title":"Geometry.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.html#from_wkb!/2","title":"Geometry.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the geometry from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; Geometry . from_wkt ( &quot;Point ZM (1 2 3 4)&quot; ) { :ok , % PointZM { coordinate : [ 1 , 2 , 3 , 4 ] } } iex&gt; Geometry . from_wkt ( &quot;SRID=42;Point (1.1 2.2)&quot; ) { :ok , { % Point { coordinate : [ 1.1 , 2.2 ] } , 42 } }","ref":"Geometry.html#from_wkt/1","title":"Geometry.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.html#from_wkt!/1","title":"Geometry.from_wkt!/1","type":"function"},{"doc":"Returns the GeoJSON term representation of a geometry. Examples iex&gt; Geometry . to_geo_json ( PointZ . new ( 1.2 , 3.4 , 5.6 ) ) %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1.2 , 3.4 , 5.6 ] } iex&gt; Geometry . to_geo_json ( LineString . new ( [ Point . new ( 1 , 2 ) , Point . new ( 3 , 4 ) ] ) ) %{ &quot;type&quot; =&gt; &quot;LineString&quot; , &quot;coordinates&quot; =&gt; [ [ 1 , 2 ] , [ 3 , 4 ] ] }","ref":"Geometry.html#to_geo_json/1","title":"Geometry.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation of a geometry. With option :srid an EWKB representation with the SRID is returned. The option :endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . Examples iex&gt; Geometry . to_wkb ( PointZ . new ( 1 , 2 , 3 ) , endian : :ndr , mode : :hex ) &quot;0101000080000000000000F03F00000000000000400000000000000840&quot; iex&gt; Geometry . to_wkb ( Point . new ( 1 , 2 ) , srid : 4711 ) |&gt; Hex . from_binary ( ) &quot;0020000001000012673FF00000000000004000000000000000&quot;","ref":"Geometry.html#to_wkb/2","title":"Geometry.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation of a geometry. An optional :srid can be set in the options. Examples iex&gt; Geometry . to_wkt ( Point . new ( 1 , 2 ) ) &quot;Point (1 2)&quot; iex&gt; Geometry . to_wkt ( PointZ . new ( 1.1 , 2.2 , 3.3 ) , srid : 4211 ) &quot;SRID=4211;Point Z (1.1 2.2 3.3)&quot; iex&gt; Geometry . to_wkt ( LineString . new ( [ Point . new ( 1 , 2 ) , Point . new ( 3 , 4 ) ] ) ) &quot;LineString (1 2, 3 4)&quot;","ref":"Geometry.html#to_wkt/2","title":"Geometry.to_wkt/2","type":"function"},{"doc":"An n-dimensional coordinate.","ref":"Geometry.html#t:coordinate/0","title":"Geometry.coordinate/0","type":"type"},{"doc":"A list of n-dimensional coordinates.","ref":"Geometry.html#t:coordinates/0","title":"Geometry.coordinates/0","type":"type"},{"doc":"Byte order. :ndr : Little endian byte order encoding :xdr : Big endian byte order encoding","ref":"Geometry.html#t:endian/0","title":"Geometry.endian/0","type":"type"},{"doc":"Errors that can occur when a geometry is generating from GeoJson.","ref":"Geometry.html#t:geo_json_error/0","title":"Geometry.geo_json_error/0","type":"type"},{"doc":"A GeoJson term.","ref":"Geometry.html#t:geo_json_term/0","title":"Geometry.geo_json_term/0","type":"type"},{"doc":"","ref":"Geometry.html#t:mode/0","title":"Geometry.mode/0","type":"type"},{"doc":"The Spatial Reference System Identifier to identify projected, unprojected, and local spatial coordinate system definitions.","ref":"Geometry.html#t:srid/0","title":"Geometry.srid/0","type":"type"},{"doc":"A geometry is one of the provided geometries or geometry-collections.","ref":"Geometry.html#t:t/0","title":"Geometry.t/0","type":"type"},{"doc":"Well-known binary The binary representation of WKT.","ref":"Geometry.html#t:wkb/0","title":"Geometry.wkb/0","type":"type"},{"doc":"Errors that can occur when a geometry is generating from WKT.","ref":"Geometry.html#t:wkb_error/0","title":"Geometry.wkb_error/0","type":"type"},{"doc":"Well-known text (WKT) is a text markup language for representing vector geometry objects.","ref":"Geometry.html#t:wkt/0","title":"Geometry.wkt/0","type":"type"},{"doc":"Errors that can occur when a geometry is generating from WKT.","ref":"Geometry.html#t:wkt_error/0","title":"Geometry.wkt_error/0","type":"type"},{"doc":"A line-string struct, representing a 2D line. A none empty line-string requires at least two points.","ref":"Geometry.LineString.html","title":"Geometry.LineString","type":"module"},{"doc":"Returns true if the given LineString is empty. Examples iex&gt; LineString . empty? ( LineString . new ( ) ) true iex&gt; LineString . empty? ( ...&gt; LineString . new ( ...&gt; [ Point . new ( 1 , 2 ) , Point . new ( 3 , 4 ) ] ...&gt; ) ...&gt; ) false","ref":"Geometry.LineString.html#empty?/1","title":"Geometry.LineString.empty?/1","type":"function"},{"doc":"Creates a LineString from the given coordinates. Examples iex&gt; LineString . from_coordinates ( ...&gt; [ [ - 1 , 1 ] , [ - 2 , 2 ] , [ - 3 , 3 ] ] ...&gt; ) % LineString { points : [ [ - 1 , 1 ] , [ - 2 , 2 ] , [ - 3 , 3 ] ] }","ref":"Geometry.LineString.html#from_coordinates/1","title":"Geometry.LineString.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the LineString from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;LineString&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [1.1, 1.2], ...&gt; [20.1, 20.2] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; LineString . from_geo_json ( ) { :ok , % LineString { points : [ [ 1.1 , 1.2 ] , [ 20.1 , 20.2 ] ] } }","ref":"Geometry.LineString.html#from_geo_json/1","title":"Geometry.LineString.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineString.html#from_geo_json!/1","title":"Geometry.LineString.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the LineString from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.Point.from_wkb/2 function.","ref":"Geometry.LineString.html#from_wkb/2","title":"Geometry.LineString.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineString.html#from_wkb!/2","title":"Geometry.LineString.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the LineString from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; LineString . from_wkt ( ...&gt; &quot;LineString (-5.1 7.8, 0.1 0.2)&quot; ...&gt; ) { :ok , % LineString { points : [ [ - 5.1 , 7.8 ] , [ 0.1 , 0.2 ] ] } } iex&gt; LineString . from_wkt ( ...&gt; &quot;SRID=7219;LineString (-5.1 7.8, 0.1 0.2)&quot; ...&gt; ) { :ok , { % LineString { points : [ [ - 5.1 , 7.8 ] , [ 0.1 , 0.2 ] ] } , 7219 } } iex&gt; LineString . from_wkt ( &quot;LineString EMPTY&quot; ) { :ok , % LineString { } }","ref":"Geometry.LineString.html#from_wkt/1","title":"Geometry.LineString.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineString.html#from_wkt!/1","title":"Geometry.LineString.from_wkt!/1","type":"function"},{"doc":"Creates an empty LineString . Examples iex&gt; LineString . new ( ) % LineString { points : [ ] }","ref":"Geometry.LineString.html#new/0","title":"Geometry.LineString.new/0","type":"function"},{"doc":"Creates a LineString from the given Geometry.Point s. Examples iex&gt; LineString . new ( [ Point . new ( 1 , 2 ) , Point . new ( 3 , 4 ) ] ) % LineString { points : [ [ 1 , 2 ] , [ 3 , 4 ] ] }","ref":"Geometry.LineString.html#new/1","title":"Geometry.LineString.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a LineString . Examples iex&gt; LineString . to_geo_json ( ...&gt; LineString . new ( [ ...&gt; Point . new ( - 1.1 , - 2.2 ) , ...&gt; Point . new ( 1.1 , 2.2 ) ...&gt; ] ) ...&gt; ) %{ &quot;type&quot; =&gt; &quot;LineString&quot; , &quot;coordinates&quot; =&gt; [ [ - 1.1 , - 2.2 ] , [ 1.1 , 2.2 ] ] }","ref":"Geometry.LineString.html#to_geo_json/1","title":"Geometry.LineString.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a LineString . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.Point.to_wkb/1 function.","ref":"Geometry.LineString.html#to_wkb/2","title":"Geometry.LineString.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a LineString . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; LineString . to_wkt ( LineString . new ( ) ) &quot;LineString EMPTY&quot; iex&gt; LineString . to_wkt ( ...&gt; LineString . new ( [ ...&gt; Point . new ( 7.1 , 8.1 ) , ...&gt; Point . new ( 9.2 , 5.2 ) ...&gt; ] ) ...&gt; ) &quot;LineString (7.1 8.1, 9.2 5.2)&quot; iex&gt; LineString . to_wkt ( ...&gt; LineString . new ( [ ...&gt; Point . new ( 7.1 , 8.1 ) , ...&gt; Point . new ( 9.2 , 5.2 ) ...&gt; ] ) , ...&gt; srid : 123 ...&gt; ) &quot;SRID=123;LineString (7.1 8.1, 9.2 5.2)&quot;","ref":"Geometry.LineString.html#to_wkt/2","title":"Geometry.LineString.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.LineString.html#t:t/0","title":"Geometry.LineString.t/0","type":"type"},{"doc":"A line-string struct, representing a 2D line with a measurement. A none empty line-string requires at least two points.","ref":"Geometry.LineStringM.html","title":"Geometry.LineStringM","type":"module"},{"doc":"Returns true if the given LineStringM is empty. Examples iex&gt; LineStringM . empty? ( LineStringM . new ( ) ) true iex&gt; LineStringM . empty? ( ...&gt; LineStringM . new ( ...&gt; [ PointM . new ( 1 , 2 , 4 ) , PointM . new ( 3 , 4 , 6 ) ] ...&gt; ) ...&gt; ) false","ref":"Geometry.LineStringM.html#empty?/1","title":"Geometry.LineStringM.empty?/1","type":"function"},{"doc":"Creates a LineStringM from the given coordinates. Examples iex&gt; LineStringM . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ...&gt; ) % LineStringM { points : [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] }","ref":"Geometry.LineStringM.html#from_coordinates/1","title":"Geometry.LineStringM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the LineStringM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;LineString&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [1.1, 1.2, 1.4], ...&gt; [20.1, 20.2, 20.4] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; LineStringM . from_geo_json ( ) { :ok , % LineStringM { points : [ [ 1.1 , 1.2 , 1.4 ] , [ 20.1 , 20.2 , 20.4 ] ] } }","ref":"Geometry.LineStringM.html#from_geo_json/1","title":"Geometry.LineStringM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringM.html#from_geo_json!/1","title":"Geometry.LineStringM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the LineStringM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointM.from_wkb/2 function.","ref":"Geometry.LineStringM.html#from_wkb/2","title":"Geometry.LineStringM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringM.html#from_wkb!/2","title":"Geometry.LineStringM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the LineStringM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; LineStringM . from_wkt ( ...&gt; &quot;LineString M (-5.1 7.8 1, 0.1 0.2 2)&quot; ...&gt; ) { :ok , % LineStringM { points : [ [ - 5.1 , 7.8 , 1 ] , [ 0.1 , 0.2 , 2 ] ] } } iex&gt; LineStringM . from_wkt ( ...&gt; &quot;SRID=7219;LineString M (-5.1 7.8 1, 0.1 0.2 2)&quot; ...&gt; ) { :ok , { % LineStringM { points : [ [ - 5.1 , 7.8 , 1 ] , [ 0.1 , 0.2 , 2 ] ] } , 7219 } } iex&gt; LineStringM . from_wkt ( &quot;LineString M EMPTY&quot; ) { :ok , % LineStringM { } }","ref":"Geometry.LineStringM.html#from_wkt/1","title":"Geometry.LineStringM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringM.html#from_wkt!/1","title":"Geometry.LineStringM.from_wkt!/1","type":"function"},{"doc":"Creates an empty LineStringM . Examples iex&gt; LineStringM . new ( ) % LineStringM { points : [ ] }","ref":"Geometry.LineStringM.html#new/0","title":"Geometry.LineStringM.new/0","type":"function"},{"doc":"Creates a LineStringM from the given Geometry.PointM s. Examples iex&gt; LineStringM . new ( [ PointM . new ( 1 , 2 , 4 ) , PointM . new ( 3 , 4 , 6 ) ] ) % LineStringM { points : [ [ 1 , 2 , 4 ] , [ 3 , 4 , 6 ] ] }","ref":"Geometry.LineStringM.html#new/1","title":"Geometry.LineStringM.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a LineStringM . Examples iex&gt; LineStringM . to_geo_json ( ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( - 1.1 , - 2.2 , - 4.4 ) , ...&gt; PointM . new ( 1.1 , 2.2 , 4.4 ) ...&gt; ] ) ...&gt; ) %{ &quot;type&quot; =&gt; &quot;LineString&quot; , &quot;coordinates&quot; =&gt; [ [ - 1.1 , - 2.2 , - 4.4 ] , [ 1.1 , 2.2 , 4.4 ] ] }","ref":"Geometry.LineStringM.html#to_geo_json/1","title":"Geometry.LineStringM.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a LineStringM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointM.to_wkb/1 function.","ref":"Geometry.LineStringM.html#to_wkb/2","title":"Geometry.LineStringM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a LineStringM . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; LineStringM . to_wkt ( LineStringM . new ( ) ) &quot;LineString M EMPTY&quot; iex&gt; LineStringM . to_wkt ( ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 7.1 , 8.1 , 1 ) , ...&gt; PointM . new ( 9.2 , 5.2 , 2 ) ...&gt; ] ) ...&gt; ) &quot;LineString M (7.1 8.1 1, 9.2 5.2 2)&quot; iex&gt; LineStringM . to_wkt ( ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 7.1 , 8.1 , 1 ) , ...&gt; PointM . new ( 9.2 , 5.2 , 2 ) ...&gt; ] ) , ...&gt; srid : 123 ...&gt; ) &quot;SRID=123;LineString M (7.1 8.1 1, 9.2 5.2 2)&quot;","ref":"Geometry.LineStringM.html#to_wkt/2","title":"Geometry.LineStringM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.LineStringM.html#t:t/0","title":"Geometry.LineStringM.t/0","type":"type"},{"doc":"A point struct, representing a 2D point.","ref":"Geometry.Point.html","title":"Geometry.Point","type":"module"},{"doc":"Returns true if the given Point is empty. Examples iex&gt; Point . empty? ( Point . new ( ) ) true iex&gt; Point . empty? ( Point . new ( 1 , 2 ) ) false","ref":"Geometry.Point.html#empty?/1","title":"Geometry.Point.empty?/1","type":"function"},{"doc":"Creates a Point from the given coordinate. Examples iex&gt; Point . from_coordinates ( [ [ - 1 , 1 ] ] ) % Point { coordinate : [ - 1 , 1 ] }","ref":"Geometry.Point.html#from_coordinates/1","title":"Geometry.Point.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the Point from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s({&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1.1, 2.2]}) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; Point . from_geo_json ( ) { :ok , % Point { coordinate : [ 1.1 , 2.2 ] } }","ref":"Geometry.Point.html#from_geo_json/1","title":"Geometry.Point.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.Point.html#from_geo_json!/1","title":"Geometry.Point.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the Point from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . Examples iex&gt; Point . from_wkb ( ...&gt; &quot;00000000017FF80000000000007FF8000000000000&quot; , ...&gt; :hex ...&gt; ) { :ok , % Point { coordinate : nil } } iex&gt; Point . from_wkb ( ...&gt; &quot;00000000013FF199999999999A400199999999999A&quot; , ...&gt; :hex ...&gt; ) { :ok , % Point { coordinate : [ 1.1 , 2.2 ] } } iex&gt; Point . from_wkb ( ...&gt; &quot;01010000009A9999999999F13F9A99999999990140&quot; , ...&gt; :hex ...&gt; ) { :ok , % Point { coordinate : [ 1.1 , 2.2 ] } } iex&gt; Point . from_wkb ( ...&gt; &quot;0020000001000012673FF199999999999A400199999999999A&quot; , ...&gt; :hex ...&gt; ) { :ok , { % Point { coordinate : [ 1.1 , 2.2 ] } , 4711 } }","ref":"Geometry.Point.html#from_wkb/2","title":"Geometry.Point.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.Point.html#from_wkb!/2","title":"Geometry.Point.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the Point from the given WKT string. Otherwise returns an :error tuple. If the geometry contains an SRID the id is added to the tuple. Examples iex&gt; Point . from_wkt ( &quot;Point (-5.1 7.8)&quot; ) { :ok , % Point { coordinate : [ - 5.1 , 7.8 ] } } iex&gt; Point . from_wkt ( &quot;SRID=7219;Point (-5.1 7.8)&quot; ) { :ok , { % Point { coordinate : [ - 5.1 , 7.8 ] } , 7219 } } iex&gt; Point . from_wkt ( &quot;Point EMPTY&quot; ) { :ok , % Point { } }","ref":"Geometry.Point.html#from_wkt/1","title":"Geometry.Point.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.Point.html#from_wkt!/1","title":"Geometry.Point.from_wkt!/1","type":"function"},{"doc":"Creates an empty Point . Examples iex&gt; Point . new ( ) % Point { coordinate : nil }","ref":"Geometry.Point.html#new/0","title":"Geometry.Point.new/0","type":"function"},{"doc":"Creates a Point from the given coordinate . Examples iex&gt; Point . new ( [ 1.5 , - 2.1 ] ) % Point { coordinate : [ 1.5 , - 2.1 ] }","ref":"Geometry.Point.html#new/1","title":"Geometry.Point.new/1","type":"function"},{"doc":"Creates a Point from the given x and y . Examples iex&gt; Point . new ( - 1.1 , 2.2 ) % Point { coordinate : [ - 1.1 , 2.2 ] }","ref":"Geometry.Point.html#new/2","title":"Geometry.Point.new/2","type":"function"},{"doc":"Returns the GeoJSON term of a Point . Examples iex&gt; Point . to_geo_json ( Point . new ( 1 , 2 ) ) %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1 , 2 ] }","ref":"Geometry.Point.html#to_geo_json/1","title":"Geometry.Point.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a Point . With option :srid an EWKB representation with the SRID is returned. The option :endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . Examples iex&gt; Point . to_wkb ( Point . new ( ) , mode : :hex ) &quot;00000000017FF80000000000007FF8000000000000&quot; iex&gt; Point . to_wkb ( Point . new ( ) , endian : :ndr , mode : :hex ) &quot;0101000000000000000000F87F000000000000F87F&quot; iex&gt; Point . to_wkb ( Point . new ( 1.1 , 2.2 ) , endian : :xdr , mode : :hex ) &quot;00000000013FF199999999999A400199999999999A&quot; iex&gt; Point . to_wkb ( Point . new ( 1.1 , 2.2 ) , endian : :ndr , mode : :hex ) &quot;01010000009A9999999999F13F9A99999999990140&quot; iex&gt; Point . to_wkb ( Point . new ( 1.1 , 2.2 ) , srid : 4711 , endian : :xdr , mode : :hex ) &quot;0020000001000012673FF199999999999A400199999999999A&quot;","ref":"Geometry.Point.html#to_wkb/2","title":"Geometry.Point.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a Point . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; Point . to_wkt ( Point . new ( ) ) &quot;Point EMPTY&quot; iex&gt; Point . to_wkt ( Point . new ( 1.1 , 2.2 ) ) &quot;Point (1.1 2.2)&quot; iex&gt; Point . to_wkt ( Point . new ( 1.1 , 2.2 ) , srid : 4711 ) &quot;SRID=4711;Point (1.1 2.2)&quot;","ref":"Geometry.Point.html#to_wkt/2","title":"Geometry.Point.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.Point.html#t:t/0","title":"Geometry.Point.t/0","type":"type"},{"doc":"A point struct, representing a 2D point with a measurement.","ref":"Geometry.PointM.html","title":"Geometry.PointM","type":"module"},{"doc":"Returns true if the given PointM is empty. Examples iex&gt; PointM . empty? ( PointM . new ( ) ) true iex&gt; PointM . empty? ( PointM . new ( 1 , 2 , 4 ) ) false","ref":"Geometry.PointM.html#empty?/1","title":"Geometry.PointM.empty?/1","type":"function"},{"doc":"Creates a PointM from the given coordinate. Examples iex&gt; PointM . from_coordinates ( [ [ - 1 , 1 , 1 ] ] ) % PointM { coordinate : [ - 1 , 1 , 1 ] }","ref":"Geometry.PointM.html#from_coordinates/1","title":"Geometry.PointM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the PointM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s({&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1.1, 2.2, 4.4]}) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PointM . from_geo_json ( ) { :ok , % PointM { coordinate : [ 1.1 , 2.2 , 4.4 ] } }","ref":"Geometry.PointM.html#from_geo_json/1","title":"Geometry.PointM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointM.html#from_geo_json!/1","title":"Geometry.PointM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the PointM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . Examples iex&gt; PointM . from_wkb ( ...&gt; &quot;00400000017FF80000000000007FF80000000000007FF8000000000000&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointM { coordinate : nil } } iex&gt; PointM . from_wkb ( ...&gt; &quot;00400000013FF199999999999A400199999999999A401199999999999A&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointM { coordinate : [ 1.1 , 2.2 , 4.4 ] } } iex&gt; PointM . from_wkb ( ...&gt; &quot;01010000409A9999999999F13F9A999999999901409A99999999991140&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointM { coordinate : [ 1.1 , 2.2 , 4.4 ] } } iex&gt; PointM . from_wkb ( ...&gt; &quot;0060000001000012673FF199999999999A400199999999999A401199999999999A&quot; , ...&gt; :hex ...&gt; ) { :ok , { % PointM { coordinate : [ 1.1 , 2.2 , 4.4 ] } , 4711 } }","ref":"Geometry.PointM.html#from_wkb/2","title":"Geometry.PointM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointM.html#from_wkb!/2","title":"Geometry.PointM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the PointM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains an SRID the id is added to the tuple. Examples iex&gt; PointM . from_wkt ( &quot;Point M (-5.1 7.8 12)&quot; ) { :ok , % PointM { coordinate : [ - 5.1 , 7.8 , 12 ] } } iex&gt; PointM . from_wkt ( &quot;SRID=7219;Point M (-5.1 7.8 12)&quot; ) { :ok , { % PointM { coordinate : [ - 5.1 , 7.8 , 12 ] } , 7219 } } iex&gt; PointM . from_wkt ( &quot;Point M EMPTY&quot; ) { :ok , % PointM { } }","ref":"Geometry.PointM.html#from_wkt/1","title":"Geometry.PointM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointM.html#from_wkt!/1","title":"Geometry.PointM.from_wkt!/1","type":"function"},{"doc":"Creates an empty PointM . Examples iex&gt; PointM . new ( ) % PointM { coordinate : nil }","ref":"Geometry.PointM.html#new/0","title":"Geometry.PointM.new/0","type":"function"},{"doc":"Creates a PointM from the given coordinate . Examples iex&gt; PointM . new ( [ 1.5 , - 2.1 , 4 ] ) % PointM { coordinate : [ 1.5 , - 2.1 , 4 ] }","ref":"Geometry.PointM.html#new/1","title":"Geometry.PointM.new/1","type":"function"},{"doc":"Creates a PointM from the given x , y , and m . Examples iex&gt; PointM . new ( - 1.1 , 2.2 , 4 ) % PointM { coordinate : [ - 1.1 , 2.2 , 4 ] }","ref":"Geometry.PointM.html#new/3","title":"Geometry.PointM.new/3","type":"function"},{"doc":"Returns the GeoJSON term of a PointM . Examples iex&gt; PointM . to_geo_json ( PointM . new ( 1 , 2 , 4 ) ) %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1 , 2 , 4 ] }","ref":"Geometry.PointM.html#to_geo_json/1","title":"Geometry.PointM.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a PointM . With option :srid an EWKB representation with the SRID is returned. The option :endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . Examples iex&gt; PointM . to_wkb ( PointM . new ( ) , mode : :hex ) &quot;00400000017FF80000000000007FF80000000000007FF8000000000000&quot; iex&gt; PointM . to_wkb ( PointM . new ( ) , endian : :ndr , mode : :hex ) &quot;0101000040000000000000F87F000000000000F87F000000000000F87F&quot; iex&gt; PointM . to_wkb ( PointM . new ( 1.1 , 2.2 , 4.4 ) , endian : :xdr , mode : :hex ) &quot;00400000013FF199999999999A400199999999999A401199999999999A&quot; iex&gt; PointM . to_wkb ( PointM . new ( 1.1 , 2.2 , 4.4 ) , endian : :ndr , mode : :hex ) &quot;01010000409A9999999999F13F9A999999999901409A99999999991140&quot; iex&gt; PointM . to_wkb ( PointM . new ( 1.1 , 2.2 , 4.4 ) , srid : 4711 , endian : :xdr , mode : :hex ) &quot;0060000001000012673FF199999999999A400199999999999A401199999999999A&quot;","ref":"Geometry.PointM.html#to_wkb/2","title":"Geometry.PointM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a PointM . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; PointM . to_wkt ( PointM . new ( ) ) &quot;Point M EMPTY&quot; iex&gt; PointM . to_wkt ( PointM . new ( 1.1 , 2.2 , 4.4 ) ) &quot;Point M (1.1 2.2 4.4)&quot; iex&gt; PointM . to_wkt ( PointM . new ( 1.1 , 2.2 , 4.4 ) , srid : 4711 ) &quot;SRID=4711;Point M (1.1 2.2 4.4)&quot;","ref":"Geometry.PointM.html#to_wkt/2","title":"Geometry.PointM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.PointM.html#t:t/0","title":"Geometry.PointM.t/0","type":"type"},{"doc":"A polygon struct, representing a 2D polygon. A none empty line-string requires at least one ring with four points.","ref":"Geometry.Polygon.html","title":"Geometry.Polygon","type":"module"},{"doc":"Returns true if the given Polygon is empty. Examples iex&gt; Polygon . empty? ( Polygon . new ( ) ) true iex&gt; Polygon . empty? ( ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 35 , 10 ) , ...&gt; Point . new ( 45 , 45 ) , ...&gt; Point . new ( 10 , 20 ) , ...&gt; Point . new ( 35 , 10 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.Polygon.html#empty?/1","title":"Geometry.Polygon.empty?/1","type":"function"},{"doc":"Creates a Polygon from the given coordinates. Examples iex&gt; Polygon . from_coordinates ( [ ...&gt; [ [ 1 , 1 ] , [ 2 , 1 ] , [ 2 , 2 ] , [ 1 , 1 ] ] ...&gt; ] ) % Polygon { rings : [ [ [ 1 , 1 ] , [ 2 , 1 ] , [ 2 , 2 ] , [ 1 , 1 ] ] ] }","ref":"Geometry.Polygon.html#from_coordinates/1","title":"Geometry.Polygon.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the Polygon from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;Polygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[35, 10], ...&gt; [45, 45], ...&gt; [15, 40], ...&gt; [10, 20], ...&gt; [35, 10]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; Polygon . from_geo_json ( ) { :ok , % Polygon { rings : [ [ [ 35 , 10 ] , [ 45 , 45 ] , [ 15 , 40 ] , [ 10 , 20 ] , [ 35 , 10 ] ] ] } } iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;Polygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[35, 10], ...&gt; [45, 45], ...&gt; [15, 40], ...&gt; [10, 20], ...&gt; [35, 10]], ...&gt; [[20, 30], ...&gt; [35, 35], ...&gt; [30, 20], ...&gt; [20, 30]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; Polygon . from_geo_json ( ) { :ok , % Polygon { rings : [ [ [ 35 , 10 ] , [ 45 , 45 ] , [ 15 , 40 ] , [ 10 , 20 ] , [ 35 , 10 ] ] , [ [ 20 , 30 ] , [ 35 , 35 ] , [ 30 , 20 ] , [ 20 , 30 ] ] ] } }","ref":"Geometry.Polygon.html#from_geo_json/1","title":"Geometry.Polygon.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.Polygon.html#from_geo_json!/1","title":"Geometry.Polygon.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the Polygon from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.Point.from_wkb/2 function.","ref":"Geometry.Polygon.html#from_wkb/2","title":"Geometry.Polygon.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.Polygon.html#from_wkb!/2","title":"Geometry.Polygon.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the Polygon from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; Polygon . from_wkt ( &quot; ...&gt; POLYGON ( ...&gt; (35 10, 45 45, 15 40, 10 20, 35 10), ...&gt; (20 30, 35 35, 30 20, 20 30) ...&gt; ) ...&gt; &quot; ) { :ok , % Polygon { rings : [ [ [ 35 , 10 ] , [ 45 , 45 ] , [ 15 , 40 ] , [ 10 , 20 ] , [ 35 , 10 ] ] , [ [ 20 , 30 ] , [ 35 , 35 ] , [ 30 , 20 ] , [ 20 , 30 ] ] ] } } iex&gt; &quot; ...&gt; SRID=789; ...&gt; POLYGON ( ...&gt; (35 10, 45 45, 15 40, 10 20, 35 10), ...&gt; (20 30, 35 35, 30 20, 20 30) ...&gt; ) ...&gt; &quot; iex&gt; |&gt; Polygon . from_wkt ( ) { :ok , { % Polygon { rings : [ [ [ 35 , 10 ] , [ 45 , 45 ] , [ 15 , 40 ] , [ 10 , 20 ] , [ 35 , 10 ] ] , [ [ 20 , 30 ] , [ 35 , 35 ] , [ 30 , 20 ] , [ 20 , 30 ] ] ] } , 789 } } iex&gt; Polygon . from_wkt ( &quot;Polygon EMPTY&quot; ) { :ok , % Polygon { } }","ref":"Geometry.Polygon.html#from_wkt/1","title":"Geometry.Polygon.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.Polygon.html#from_wkt!/1","title":"Geometry.Polygon.from_wkt!/1","type":"function"},{"doc":"Creates an empty Polygon . Examples iex&gt; Polygon . new ( ) % Polygon { rings : [ ] }","ref":"Geometry.Polygon.html#new/0","title":"Geometry.Polygon.new/0","type":"function"},{"doc":"Creates a Polygon from the given rings . Examples iex&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 35 , 10 ) , ...&gt; Point . new ( 45 , 45 ) , ...&gt; Point . new ( 10 , 20 ) , ...&gt; Point . new ( 35 , 10 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 20 , 30 ) , ...&gt; Point . new ( 35 , 35 ) , ...&gt; Point . new ( 30 , 20 ) , ...&gt; Point . new ( 20 , 30 ) ...&gt; ] ) ...&gt; ] ) % Polygon { rings : [ [ [ 35 , 10 ] , [ 45 , 45 ] , [ 10 , 20 ] , [ 35 , 10 ] ] , [ [ 20 , 30 ] , [ 35 , 35 ] , [ 30 , 20 ] , [ 20 , 30 ] ] ] } iex&gt; Polygon . new ( ) % Polygon { }","ref":"Geometry.Polygon.html#new/1","title":"Geometry.Polygon.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a Polygon . Examples iex&gt; Polygon . to_geo_json ( ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 35 , 10 ) , ...&gt; Point . new ( 45 , 45 ) , ...&gt; Point . new ( 10 , 20 ) , ...&gt; Point . new ( 35 , 10 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 20 , 30 ) , ...&gt; Point . new ( 35 , 35 ) , ...&gt; Point . new ( 30 , 20 ) , ...&gt; Point . new ( 20 , 30 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) %{ &quot;type&quot; =&gt; &quot;Polygon&quot; , &quot;coordinates&quot; =&gt; [ [ [ 35 , 10 ] , [ 45 , 45 ] , [ 10 , 20 ] , [ 35 , 10 ] ] , [ [ 20 , 30 ] , [ 35 , 35 ] , [ 30 , 20 ] , [ 20 , 30 ] ] ] }","ref":"Geometry.Polygon.html#to_geo_json/1","title":"Geometry.Polygon.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a Polygon . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.Point.to_wkb/1 function.","ref":"Geometry.Polygon.html#to_wkb/2","title":"Geometry.Polygon.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a Polygon . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; Polygon . to_wkt ( Polygon . new ( ) ) &quot;Polygon EMPTY&quot; iex&gt; Polygon . to_wkt ( Polygon . new ( ) , srid : 1123 ) &quot;SRID=1123;Polygon EMPTY&quot; iex&gt; Polygon . to_wkt ( ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 35 , 10 ) , ...&gt; Point . new ( 45 , 45 ) , ...&gt; Point . new ( 10 , 20 ) , ...&gt; Point . new ( 35 , 10 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 20 , 30 ) , ...&gt; Point . new ( 35 , 35 ) , ...&gt; Point . new ( 30 , 20 ) , ...&gt; Point . new ( 20 , 30 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) &quot;Polygon ((35 10, 45 45, 10 20, 35 10), (20 30, 35 35, 30 20, 20 30))&quot;","ref":"Geometry.Polygon.html#to_wkt/2","title":"Geometry.Polygon.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.Polygon.html#t:t/0","title":"Geometry.Polygon.t/0","type":"type"},{"doc":"A polygon struct, representing a 2D polygon with a measurement. A none empty line-string requires at least one ring with four points.","ref":"Geometry.PolygonM.html","title":"Geometry.PolygonM","type":"module"},{"doc":"Returns true if the given PolygonM is empty. Examples iex&gt; PolygonM . empty? ( PolygonM . new ( ) ) true iex&gt; PolygonM . empty? ( ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 35 , 10 , 14 ) , ...&gt; PointM . new ( 45 , 45 , 24 ) , ...&gt; PointM . new ( 10 , 20 , 34 ) , ...&gt; PointM . new ( 35 , 10 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.PolygonM.html#empty?/1","title":"Geometry.PolygonM.empty?/1","type":"function"},{"doc":"Creates a PolygonM from the given coordinates. Examples iex&gt; PolygonM . from_coordinates ( [ ...&gt; [ [ 1 , 1 , 1 ] , [ 2 , 1 , 3 ] , [ 2 , 2 , 2 ] , [ 1 , 1 , 1 ] ] ...&gt; ] ) % PolygonM { rings : [ [ [ 1 , 1 , 1 ] , [ 2 , 1 , 3 ] , [ 2 , 2 , 2 ] , [ 1 , 1 , 1 ] ] ] }","ref":"Geometry.PolygonM.html#from_coordinates/1","title":"Geometry.PolygonM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the PolygonM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;Polygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[35, 10, 12], ...&gt; [45, 45, 22], ...&gt; [15, 40, 33], ...&gt; [10, 20, 55], ...&gt; [35, 10, 12]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PolygonM . from_geo_json ( ) { :ok , % PolygonM { rings : [ [ [ 35 , 10 , 12 ] , [ 45 , 45 , 22 ] , [ 15 , 40 , 33 ] , [ 10 , 20 , 55 ] , [ 35 , 10 , 12 ] ] ] } } iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;Polygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[35, 10, 12], ...&gt; [45, 45, 22], ...&gt; [15, 40, 33], ...&gt; [10, 20, 55], ...&gt; [35, 10, 12]], ...&gt; [[20, 30, 11], ...&gt; [35, 35, 55], ...&gt; [30, 20, 45], ...&gt; [20, 30, 11]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PolygonM . from_geo_json ( ) { :ok , % PolygonM { rings : [ [ [ 35 , 10 , 12 ] , [ 45 , 45 , 22 ] , [ 15 , 40 , 33 ] , [ 10 , 20 , 55 ] , [ 35 , 10 , 12 ] ] , [ [ 20 , 30 , 11 ] , [ 35 , 35 , 55 ] , [ 30 , 20 , 45 ] , [ 20 , 30 , 11 ] ] ] } }","ref":"Geometry.PolygonM.html#from_geo_json/1","title":"Geometry.PolygonM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonM.html#from_geo_json!/1","title":"Geometry.PolygonM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the PolygonM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointM.from_wkb/2 function.","ref":"Geometry.PolygonM.html#from_wkb/2","title":"Geometry.PolygonM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonM.html#from_wkb!/2","title":"Geometry.PolygonM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the PolygonM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; PolygonM . from_wkt ( &quot; ...&gt; POLYGON M ( ...&gt; (35 10 22, 45 45 33, 15 40 44, 10 20 66, 35 10 22), ...&gt; (20 30 55, 35 35 66, 30 20 99, 20 30 55) ...&gt; ) ...&gt; &quot; ) { :ok , % PolygonM { rings : [ [ [ 35 , 10 , 22 ] , [ 45 , 45 , 33 ] , [ 15 , 40 , 44 ] , [ 10 , 20 , 66 ] , [ 35 , 10 , 22 ] ] , [ [ 20 , 30 , 55 ] , [ 35 , 35 , 66 ] , [ 30 , 20 , 99 ] , [ 20 , 30 , 55 ] ] ] } } iex&gt; &quot; ...&gt; SRID=789; ...&gt; POLYGON M ( ...&gt; (35 10 22, 45 45 33, 15 40 44, 10 20 66, 35 10 22), ...&gt; (20 30 55, 35 35 66, 30 20 99, 20 30 55) ...&gt; ) ...&gt; &quot; iex&gt; |&gt; PolygonM . from_wkt ( ) { :ok , { % PolygonM { rings : [ [ [ 35 , 10 , 22 ] , [ 45 , 45 , 33 ] , [ 15 , 40 , 44 ] , [ 10 , 20 , 66 ] , [ 35 , 10 , 22 ] ] , [ [ 20 , 30 , 55 ] , [ 35 , 35 , 66 ] , [ 30 , 20 , 99 ] , [ 20 , 30 , 55 ] ] ] } , 789 } } iex&gt; PolygonM . from_wkt ( &quot;Polygon M EMPTY&quot; ) { :ok , % PolygonM { } }","ref":"Geometry.PolygonM.html#from_wkt/1","title":"Geometry.PolygonM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonM.html#from_wkt!/1","title":"Geometry.PolygonM.from_wkt!/1","type":"function"},{"doc":"Creates an empty PolygonM . Examples iex&gt; PolygonM . new ( ) % PolygonM { rings : [ ] }","ref":"Geometry.PolygonM.html#new/0","title":"Geometry.PolygonM.new/0","type":"function"},{"doc":"Creates a PolygonM from the given rings . Examples iex&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 35 , 10 , 14 ) , ...&gt; PointM . new ( 45 , 45 , 24 ) , ...&gt; PointM . new ( 10 , 20 , 34 ) , ...&gt; PointM . new ( 35 , 10 , 14 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 20 , 30 , 14 ) , ...&gt; PointM . new ( 35 , 35 , 24 ) , ...&gt; PointM . new ( 30 , 20 , 34 ) , ...&gt; PointM . new ( 20 , 30 , 14 ) ...&gt; ] ) ...&gt; ] ) % PolygonM { rings : [ [ [ 35 , 10 , 14 ] , [ 45 , 45 , 24 ] , [ 10 , 20 , 34 ] , [ 35 , 10 , 14 ] ] , [ [ 20 , 30 , 14 ] , [ 35 , 35 , 24 ] , [ 30 , 20 , 34 ] , [ 20 , 30 , 14 ] ] ] } iex&gt; PolygonM . new ( ) % PolygonM { }","ref":"Geometry.PolygonM.html#new/1","title":"Geometry.PolygonM.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a PolygonM . Examples iex&gt; PolygonM . to_geo_json ( ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 35 , 10 , 14 ) , ...&gt; PointM . new ( 45 , 45 , 24 ) , ...&gt; PointM . new ( 10 , 20 , 34 ) , ...&gt; PointM . new ( 35 , 10 , 14 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 20 , 30 , 14 ) , ...&gt; PointM . new ( 35 , 35 , 24 ) , ...&gt; PointM . new ( 30 , 20 , 34 ) , ...&gt; PointM . new ( 20 , 30 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) %{ &quot;type&quot; =&gt; &quot;Polygon&quot; , &quot;coordinates&quot; =&gt; [ [ [ 35 , 10 , 14 ] , [ 45 , 45 , 24 ] , [ 10 , 20 , 34 ] , [ 35 , 10 , 14 ] ] , [ [ 20 , 30 , 14 ] , [ 35 , 35 , 24 ] , [ 30 , 20 , 34 ] , [ 20 , 30 , 14 ] ] ] }","ref":"Geometry.PolygonM.html#to_geo_json/1","title":"Geometry.PolygonM.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a PolygonM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointM.to_wkb/1 function.","ref":"Geometry.PolygonM.html#to_wkb/2","title":"Geometry.PolygonM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a PolygonM . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; PolygonM . to_wkt ( PolygonM . new ( ) ) &quot;Polygon M EMPTY&quot; iex&gt; PolygonM . to_wkt ( PolygonM . new ( ) , srid : 1123 ) &quot;SRID=1123;Polygon M EMPTY&quot; iex&gt; PolygonM . to_wkt ( ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 35 , 10 , 14 ) , ...&gt; PointM . new ( 45 , 45 , 24 ) , ...&gt; PointM . new ( 10 , 20 , 34 ) , ...&gt; PointM . new ( 35 , 10 , 14 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 20 , 30 , 14 ) , ...&gt; PointM . new ( 35 , 35 , 24 ) , ...&gt; PointM . new ( 30 , 20 , 34 ) , ...&gt; PointM . new ( 20 , 30 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) &quot;Polygon M ((35 10 14, 45 45 24, 10 20 34, 35 10 14), (20 30 14, 35 35 24, 30 20 34, 20 30 14))&quot;","ref":"Geometry.PolygonM.html#to_wkt/2","title":"Geometry.PolygonM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.PolygonM.html#t:t/0","title":"Geometry.PolygonM.t/0","type":"type"},{"doc":"A line-string struct, representing a 3D line. A none empty line-string requires at least two points.","ref":"Geometry.LineStringZ.html","title":"Geometry.LineStringZ","type":"module"},{"doc":"Returns true if the given LineStringZ is empty. Examples iex&gt; LineStringZ . empty? ( LineStringZ . new ( ) ) true iex&gt; LineStringZ . empty? ( ...&gt; LineStringZ . new ( ...&gt; [ PointZ . new ( 1 , 2 , 3 ) , PointZ . new ( 3 , 4 , 5 ) ] ...&gt; ) ...&gt; ) false","ref":"Geometry.LineStringZ.html#empty?/1","title":"Geometry.LineStringZ.empty?/1","type":"function"},{"doc":"Creates a LineStringZ from the given coordinates. Examples iex&gt; LineStringZ . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ...&gt; ) % LineStringZ { points : [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] }","ref":"Geometry.LineStringZ.html#from_coordinates/1","title":"Geometry.LineStringZ.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the LineStringZ from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;LineString&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [1.1, 1.2, 1.3], ...&gt; [20.1, 20.2, 20.3] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; LineStringZ . from_geo_json ( ) { :ok , % LineStringZ { points : [ [ 1.1 , 1.2 , 1.3 ] , [ 20.1 , 20.2 , 20.3 ] ] } }","ref":"Geometry.LineStringZ.html#from_geo_json/1","title":"Geometry.LineStringZ.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringZ.html#from_geo_json!/1","title":"Geometry.LineStringZ.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the LineStringZ from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZ.from_wkb/2 function.","ref":"Geometry.LineStringZ.html#from_wkb/2","title":"Geometry.LineStringZ.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringZ.html#from_wkb!/2","title":"Geometry.LineStringZ.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the LineStringZ from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; LineStringZ . from_wkt ( ...&gt; &quot;LineString Z (-5.1 7.8 1.1, 0.1 0.2 2.2)&quot; ...&gt; ) { :ok , % LineStringZ { points : [ [ - 5.1 , 7.8 , 1.1 ] , [ 0.1 , 0.2 , 2.2 ] ] } } iex&gt; LineStringZ . from_wkt ( ...&gt; &quot;SRID=7219;LineString Z (-5.1 7.8 1.1, 0.1 0.2 2.2)&quot; ...&gt; ) { :ok , { % LineStringZ { points : [ [ - 5.1 , 7.8 , 1.1 ] , [ 0.1 , 0.2 , 2.2 ] ] } , 7219 } } iex&gt; LineStringZ . from_wkt ( &quot;LineString Z EMPTY&quot; ) { :ok , % LineStringZ { } }","ref":"Geometry.LineStringZ.html#from_wkt/1","title":"Geometry.LineStringZ.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringZ.html#from_wkt!/1","title":"Geometry.LineStringZ.from_wkt!/1","type":"function"},{"doc":"Creates an empty LineStringZ . Examples iex&gt; LineStringZ . new ( ) % LineStringZ { points : [ ] }","ref":"Geometry.LineStringZ.html#new/0","title":"Geometry.LineStringZ.new/0","type":"function"},{"doc":"Creates a LineStringZ from the given Geometry.PointZ s. Examples iex&gt; LineStringZ . new ( [ PointZ . new ( 1 , 2 , 3 ) , PointZ . new ( 3 , 4 , 5 ) ] ) % LineStringZ { points : [ [ 1 , 2 , 3 ] , [ 3 , 4 , 5 ] ] }","ref":"Geometry.LineStringZ.html#new/1","title":"Geometry.LineStringZ.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a LineStringZ . Examples iex&gt; LineStringZ . to_geo_json ( ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( - 1.1 , - 2.2 , - 3.3 ) , ...&gt; PointZ . new ( 1.1 , 2.2 , 3.3 ) ...&gt; ] ) ...&gt; ) %{ &quot;type&quot; =&gt; &quot;LineString&quot; , &quot;coordinates&quot; =&gt; [ [ - 1.1 , - 2.2 , - 3.3 ] , [ 1.1 , 2.2 , 3.3 ] ] }","ref":"Geometry.LineStringZ.html#to_geo_json/1","title":"Geometry.LineStringZ.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a LineStringZ . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZ.to_wkb/1 function.","ref":"Geometry.LineStringZ.html#to_wkb/2","title":"Geometry.LineStringZ.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a LineStringZ . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; LineStringZ . to_wkt ( LineStringZ . new ( ) ) &quot;LineString Z EMPTY&quot; iex&gt; LineStringZ . to_wkt ( ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 7.1 , 8.1 , 1.1 ) , ...&gt; PointZ . new ( 9.2 , 5.2 , 2.2 ) ...&gt; ] ) ...&gt; ) &quot;LineString Z (7.1 8.1 1.1, 9.2 5.2 2.2)&quot; iex&gt; LineStringZ . to_wkt ( ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 7.1 , 8.1 , 1.1 ) , ...&gt; PointZ . new ( 9.2 , 5.2 , 2.2 ) ...&gt; ] ) , ...&gt; srid : 123 ...&gt; ) &quot;SRID=123;LineString Z (7.1 8.1 1.1, 9.2 5.2 2.2)&quot;","ref":"Geometry.LineStringZ.html#to_wkt/2","title":"Geometry.LineStringZ.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.LineStringZ.html#t:t/0","title":"Geometry.LineStringZ.t/0","type":"type"},{"doc":"A line-string struct, representing a 3D line with a measurement. A none empty line-string requires at least two points.","ref":"Geometry.LineStringZM.html","title":"Geometry.LineStringZM","type":"module"},{"doc":"Returns true if the given LineStringZM is empty. Examples iex&gt; LineStringZM . empty? ( LineStringZM . new ( ) ) true iex&gt; LineStringZM . empty? ( ...&gt; LineStringZM . new ( ...&gt; [ PointZM . new ( 1 , 2 , 3 , 4 ) , PointZM . new ( 3 , 4 , 5 , 6 ) ] ...&gt; ) ...&gt; ) false","ref":"Geometry.LineStringZM.html#empty?/1","title":"Geometry.LineStringZM.empty?/1","type":"function"},{"doc":"Creates a LineStringZM from the given coordinates. Examples iex&gt; LineStringZM . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 , 1 ] , [ - 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] ...&gt; ) % LineStringZM { points : [ [ - 1 , 1 , 1 , 1 ] , [ - 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] }","ref":"Geometry.LineStringZM.html#from_coordinates/1","title":"Geometry.LineStringZM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the LineStringZM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;LineString&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [1.1, 1.2, 1.3, 1.4], ...&gt; [20.1, 20.2, 20.3, 20.4] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; LineStringZM . from_geo_json ( ) { :ok , % LineStringZM { points : [ [ 1.1 , 1.2 , 1.3 , 1.4 ] , [ 20.1 , 20.2 , 20.3 , 20.4 ] ] } }","ref":"Geometry.LineStringZM.html#from_geo_json/1","title":"Geometry.LineStringZM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringZM.html#from_geo_json!/1","title":"Geometry.LineStringZM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the LineStringZM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZM.from_wkb/2 function.","ref":"Geometry.LineStringZM.html#from_wkb/2","title":"Geometry.LineStringZM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringZM.html#from_wkb!/2","title":"Geometry.LineStringZM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the LineStringZM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; LineStringZM . from_wkt ( ...&gt; &quot;LineString ZM (-5.1 7.8 1.1 1, 0.1 0.2 2.2 2)&quot; ...&gt; ) { :ok , % LineStringZM { points : [ [ - 5.1 , 7.8 , 1.1 , 1 ] , [ 0.1 , 0.2 , 2.2 , 2 ] ] } } iex&gt; LineStringZM . from_wkt ( ...&gt; &quot;SRID=7219;LineString ZM (-5.1 7.8 1.1 1, 0.1 0.2 2.2 2)&quot; ...&gt; ) { :ok , { % LineStringZM { points : [ [ - 5.1 , 7.8 , 1.1 , 1 ] , [ 0.1 , 0.2 , 2.2 , 2 ] ] } , 7219 } } iex&gt; LineStringZM . from_wkt ( &quot;LineString ZM EMPTY&quot; ) { :ok , % LineStringZM { } }","ref":"Geometry.LineStringZM.html#from_wkt/1","title":"Geometry.LineStringZM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.LineStringZM.html#from_wkt!/1","title":"Geometry.LineStringZM.from_wkt!/1","type":"function"},{"doc":"Creates an empty LineStringZM . Examples iex&gt; LineStringZM . new ( ) % LineStringZM { points : [ ] }","ref":"Geometry.LineStringZM.html#new/0","title":"Geometry.LineStringZM.new/0","type":"function"},{"doc":"Creates a LineStringZM from the given Geometry.PointZM s. Examples iex&gt; LineStringZM . new ( [ PointZM . new ( 1 , 2 , 3 , 4 ) , PointZM . new ( 3 , 4 , 5 , 6 ) ] ) % LineStringZM { points : [ [ 1 , 2 , 3 , 4 ] , [ 3 , 4 , 5 , 6 ] ] }","ref":"Geometry.LineStringZM.html#new/1","title":"Geometry.LineStringZM.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a LineStringZM . Examples iex&gt; LineStringZM . to_geo_json ( ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( - 1.1 , - 2.2 , - 3.3 , - 4.4 ) , ...&gt; PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) ...&gt; ] ) ...&gt; ) %{ &quot;type&quot; =&gt; &quot;LineString&quot; , &quot;coordinates&quot; =&gt; [ [ - 1.1 , - 2.2 , - 3.3 , - 4.4 ] , [ 1.1 , 2.2 , 3.3 , 4.4 ] ] }","ref":"Geometry.LineStringZM.html#to_geo_json/1","title":"Geometry.LineStringZM.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a LineStringZM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZM.to_wkb/1 function.","ref":"Geometry.LineStringZM.html#to_wkb/2","title":"Geometry.LineStringZM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a LineStringZM . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; LineStringZM . to_wkt ( LineStringZM . new ( ) ) &quot;LineString ZM EMPTY&quot; iex&gt; LineStringZM . to_wkt ( ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 7.1 , 8.1 , 1.1 , 1 ) , ...&gt; PointZM . new ( 9.2 , 5.2 , 2.2 , 2 ) ...&gt; ] ) ...&gt; ) &quot;LineString ZM (7.1 8.1 1.1 1, 9.2 5.2 2.2 2)&quot; iex&gt; LineStringZM . to_wkt ( ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 7.1 , 8.1 , 1.1 , 1 ) , ...&gt; PointZM . new ( 9.2 , 5.2 , 2.2 , 2 ) ...&gt; ] ) , ...&gt; srid : 123 ...&gt; ) &quot;SRID=123;LineString ZM (7.1 8.1 1.1 1, 9.2 5.2 2.2 2)&quot;","ref":"Geometry.LineStringZM.html#to_wkt/2","title":"Geometry.LineStringZM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.LineStringZM.html#t:t/0","title":"Geometry.LineStringZM.t/0","type":"type"},{"doc":"A point struct, representing a 3D point.","ref":"Geometry.PointZ.html","title":"Geometry.PointZ","type":"module"},{"doc":"Returns true if the given PointZ is empty. Examples iex&gt; PointZ . empty? ( PointZ . new ( ) ) true iex&gt; PointZ . empty? ( PointZ . new ( 1 , 2 , 3 ) ) false","ref":"Geometry.PointZ.html#empty?/1","title":"Geometry.PointZ.empty?/1","type":"function"},{"doc":"Creates a PointZ from the given coordinate. Examples iex&gt; PointZ . from_coordinates ( [ [ - 1 , 1 , 1 ] ] ) % PointZ { coordinate : [ - 1 , 1 , 1 ] }","ref":"Geometry.PointZ.html#from_coordinates/1","title":"Geometry.PointZ.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the PointZ from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s({&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1.1, 2.2, 3.3]}) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PointZ . from_geo_json ( ) { :ok , % PointZ { coordinate : [ 1.1 , 2.2 , 3.3 ] } }","ref":"Geometry.PointZ.html#from_geo_json/1","title":"Geometry.PointZ.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointZ.html#from_geo_json!/1","title":"Geometry.PointZ.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the PointZ from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . Examples iex&gt; PointZ . from_wkb ( ...&gt; &quot;00800000017FF80000000000007FF80000000000007FF8000000000000&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointZ { coordinate : nil } } iex&gt; PointZ . from_wkb ( ...&gt; &quot;00800000013FF199999999999A400199999999999A400A666666666666&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointZ { coordinate : [ 1.1 , 2.2 , 3.3 ] } } iex&gt; PointZ . from_wkb ( ...&gt; &quot;01010000809A9999999999F13F9A999999999901406666666666660A40&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointZ { coordinate : [ 1.1 , 2.2 , 3.3 ] } } iex&gt; PointZ . from_wkb ( ...&gt; &quot;00A0000001000012673FF199999999999A400199999999999A400A666666666666&quot; , ...&gt; :hex ...&gt; ) { :ok , { % PointZ { coordinate : [ 1.1 , 2.2 , 3.3 ] } , 4711 } }","ref":"Geometry.PointZ.html#from_wkb/2","title":"Geometry.PointZ.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointZ.html#from_wkb!/2","title":"Geometry.PointZ.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the PointZ from the given WKT string. Otherwise returns an :error tuple. If the geometry contains an SRID the id is added to the tuple. Examples iex&gt; PointZ . from_wkt ( &quot;Point Z (-5.1 7.8 9.9)&quot; ) { :ok , % PointZ { coordinate : [ - 5.1 , 7.8 , 9.9 ] } } iex&gt; PointZ . from_wkt ( &quot;SRID=7219;Point Z (-5.1 7.8 9.9)&quot; ) { :ok , { % PointZ { coordinate : [ - 5.1 , 7.8 , 9.9 ] } , 7219 } } iex&gt; PointZ . from_wkt ( &quot;Point Z EMPTY&quot; ) { :ok , % PointZ { } }","ref":"Geometry.PointZ.html#from_wkt/1","title":"Geometry.PointZ.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointZ.html#from_wkt!/1","title":"Geometry.PointZ.from_wkt!/1","type":"function"},{"doc":"Creates an empty PointZ . Examples iex&gt; PointZ . new ( ) % PointZ { coordinate : nil }","ref":"Geometry.PointZ.html#new/0","title":"Geometry.PointZ.new/0","type":"function"},{"doc":"Creates a PointZ from the given coordinate . Examples iex&gt; PointZ . new ( [ 1.5 , - 2.1 , 3 ] ) % PointZ { coordinate : [ 1.5 , - 2.1 , 3 ] }","ref":"Geometry.PointZ.html#new/1","title":"Geometry.PointZ.new/1","type":"function"},{"doc":"Creates a PointZ from the given x , y , and z . Examples iex&gt; PointZ . new ( - 1.1 , 2.2 , 3 ) % PointZ { coordinate : [ - 1.1 , 2.2 , 3 ] }","ref":"Geometry.PointZ.html#new/3","title":"Geometry.PointZ.new/3","type":"function"},{"doc":"Returns the GeoJSON term of a PointZ . Examples iex&gt; PointZ . to_geo_json ( PointZ . new ( 1 , 2 , 3 ) ) %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1 , 2 , 3 ] }","ref":"Geometry.PointZ.html#to_geo_json/1","title":"Geometry.PointZ.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a PointZ . With option :srid an EWKB representation with the SRID is returned. The option :endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . Examples iex&gt; PointZ . to_wkb ( PointZ . new ( ) , mode : :hex ) &quot;00800000017FF80000000000007FF80000000000007FF8000000000000&quot; iex&gt; PointZ . to_wkb ( PointZ . new ( ) , endian : :ndr , mode : :hex ) &quot;0101000080000000000000F87F000000000000F87F000000000000F87F&quot; iex&gt; PointZ . to_wkb ( PointZ . new ( 1.1 , 2.2 , 3.3 ) , endian : :xdr , mode : :hex ) &quot;00800000013FF199999999999A400199999999999A400A666666666666&quot; iex&gt; PointZ . to_wkb ( PointZ . new ( 1.1 , 2.2 , 3.3 ) , endian : :ndr , mode : :hex ) &quot;01010000809A9999999999F13F9A999999999901406666666666660A40&quot; iex&gt; PointZ . to_wkb ( PointZ . new ( 1.1 , 2.2 , 3.3 ) , srid : 4711 , endian : :xdr , mode : :hex ) &quot;00A0000001000012673FF199999999999A400199999999999A400A666666666666&quot;","ref":"Geometry.PointZ.html#to_wkb/2","title":"Geometry.PointZ.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a PointZ . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; PointZ . to_wkt ( PointZ . new ( ) ) &quot;Point Z EMPTY&quot; iex&gt; PointZ . to_wkt ( PointZ . new ( 1.1 , 2.2 , 3.3 ) ) &quot;Point Z (1.1 2.2 3.3)&quot; iex&gt; PointZ . to_wkt ( PointZ . new ( 1.1 , 2.2 , 3.3 ) , srid : 4711 ) &quot;SRID=4711;Point Z (1.1 2.2 3.3)&quot;","ref":"Geometry.PointZ.html#to_wkt/2","title":"Geometry.PointZ.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.PointZ.html#t:t/0","title":"Geometry.PointZ.t/0","type":"type"},{"doc":"A point struct, representing a 3D point with a measurement.","ref":"Geometry.PointZM.html","title":"Geometry.PointZM","type":"module"},{"doc":"Returns true if the given PointZM is empty. Examples iex&gt; PointZM . empty? ( PointZM . new ( ) ) true iex&gt; PointZM . empty? ( PointZM . new ( 1 , 2 , 3 , 4 ) ) false","ref":"Geometry.PointZM.html#empty?/1","title":"Geometry.PointZM.empty?/1","type":"function"},{"doc":"Creates a PointZM from the given coordinate. Examples iex&gt; PointZM . from_coordinates ( [ [ - 1 , 1 , 1 , 1 ] ] ) % PointZM { coordinate : [ - 1 , 1 , 1 , 1 ] }","ref":"Geometry.PointZM.html#from_coordinates/1","title":"Geometry.PointZM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the PointZM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s({&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1.1, 2.2, 3.3, 4.4]}) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PointZM . from_geo_json ( ) { :ok , % PointZM { coordinate : [ 1.1 , 2.2 , 3.3 , 4.4 ] } }","ref":"Geometry.PointZM.html#from_geo_json/1","title":"Geometry.PointZM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointZM.html#from_geo_json!/1","title":"Geometry.PointZM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the PointZM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . Examples iex&gt; PointZM . from_wkb ( ...&gt; &quot;00C00000017FF80000000000007FF80000000000007FF80000000000007FF8000000000000&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointZM { coordinate : nil } } iex&gt; PointZM . from_wkb ( ...&gt; &quot;00C00000013FF199999999999A400199999999999A400A666666666666401199999999999A&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointZM { coordinate : [ 1.1 , 2.2 , 3.3 , 4.4 ] } } iex&gt; PointZM . from_wkb ( ...&gt; &quot;01010000C09A9999999999F13F9A999999999901406666666666660A409A99999999991140&quot; , ...&gt; :hex ...&gt; ) { :ok , % PointZM { coordinate : [ 1.1 , 2.2 , 3.3 , 4.4 ] } } iex&gt; PointZM . from_wkb ( ...&gt; &quot;00E0000001000012673FF199999999999A400199999999999A400A666666666666401199999999999A&quot; , ...&gt; :hex ...&gt; ) { :ok , { % PointZM { coordinate : [ 1.1 , 2.2 , 3.3 , 4.4 ] } , 4711 } }","ref":"Geometry.PointZM.html#from_wkb/2","title":"Geometry.PointZM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointZM.html#from_wkb!/2","title":"Geometry.PointZM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the PointZM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains an SRID the id is added to the tuple. Examples iex&gt; PointZM . from_wkt ( &quot;Point ZM (-5.1 7.8 9.9 12)&quot; ) { :ok , % PointZM { coordinate : [ - 5.1 , 7.8 , 9.9 , 12 ] } } iex&gt; PointZM . from_wkt ( &quot;SRID=7219;Point ZM (-5.1 7.8 9.9 12)&quot; ) { :ok , { % PointZM { coordinate : [ - 5.1 , 7.8 , 9.9 , 12 ] } , 7219 } } iex&gt; PointZM . from_wkt ( &quot;Point ZM EMPTY&quot; ) { :ok , % PointZM { } }","ref":"Geometry.PointZM.html#from_wkt/1","title":"Geometry.PointZM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PointZM.html#from_wkt!/1","title":"Geometry.PointZM.from_wkt!/1","type":"function"},{"doc":"Creates an empty PointZM . Examples iex&gt; PointZM . new ( ) % PointZM { coordinate : nil }","ref":"Geometry.PointZM.html#new/0","title":"Geometry.PointZM.new/0","type":"function"},{"doc":"Creates a PointZM from the given coordinate . Examples iex&gt; PointZM . new ( [ 1.5 , - 2.1 , 3 , 4 ] ) % PointZM { coordinate : [ 1.5 , - 2.1 , 3 , 4 ] }","ref":"Geometry.PointZM.html#new/1","title":"Geometry.PointZM.new/1","type":"function"},{"doc":"Creates a PointZM from the given x , y , z , and m . Examples iex&gt; PointZM . new ( - 1.1 , 2.2 , 3 , 4 ) % PointZM { coordinate : [ - 1.1 , 2.2 , 3 , 4 ] }","ref":"Geometry.PointZM.html#new/4","title":"Geometry.PointZM.new/4","type":"function"},{"doc":"Returns the GeoJSON term of a PointZM . Examples iex&gt; PointZM . to_geo_json ( PointZM . new ( 1 , 2 , 3 , 4 ) ) %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1 , 2 , 3 , 4 ] }","ref":"Geometry.PointZM.html#to_geo_json/1","title":"Geometry.PointZM.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a PointZM . With option :srid an EWKB representation with the SRID is returned. The option :endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . Examples iex&gt; PointZM . to_wkb ( PointZM . new ( ) , mode : :hex ) &quot;00C00000017FF80000000000007FF80000000000007FF80000000000007FF8000000000000&quot; iex&gt; PointZM . to_wkb ( PointZM . new ( ) , endian : :ndr , mode : :hex ) &quot;01010000C0000000000000F87F000000000000F87F000000000000F87F000000000000F87F&quot; iex&gt; PointZM . to_wkb ( PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) , endian : :xdr , mode : :hex ) &quot;00C00000013FF199999999999A400199999999999A400A666666666666401199999999999A&quot; iex&gt; PointZM . to_wkb ( PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) , endian : :ndr , mode : :hex ) &quot;01010000C09A9999999999F13F9A999999999901406666666666660A409A99999999991140&quot; iex&gt; PointZM . to_wkb ( PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) , srid : 4711 , endian : :xdr , mode : :hex ) &quot;00E0000001000012673FF199999999999A400199999999999A400A666666666666401199999999999A&quot;","ref":"Geometry.PointZM.html#to_wkb/2","title":"Geometry.PointZM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a PointZM . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; PointZM . to_wkt ( PointZM . new ( ) ) &quot;Point ZM EMPTY&quot; iex&gt; PointZM . to_wkt ( PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) ) &quot;Point ZM (1.1 2.2 3.3 4.4)&quot; iex&gt; PointZM . to_wkt ( PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) , srid : 4711 ) &quot;SRID=4711;Point ZM (1.1 2.2 3.3 4.4)&quot;","ref":"Geometry.PointZM.html#to_wkt/2","title":"Geometry.PointZM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.PointZM.html#t:t/0","title":"Geometry.PointZM.t/0","type":"type"},{"doc":"A polygon struct, representing a 3D polygon. A none empty line-string requires at least one ring with four points.","ref":"Geometry.PolygonZ.html","title":"Geometry.PolygonZ","type":"module"},{"doc":"Returns true if the given PolygonZ is empty. Examples iex&gt; PolygonZ . empty? ( PolygonZ . new ( ) ) true iex&gt; PolygonZ . empty? ( ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 35 , 10 , 13 ) , ...&gt; PointZ . new ( 45 , 45 , 23 ) , ...&gt; PointZ . new ( 10 , 20 , 33 ) , ...&gt; PointZ . new ( 35 , 10 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.PolygonZ.html#empty?/1","title":"Geometry.PolygonZ.empty?/1","type":"function"},{"doc":"Creates a PolygonZ from the given coordinates. Examples iex&gt; PolygonZ . from_coordinates ( [ ...&gt; [ [ 1 , 1 , 1 ] , [ 2 , 1 , 2 ] , [ 2 , 2 , 3 ] , [ 1 , 1 , 1 ] ] ...&gt; ] ) % PolygonZ { rings : [ [ [ 1 , 1 , 1 ] , [ 2 , 1 , 2 ] , [ 2 , 2 , 3 ] , [ 1 , 1 , 1 ] ] ] }","ref":"Geometry.PolygonZ.html#from_coordinates/1","title":"Geometry.PolygonZ.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the PolygonZ from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;Polygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[35, 10, 11], ...&gt; [45, 45, 21], ...&gt; [15, 40, 31], ...&gt; [10, 20, 11], ...&gt; [35, 10, 11]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PolygonZ . from_geo_json ( ) { :ok , % PolygonZ { rings : [ [ [ 35 , 10 , 11 ] , [ 45 , 45 , 21 ] , [ 15 , 40 , 31 ] , [ 10 , 20 , 11 ] , [ 35 , 10 , 11 ] ] ] } } iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;Polygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[35, 10, 11], ...&gt; [45, 45, 21], ...&gt; [15, 40, 31], ...&gt; [10, 20, 11], ...&gt; [35, 10, 11]], ...&gt; [[20, 30, 11], ...&gt; [35, 35, 14], ...&gt; [30, 20, 12], ...&gt; [20, 30, 11]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PolygonZ . from_geo_json ( ) { :ok , % PolygonZ { rings : [ [ [ 35 , 10 , 11 ] , [ 45 , 45 , 21 ] , [ 15 , 40 , 31 ] , [ 10 , 20 , 11 ] , [ 35 , 10 , 11 ] ] , [ [ 20 , 30 , 11 ] , [ 35 , 35 , 14 ] , [ 30 , 20 , 12 ] , [ 20 , 30 , 11 ] ] ] } }","ref":"Geometry.PolygonZ.html#from_geo_json/1","title":"Geometry.PolygonZ.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonZ.html#from_geo_json!/1","title":"Geometry.PolygonZ.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the PolygonZ from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZ.from_wkb/2 function.","ref":"Geometry.PolygonZ.html#from_wkb/2","title":"Geometry.PolygonZ.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonZ.html#from_wkb!/2","title":"Geometry.PolygonZ.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the PolygonZ from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; PolygonZ . from_wkt ( &quot; ...&gt; POLYGON Z ( ...&gt; (35 10 11, 45 45 22, 15 40 33, 10 20 55, 35 10 11), ...&gt; (20 30 22, 35 35 33, 30 20 88, 20 30 22) ...&gt; ) ...&gt; &quot; ) { :ok , % PolygonZ { rings : [ [ [ 35 , 10 , 11 ] , [ 45 , 45 , 22 ] , [ 15 , 40 , 33 ] , [ 10 , 20 , 55 ] , [ 35 , 10 , 11 ] ] , [ [ 20 , 30 , 22 ] , [ 35 , 35 , 33 ] , [ 30 , 20 , 88 ] , [ 20 , 30 , 22 ] ] ] } } iex&gt; &quot; ...&gt; SRID=789; ...&gt; POLYGON Z ( ...&gt; (35 10 11, 45 45 22, 15 40 33, 10 20 55, 35 10 11), ...&gt; (20 30 22, 35 35 33, 30 20 88, 20 30 22) ...&gt; ) ...&gt; &quot; iex&gt; |&gt; PolygonZ . from_wkt ( ) { :ok , { % PolygonZ { rings : [ [ [ 35 , 10 , 11 ] , [ 45 , 45 , 22 ] , [ 15 , 40 , 33 ] , [ 10 , 20 , 55 ] , [ 35 , 10 , 11 ] ] , [ [ 20 , 30 , 22 ] , [ 35 , 35 , 33 ] , [ 30 , 20 , 88 ] , [ 20 , 30 , 22 ] ] ] } , 789 } } iex&gt; PolygonZ . from_wkt ( &quot;Polygon Z EMPTY&quot; ) { :ok , % PolygonZ { } }","ref":"Geometry.PolygonZ.html#from_wkt/1","title":"Geometry.PolygonZ.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonZ.html#from_wkt!/1","title":"Geometry.PolygonZ.from_wkt!/1","type":"function"},{"doc":"Creates an empty PolygonZ . Examples iex&gt; PolygonZ . new ( ) % PolygonZ { rings : [ ] }","ref":"Geometry.PolygonZ.html#new/0","title":"Geometry.PolygonZ.new/0","type":"function"},{"doc":"Creates a PolygonZ from the given rings . Examples iex&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 35 , 10 , 13 ) , ...&gt; PointZ . new ( 45 , 45 , 23 ) , ...&gt; PointZ . new ( 10 , 20 , 33 ) , ...&gt; PointZ . new ( 35 , 10 , 13 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 20 , 30 , 13 ) , ...&gt; PointZ . new ( 35 , 35 , 23 ) , ...&gt; PointZ . new ( 30 , 20 , 33 ) , ...&gt; PointZ . new ( 20 , 30 , 13 ) ...&gt; ] ) ...&gt; ] ) % PolygonZ { rings : [ [ [ 35 , 10 , 13 ] , [ 45 , 45 , 23 ] , [ 10 , 20 , 33 ] , [ 35 , 10 , 13 ] ] , [ [ 20 , 30 , 13 ] , [ 35 , 35 , 23 ] , [ 30 , 20 , 33 ] , [ 20 , 30 , 13 ] ] ] } iex&gt; PolygonZ . new ( ) % PolygonZ { }","ref":"Geometry.PolygonZ.html#new/1","title":"Geometry.PolygonZ.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a PolygonZ . Examples iex&gt; PolygonZ . to_geo_json ( ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 35 , 10 , 13 ) , ...&gt; PointZ . new ( 45 , 45 , 23 ) , ...&gt; PointZ . new ( 10 , 20 , 33 ) , ...&gt; PointZ . new ( 35 , 10 , 13 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 20 , 30 , 13 ) , ...&gt; PointZ . new ( 35 , 35 , 23 ) , ...&gt; PointZ . new ( 30 , 20 , 33 ) , ...&gt; PointZ . new ( 20 , 30 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) %{ &quot;type&quot; =&gt; &quot;Polygon&quot; , &quot;coordinates&quot; =&gt; [ [ [ 35 , 10 , 13 ] , [ 45 , 45 , 23 ] , [ 10 , 20 , 33 ] , [ 35 , 10 , 13 ] ] , [ [ 20 , 30 , 13 ] , [ 35 , 35 , 23 ] , [ 30 , 20 , 33 ] , [ 20 , 30 , 13 ] ] ] }","ref":"Geometry.PolygonZ.html#to_geo_json/1","title":"Geometry.PolygonZ.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a PolygonZ . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZ.to_wkb/1 function.","ref":"Geometry.PolygonZ.html#to_wkb/2","title":"Geometry.PolygonZ.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a PolygonZ . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; PolygonZ . to_wkt ( PolygonZ . new ( ) ) &quot;Polygon Z EMPTY&quot; iex&gt; PolygonZ . to_wkt ( PolygonZ . new ( ) , srid : 1123 ) &quot;SRID=1123;Polygon Z EMPTY&quot; iex&gt; PolygonZ . to_wkt ( ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 35 , 10 , 13 ) , ...&gt; PointZ . new ( 45 , 45 , 23 ) , ...&gt; PointZ . new ( 10 , 20 , 33 ) , ...&gt; PointZ . new ( 35 , 10 , 13 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 20 , 30 , 13 ) , ...&gt; PointZ . new ( 35 , 35 , 23 ) , ...&gt; PointZ . new ( 30 , 20 , 33 ) , ...&gt; PointZ . new ( 20 , 30 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) &quot;Polygon Z ((35 10 13, 45 45 23, 10 20 33, 35 10 13), (20 30 13, 35 35 23, 30 20 33, 20 30 13))&quot;","ref":"Geometry.PolygonZ.html#to_wkt/2","title":"Geometry.PolygonZ.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.PolygonZ.html#t:t/0","title":"Geometry.PolygonZ.t/0","type":"type"},{"doc":"A polygon struct, representing a 3D polygon with a measurement. A none empty line-string requires at least one ring with four points.","ref":"Geometry.PolygonZM.html","title":"Geometry.PolygonZM","type":"module"},{"doc":"Returns true if the given PolygonZM is empty. Examples iex&gt; PolygonZM . empty? ( PolygonZM . new ( ) ) true iex&gt; PolygonZM . empty? ( ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) , ...&gt; PointZM . new ( 45 , 45 , 23 , 24 ) , ...&gt; PointZM . new ( 10 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.PolygonZM.html#empty?/1","title":"Geometry.PolygonZM.empty?/1","type":"function"},{"doc":"Creates a PolygonZM from the given coordinates. Examples iex&gt; PolygonZM . from_coordinates ( [ ...&gt; [ [ 1 , 1 , 1 , 1 ] , [ 2 , 1 , 2 , 3 ] , [ 2 , 2 , 3 , 2 ] , [ 1 , 1 , 1 , 1 ] ] ...&gt; ] ) % PolygonZM { rings : [ [ [ 1 , 1 , 1 , 1 ] , [ 2 , 1 , 2 , 3 ] , [ 2 , 2 , 3 , 2 ] , [ 1 , 1 , 1 , 1 ] ] ] }","ref":"Geometry.PolygonZM.html#from_coordinates/1","title":"Geometry.PolygonZM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the PolygonZM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;Polygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[35, 10, 11, 12], ...&gt; [45, 45, 21, 22], ...&gt; [15, 40, 31, 33], ...&gt; [10, 20, 11, 55], ...&gt; [35, 10, 11, 12]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PolygonZM . from_geo_json ( ) { :ok , % PolygonZM { rings : [ [ [ 35 , 10 , 11 , 12 ] , [ 45 , 45 , 21 , 22 ] , [ 15 , 40 , 31 , 33 ] , [ 10 , 20 , 11 , 55 ] , [ 35 , 10 , 11 , 12 ] ] ] } } iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;Polygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[35, 10, 11, 12], ...&gt; [45, 45, 21, 22], ...&gt; [15, 40, 31, 33], ...&gt; [10, 20, 11, 55], ...&gt; [35, 10, 11, 12]], ...&gt; [[20, 30, 11, 11], ...&gt; [35, 35, 14, 55], ...&gt; [30, 20, 12, 45], ...&gt; [20, 30, 11, 11]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; PolygonZM . from_geo_json ( ) { :ok , % PolygonZM { rings : [ [ [ 35 , 10 , 11 , 12 ] , [ 45 , 45 , 21 , 22 ] , [ 15 , 40 , 31 , 33 ] , [ 10 , 20 , 11 , 55 ] , [ 35 , 10 , 11 , 12 ] ] , [ [ 20 , 30 , 11 , 11 ] , [ 35 , 35 , 14 , 55 ] , [ 30 , 20 , 12 , 45 ] , [ 20 , 30 , 11 , 11 ] ] ] } }","ref":"Geometry.PolygonZM.html#from_geo_json/1","title":"Geometry.PolygonZM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonZM.html#from_geo_json!/1","title":"Geometry.PolygonZM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the PolygonZM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. The optional second argument determines if a :hex -string or a :binary input is expected. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZM.from_wkb/2 function.","ref":"Geometry.PolygonZM.html#from_wkb/2","title":"Geometry.PolygonZM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonZM.html#from_wkb!/2","title":"Geometry.PolygonZM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the PolygonZM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; PolygonZM . from_wkt ( &quot; ...&gt; POLYGON ZM ( ...&gt; (35 10 11 22, 45 45 22 33, 15 40 33 44, 10 20 55 66, 35 10 11 22), ...&gt; (20 30 22 55, 35 35 33 66, 30 20 88 99, 20 30 22 55) ...&gt; ) ...&gt; &quot; ) { :ok , % PolygonZM { rings : [ [ [ 35 , 10 , 11 , 22 ] , [ 45 , 45 , 22 , 33 ] , [ 15 , 40 , 33 , 44 ] , [ 10 , 20 , 55 , 66 ] , [ 35 , 10 , 11 , 22 ] ] , [ [ 20 , 30 , 22 , 55 ] , [ 35 , 35 , 33 , 66 ] , [ 30 , 20 , 88 , 99 ] , [ 20 , 30 , 22 , 55 ] ] ] } } iex&gt; &quot; ...&gt; SRID=789; ...&gt; POLYGON ZM ( ...&gt; (35 10 11 22, 45 45 22 33, 15 40 33 44, 10 20 55 66, 35 10 11 22), ...&gt; (20 30 22 55, 35 35 33 66, 30 20 88 99, 20 30 22 55) ...&gt; ) ...&gt; &quot; iex&gt; |&gt; PolygonZM . from_wkt ( ) { :ok , { % PolygonZM { rings : [ [ [ 35 , 10 , 11 , 22 ] , [ 45 , 45 , 22 , 33 ] , [ 15 , 40 , 33 , 44 ] , [ 10 , 20 , 55 , 66 ] , [ 35 , 10 , 11 , 22 ] ] , [ [ 20 , 30 , 22 , 55 ] , [ 35 , 35 , 33 , 66 ] , [ 30 , 20 , 88 , 99 ] , [ 20 , 30 , 22 , 55 ] ] ] } , 789 } } iex&gt; PolygonZM . from_wkt ( &quot;Polygon ZM EMPTY&quot; ) { :ok , % PolygonZM { } }","ref":"Geometry.PolygonZM.html#from_wkt/1","title":"Geometry.PolygonZM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.PolygonZM.html#from_wkt!/1","title":"Geometry.PolygonZM.from_wkt!/1","type":"function"},{"doc":"Creates an empty PolygonZM . Examples iex&gt; PolygonZM . new ( ) % PolygonZM { rings : [ ] }","ref":"Geometry.PolygonZM.html#new/0","title":"Geometry.PolygonZM.new/0","type":"function"},{"doc":"Creates a PolygonZM from the given rings . Examples iex&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) , ...&gt; PointZM . new ( 45 , 45 , 23 , 24 ) , ...&gt; PointZM . new ( 10 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 20 , 30 , 13 , 14 ) , ...&gt; PointZM . new ( 35 , 35 , 23 , 24 ) , ...&gt; PointZM . new ( 30 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 20 , 30 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) % PolygonZM { rings : [ [ [ 35 , 10 , 13 , 14 ] , [ 45 , 45 , 23 , 24 ] , [ 10 , 20 , 33 , 34 ] , [ 35 , 10 , 13 , 14 ] ] , [ [ 20 , 30 , 13 , 14 ] , [ 35 , 35 , 23 , 24 ] , [ 30 , 20 , 33 , 34 ] , [ 20 , 30 , 13 , 14 ] ] ] } iex&gt; PolygonZM . new ( ) % PolygonZM { }","ref":"Geometry.PolygonZM.html#new/1","title":"Geometry.PolygonZM.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a PolygonZM . Examples iex&gt; PolygonZM . to_geo_json ( ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) , ...&gt; PointZM . new ( 45 , 45 , 23 , 24 ) , ...&gt; PointZM . new ( 10 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 20 , 30 , 13 , 14 ) , ...&gt; PointZM . new ( 35 , 35 , 23 , 24 ) , ...&gt; PointZM . new ( 30 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 20 , 30 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) %{ &quot;type&quot; =&gt; &quot;Polygon&quot; , &quot;coordinates&quot; =&gt; [ [ [ 35 , 10 , 13 , 14 ] , [ 45 , 45 , 23 , 24 ] , [ 10 , 20 , 33 , 34 ] , [ 35 , 10 , 13 , 14 ] ] , [ [ 20 , 30 , 13 , 14 ] , [ 35 , 35 , 23 , 24 ] , [ 30 , 20 , 33 , 34 ] , [ 20 , 30 , 13 , 14 ] ] ] }","ref":"Geometry.PolygonZM.html#to_geo_json/1","title":"Geometry.PolygonZM.to_geo_json/1","type":"function"},{"doc":"Returns the WKB representation for a PolygonZM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZM.to_wkb/1 function.","ref":"Geometry.PolygonZM.html#to_wkb/2","title":"Geometry.PolygonZM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a PolygonZM . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; PolygonZM . to_wkt ( PolygonZM . new ( ) ) &quot;Polygon ZM EMPTY&quot; iex&gt; PolygonZM . to_wkt ( PolygonZM . new ( ) , srid : 1123 ) &quot;SRID=1123;Polygon ZM EMPTY&quot; iex&gt; PolygonZM . to_wkt ( ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) , ...&gt; PointZM . new ( 45 , 45 , 23 , 24 ) , ...&gt; PointZM . new ( 10 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 20 , 30 , 13 , 14 ) , ...&gt; PointZM . new ( 35 , 35 , 23 , 24 ) , ...&gt; PointZM . new ( 30 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 20 , 30 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) &quot;Polygon ZM ((35 10 13 14, 45 45 23 24, 10 20 33 34, 35 10 13 14), (20 30 13 14, 35 35 23 24, 30 20 33 34, 20 30 13 14))&quot;","ref":"Geometry.PolygonZM.html#to_wkt/2","title":"Geometry.PolygonZM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.PolygonZM.html#t:t/0","title":"Geometry.PolygonZM.t/0","type":"type"},{"doc":"A set of line-strings from type Geometry.LineString MultiLineStringMZ implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiLineString . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 1 , 2 ) , ...&gt; Point . new ( 3 , 4 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 1 , 2 ) , ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 13 , 14 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn line_string -&gt; length line_string end ...&gt; ) [ 2 , 3 ] iex&gt; Enum . into ( ...&gt; [ LineString . new ( [ Point . new ( 1 , 2 ) , Point . new ( 5 , 6 ) ] ) ] , ...&gt; MultiLineString . new ( ) ) % MultiLineString { line_strings : MapSet . new ( [ [ [ 1 , 2 ] , [ 5 , 6 ] ] ] ) }","ref":"Geometry.MultiLineString.html","title":"Geometry.MultiLineString","type":"module"},{"doc":"Returns true if the given MultiLineString is empty. Examples iex&gt; MultiLineString . empty? ( MultiLineString . new ( ) ) true iex&gt; MultiLineString . empty? ( ...&gt; MultiLineString . new ( [ ...&gt; LineString . new ( [ Point . new ( 1 , 2 ) , Point . new ( 3 , 4 ) ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiLineString.html#empty?/1","title":"Geometry.MultiLineString.empty?/1","type":"function"},{"doc":"Creates a MultiLineString from the given coordinates. Examples iex&gt; MultiLineString . from_coordinates ( [ ...&gt; [ [ - 1 , 1 ] , [ 2 , 2 ] , [ - 3 , 3 ] ] , ...&gt; [ [ - 10 , 10 ] , [ - 20 , 20 ] ] ...&gt; ] ) % MultiLineString { line_strings : MapSet . new ( [ [ [ - 1 , 1 ] , [ 2 , 2 ] , [ - 3 , 3 ] ] , [ [ - 10 , 10 ] , [ - 20 , 20 ] ] ] ) }","ref":"Geometry.MultiLineString.html#from_coordinates/1","title":"Geometry.MultiLineString.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineString from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiLineString&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[-1, 1], [2, 2], [-3, 3]], ...&gt; [[-10, 10], [-20, 20]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; MultiLineString . from_geo_json ( ) { :ok , % Geometry.MultiLineString { line_strings : MapSet . new ( [ [ [ - 10 , 10 ] , [ - 20 , 20 ] ] , [ [ - 1 , 1 ] , [ 2 , 2 ] , [ - 3 , 3 ] ] ] ) } }","ref":"Geometry.MultiLineString.html#from_geo_json/1","title":"Geometry.MultiLineString.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineString.html#from_geo_json!/1","title":"Geometry.MultiLineString.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineString from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.Point.from_wkb/2 function.","ref":"Geometry.MultiLineString.html#from_wkb/2","title":"Geometry.MultiLineString.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineString.html#from_wkb!/2","title":"Geometry.MultiLineString.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineString from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiLineString . from_wkt ( &quot; ...&gt; SRID=1234;MultiLineString ( ...&gt; (10 20, 20 10, 20 40), ...&gt; (40 30, 30 30) ...&gt; ) ...&gt; &quot; ) { :ok , { % MultiLineString { line_strings : MapSet . new ( [ [ [ 10 , 20 ] , [ 20 , 10 ] , [ 20 , 40 ] ] , [ [ 40 , 30 ] , [ 30 , 30 ] ] ] ) } , 1234 } } iex&gt; MultiLineString . from_wkt ( &quot;MultiLineString EMPTY&quot; ) { :ok , % MultiLineString { } }","ref":"Geometry.MultiLineString.html#from_wkt/1","title":"Geometry.MultiLineString.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineString.html#from_wkt!/1","title":"Geometry.MultiLineString.from_wkt!/1","type":"function"},{"doc":"Checks if MultiLineString contains line_string . Examples iex&gt; MultiLineString . member? ( ...&gt; MultiLineString . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 21 , 22 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 31 , 32 ) , ...&gt; Point . new ( 41 , 42 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 31 , 32 ) , ...&gt; Point . new ( 41 , 42 ) ...&gt; ] ) ...&gt; ) true iex&gt; MultiLineString . member? ( ...&gt; MultiLineString . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 21 , 22 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 31 , 32 ) , ...&gt; Point . new ( 41 , 42 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 41 , 42 ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiLineString.html#member?/2","title":"Geometry.MultiLineString.member?/2","type":"function"},{"doc":"Creates an empty MultiLineString . Examples iex&gt; MultiLineString . new ( ) % MultiLineString { line_strings : MapSet . new ( ) }","ref":"Geometry.MultiLineString.html#new/0","title":"Geometry.MultiLineString.new/0","type":"function"},{"doc":"Creates a MultiLineString from the given Geometry.MultiLineString s. Examples iex&gt; MultiLineString . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 1 , 2 ) , ...&gt; Point . new ( 2 , 3 ) , ...&gt; Point . new ( 3 , 4 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 10 , 20 ) , ...&gt; Point . new ( 30 , 40 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 10 , 20 ) , ...&gt; Point . new ( 30 , 40 ) ...&gt; ] ) ...&gt; ] ) % Geometry.MultiLineString { line_strings : MapSet . new ( [ [ [ 1 , 2 ] , [ 2 , 3 ] , [ 3 , 4 ] ] , [ [ 10 , 20 ] , [ 30 , 40 ] ] ] ) } iex&gt; MultiLineString . new ( [ ] ) % MultiLineString { line_strings : MapSet . new ( ) }","ref":"Geometry.MultiLineString.html#new/1","title":"Geometry.MultiLineString.new/1","type":"function"},{"doc":"Returns the number of elements in MultiLineString . Examples iex&gt; MultiLineString . size ( ...&gt; MultiLineString . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 21 , 22 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 31 , 32 ) , ...&gt; Point . new ( 41 , 42 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.MultiLineString.html#size/1","title":"Geometry.MultiLineString.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiLineString . There are no guarantees about the order of line-strings in the returned coordinates . Examples [ [ [ - 1 , 1 ] , [ 2 , 2 ] , [ - 3 , 3 ] ] , [ [ - 10 , 10 ] , [ - 20 , 20 ] ] ] |&gt; MultiLineString . from_coordinates ( ) MultiLineString . to_geo_json ( MultiLineString . new ( [ LineString . new ( [ Point . new ( - 1 , 1 ) , Point . new ( 2 , 2 ) , Point . new ( - 3 , 3 ) ] ) , LineString . new ( [ Point . new ( - 10 , 10 ) , Point . new ( - 20 , 20 ) ] ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiLineString&quot;, # &quot;coordinates&quot; =&gt; [ # [[-1, 1], [2, 2], [-3, 3]], # [[-10, 10], [-20, 20]] # ] # }","ref":"Geometry.MultiLineString.html#to_geo_json/1","title":"Geometry.MultiLineString.to_geo_json/1","type":"function"},{"doc":"Converts MultiLineString to a list.","ref":"Geometry.MultiLineString.html#to_list/1","title":"Geometry.MultiLineString.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiLineString . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.Point.to_wkb/1 function.","ref":"Geometry.MultiLineString.html#to_wkb/2","title":"Geometry.MultiLineString.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiLineString . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of line-strings in the returned WKT-string. Examples MultiLineString . to_wkt ( MultiLineString . new ( ) ) # =&gt; &quot;MultiLineString EMPTY&quot; MultiLineString . to_wkt ( MultiLineString . new ( [ LineString ( [ Point . new ( 7.1 , 8.1 ) , Point . new ( 9.2 , 5.2 ) ] ) , LineString ( [ Point . new ( 5.5 , 9.2 ) , Point . new ( 1.2 , 3.2 ) ] ) ] ) ) # Returns a string without any \\n or extra spaces (formatted just for readability): # MultiLineString ( # (5.5 9.2, 1.2 3.2), # (7.1 8.1, 9.2 5.2) # ) MultiLineString . to_wkt ( MultiLineString . new ( [ LineString ( [ Point . new ( 7.1 , 8.1 ) , Point . new ( 9.2 , 5.2 ) ] ) , LineString ( [ Point . new ( 5.5 , 9.2 ) , Point . new ( 1.2 , 3.2 ) ] ) ] ) , srid : 555 ) # Returns a string without any \\n or extra spaces (formatted just for readability): # SRID=555;MultiLineString ( # (5.5 9.2, 1.2 3.2), # (7.1 8.1, 9.2 5.2) # )","ref":"Geometry.MultiLineString.html#to_wkt/2","title":"Geometry.MultiLineString.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiLineString.html#t:t/0","title":"Geometry.MultiLineString.t/0","type":"type"},{"doc":"A set of line-strings from type Geometry.LineStringM MultiLineStringMZ implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiLineStringM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 1 , 2 , 4 ) , ...&gt; PointM . new ( 3 , 4 , 6 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 1 , 2 , 4 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 13 , 14 , 16 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn line_string -&gt; length line_string end ...&gt; ) [ 2 , 3 ] iex&gt; Enum . into ( ...&gt; [ LineStringM . new ( [ PointM . new ( 1 , 2 , 4 ) , PointM . new ( 5 , 6 , 8 ) ] ) ] , ...&gt; MultiLineStringM . new ( ) ) % MultiLineStringM { line_strings : MapSet . new ( [ [ [ 1 , 2 , 4 ] , [ 5 , 6 , 8 ] ] ] ) }","ref":"Geometry.MultiLineStringM.html","title":"Geometry.MultiLineStringM","type":"module"},{"doc":"Returns true if the given MultiLineStringM is empty. Examples iex&gt; MultiLineStringM . empty? ( MultiLineStringM . new ( ) ) true iex&gt; MultiLineStringM . empty? ( ...&gt; MultiLineStringM . new ( [ ...&gt; LineStringM . new ( [ PointM . new ( 1 , 2 , 4 ) , PointM . new ( 3 , 4 , 6 ) ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiLineStringM.html#empty?/1","title":"Geometry.MultiLineStringM.empty?/1","type":"function"},{"doc":"Creates a MultiLineStringM from the given coordinates. Examples iex&gt; MultiLineStringM . from_coordinates ( [ ...&gt; [ [ - 1 , 1 , 1 ] , [ 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] , ...&gt; [ [ - 10 , 10 , 10 ] , [ - 20 , 20 , 20 ] ] ...&gt; ] ) % MultiLineStringM { line_strings : MapSet . new ( [ [ [ - 1 , 1 , 1 ] , [ 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] , [ [ - 10 , 10 , 10 ] , [ - 20 , 20 , 20 ] ] ] ) }","ref":"Geometry.MultiLineStringM.html#from_coordinates/1","title":"Geometry.MultiLineStringM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiLineString&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[-1, 1, 1], [2, 2, 2], [-3, 3, 3]], ...&gt; [[-10, 10, 10], [-20, 20, 20]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; MultiLineStringM . from_geo_json ( ) { :ok , % Geometry.MultiLineStringM { line_strings : MapSet . new ( [ [ [ - 10 , 10 , 10 ] , [ - 20 , 20 , 20 ] ] , [ [ - 1 , 1 , 1 ] , [ 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ] ) } }","ref":"Geometry.MultiLineStringM.html#from_geo_json/1","title":"Geometry.MultiLineStringM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringM.html#from_geo_json!/1","title":"Geometry.MultiLineStringM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointM.from_wkb/2 function.","ref":"Geometry.MultiLineStringM.html#from_wkb/2","title":"Geometry.MultiLineStringM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringM.html#from_wkb!/2","title":"Geometry.MultiLineStringM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiLineStringM . from_wkt ( &quot; ...&gt; SRID=1234;MultiLineString M ( ...&gt; (10 20 45, 20 10 15, 20 40 15), ...&gt; (40 30 20, 30 30 30) ...&gt; ) ...&gt; &quot; ) { :ok , { % MultiLineStringM { line_strings : MapSet . new ( [ [ [ 10 , 20 , 45 ] , [ 20 , 10 , 15 ] , [ 20 , 40 , 15 ] ] , [ [ 40 , 30 , 20 ] , [ 30 , 30 , 30 ] ] ] ) } , 1234 } } iex&gt; MultiLineStringM . from_wkt ( &quot;MultiLineString M EMPTY&quot; ) { :ok , % MultiLineStringM { } }","ref":"Geometry.MultiLineStringM.html#from_wkt/1","title":"Geometry.MultiLineStringM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringM.html#from_wkt!/1","title":"Geometry.MultiLineStringM.from_wkt!/1","type":"function"},{"doc":"Checks if MultiLineStringM contains line_string . Examples iex&gt; MultiLineStringM . member? ( ...&gt; MultiLineStringM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 21 , 22 , 24 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 31 , 32 , 34 ) , ...&gt; PointM . new ( 41 , 42 , 44 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 31 , 32 , 34 ) , ...&gt; PointM . new ( 41 , 42 , 44 ) ...&gt; ] ) ...&gt; ) true iex&gt; MultiLineStringM . member? ( ...&gt; MultiLineStringM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 21 , 22 , 24 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 31 , 32 , 34 ) , ...&gt; PointM . new ( 41 , 42 , 44 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 41 , 42 , 44 ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiLineStringM.html#member?/2","title":"Geometry.MultiLineStringM.member?/2","type":"function"},{"doc":"Creates an empty MultiLineStringM . Examples iex&gt; MultiLineStringM . new ( ) % MultiLineStringM { line_strings : MapSet . new ( ) }","ref":"Geometry.MultiLineStringM.html#new/0","title":"Geometry.MultiLineStringM.new/0","type":"function"},{"doc":"Creates a MultiLineStringM from the given Geometry.MultiLineStringM s. Examples iex&gt; MultiLineStringM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 1 , 2 , 4 ) , ...&gt; PointM . new ( 2 , 3 , 5 ) , ...&gt; PointM . new ( 3 , 4 , 6 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 10 , 20 , 40 ) , ...&gt; PointM . new ( 30 , 40 , 60 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 10 , 20 , 40 ) , ...&gt; PointM . new ( 30 , 40 , 60 ) ...&gt; ] ) ...&gt; ] ) % Geometry.MultiLineStringM { line_strings : MapSet . new ( [ [ [ 1 , 2 , 4 ] , [ 2 , 3 , 5 ] , [ 3 , 4 , 6 ] ] , [ [ 10 , 20 , 40 ] , [ 30 , 40 , 60 ] ] ] ) } iex&gt; MultiLineStringM . new ( [ ] ) % MultiLineStringM { line_strings : MapSet . new ( ) }","ref":"Geometry.MultiLineStringM.html#new/1","title":"Geometry.MultiLineStringM.new/1","type":"function"},{"doc":"Returns the number of elements in MultiLineStringM . Examples iex&gt; MultiLineStringM . size ( ...&gt; MultiLineStringM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 21 , 22 , 24 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 31 , 32 , 34 ) , ...&gt; PointM . new ( 41 , 42 , 44 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.MultiLineStringM.html#size/1","title":"Geometry.MultiLineStringM.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiLineStringM . There are no guarantees about the order of line-strings in the returned coordinates . Examples [ [ [ - 1 , 1 , 1 ] , [ 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] , [ [ - 10 , 10 , 10 ] , [ - 20 , 20 , 20 ] ] ] |&gt; MultiLineStringM . from_coordinates ( ) MultiLineStringM . to_geo_json ( MultiLineStringM . new ( [ LineStringM . new ( [ PointM . new ( - 1 , 1 , 1 ) , PointM . new ( 2 , 2 , 2 ) , PointM . new ( - 3 , 3 , 3 ) ] ) , LineStringM . new ( [ PointM . new ( - 10 , 10 , 10 ) , PointM . new ( - 20 , 20 , 20 ) ] ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiLineString&quot;, # &quot;coordinates&quot; =&gt; [ # [[-1, 1, 1], [2, 2, 2], [-3, 3, 3]], # [[-10, 10, 10], [-20, 20, 20]] # ] # }","ref":"Geometry.MultiLineStringM.html#to_geo_json/1","title":"Geometry.MultiLineStringM.to_geo_json/1","type":"function"},{"doc":"Converts MultiLineStringM to a list.","ref":"Geometry.MultiLineStringM.html#to_list/1","title":"Geometry.MultiLineStringM.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiLineStringM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointM.to_wkb/1 function.","ref":"Geometry.MultiLineStringM.html#to_wkb/2","title":"Geometry.MultiLineStringM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiLineStringM . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of line-strings in the returned WKT-string. Examples MultiLineStringM . to_wkt ( MultiLineStringM . new ( ) ) # =&gt; &quot;MultiLineString M EMPTY&quot; MultiLineStringM . to_wkt ( MultiLineStringM . new ( [ LineStringM ( [ PointM . new ( 7.1 , 8.1 , 1 ) , PointM . new ( 9.2 , 5.2 , 2 ) ] ) , LineStringM ( [ PointM . new ( 5.5 , 9.2 , 1 ) , PointM . new ( 1.2 , 3.2 , 2 ) ] ) ] ) ) # Returns a string without any \\n or extra spaces (formatted just for readability): # MultiLineString M ( # (5.5 9.2 1, 1.2 3.2 2), # (7.1 8.1 1, 9.2 5.2 2) # ) MultiLineStringM . to_wkt ( MultiLineStringM . new ( [ LineStringM ( [ PointM . new ( 7.1 , 8.1 , 1 ) , PointM . new ( 9.2 , 5.2 , 2 ) ] ) , LineStringM ( [ PointM . new ( 5.5 , 9.2 , 1 ) , PointM . new ( 1.2 , 3.2 , 2 ) ] ) ] ) , srid : 555 ) # Returns a string without any \\n or extra spaces (formatted just for readability): # SRID=555;MultiLineString M ( # (5.5 9.2 1, 1.2 3.2 2), # (7.1 8.1 1, 9.2 5.2 2) # )","ref":"Geometry.MultiLineStringM.html#to_wkt/2","title":"Geometry.MultiLineStringM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiLineStringM.html#t:t/0","title":"Geometry.MultiLineStringM.t/0","type":"type"},{"doc":"A set of points from type Geometry.Point . MultiPoint implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiPoint . new ( [ ...&gt; Point . new ( 1 , 2 ) , ...&gt; Point . new ( 3 , 4 ) ...&gt; ] ) , ...&gt; fn [ x , _y ] -&gt; x end ...&gt; ) [ 1 , 3 ] iex&gt; Enum . into ( [ Point . new ( 1 , 2 ) ] , MultiPoint . new ( ) ) % MultiPoint { points : MapSet . new ( [ [ 1 , 2 ] ] ) }","ref":"Geometry.MultiPoint.html","title":"Geometry.MultiPoint","type":"module"},{"doc":"Returns true if the given MultiPoint is empty. Examples iex&gt; MultiPoint . empty? ( MultiPoint . new ( ) ) true iex&gt; MultiPoint . empty? ( ...&gt; MultiPoint . new ( ...&gt; [ Point . new ( 1 , 2 ) , Point . new ( 3 , 4 ) ] ...&gt; ) ...&gt; ) false","ref":"Geometry.MultiPoint.html#empty?/1","title":"Geometry.MultiPoint.empty?/1","type":"function"},{"doc":"Creates a MultiPoint from the given coordinates. Examples iex&gt; MultiPoint . from_coordinates ( ...&gt; [ [ - 1 , 1 ] , [ - 2 , 2 ] , [ - 3 , 3 ] ] ...&gt; ) % MultiPoint { points : MapSet . new ( [ [ - 1 , 1 ] , [ - 2 , 2 ] , [ - 3 , 3 ] ] ) } iex&gt; MultiPoint . from_coordinates ( ...&gt; [ [ - 1 , 1 ] , [ - 2 , 2 ] , [ - 3 , 3 ] ] ...&gt; ) % MultiPoint { points : MapSet . new ( [ [ - 1 , 1 ] , [ - 2 , 2 ] , [ - 3 , 3 ] ] ) }","ref":"Geometry.MultiPoint.html#from_coordinates/1","title":"Geometry.MultiPoint.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPoint from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiPoint&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [1.1, 1.2], ...&gt; [20.1, 20.2] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; MultiPoint . from_geo_json ( ) { :ok , % MultiPoint { points : MapSet . new ( [ [ 1.1 , 1.2 ] , [ 20.1 , 20.2 ] ] ) } }","ref":"Geometry.MultiPoint.html#from_geo_json/1","title":"Geometry.MultiPoint.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPoint.html#from_geo_json!/1","title":"Geometry.MultiPoint.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPoint from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.Point.from_wkb/2 function.","ref":"Geometry.MultiPoint.html#from_wkb/2","title":"Geometry.MultiPoint.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPoint.html#from_wkb!/2","title":"Geometry.MultiPoint.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiPoint from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiPoint . from_wkt ( ...&gt; &quot;MultiPoint (-5.1 7.8, 0.1 0.2)&quot; ...&gt; ) { :ok , % MultiPoint { points : MapSet . new ( [ [ - 5.1 , 7.8 ] , [ 0.1 , 0.2 ] ] ) } } iex&gt; MultiPoint . from_wkt ( ...&gt; &quot;SRID=7219;MultiPoint (-5.1 7.8, 0.1 0.2)&quot; ...&gt; ) { :ok , { % MultiPoint { points : MapSet . new ( [ [ - 5.1 , 7.8 ] , [ 0.1 , 0.2 ] ] ) } , 7219 } } iex&gt; MultiPoint . from_wkt ( &quot;MultiPoint EMPTY&quot; ) ...&gt; { :ok , % MultiPoint { } }","ref":"Geometry.MultiPoint.html#from_wkt/1","title":"Geometry.MultiPoint.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPoint.html#from_wkt!/1","title":"Geometry.MultiPoint.from_wkt!/1","type":"function"},{"doc":"Checks if MulitPoint contains point . Examples iex&gt; MultiPoint . member? ( ...&gt; MultiPoint . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 21 , 22 ) ...&gt; ] ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ) true iex&gt; MultiPoint . member? ( ...&gt; MultiPoint . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 21 , 22 ) ...&gt; ] ) , ...&gt; Point . new ( 1 , 2 ) ...&gt; ) false","ref":"Geometry.MultiPoint.html#member?/2","title":"Geometry.MultiPoint.member?/2","type":"function"},{"doc":"Creates an empty MultiPoint . Examples iex&gt; MultiPoint . new ( ) % MultiPoint { points : MapSet . new ( ) }","ref":"Geometry.MultiPoint.html#new/0","title":"Geometry.MultiPoint.new/0","type":"function"},{"doc":"Creates a MultiPoint from the given Geometry.Point s. Examples iex&gt; MultiPoint . new ( [ ...&gt; Point . new ( 1 , 2 ) , ...&gt; Point . new ( 1 , 2 ) , ...&gt; Point . new ( 3 , 4 ) ...&gt; ] ) % MultiPoint { points : MapSet . new ( [ [ 1 , 2 ] , [ 3 , 4 ] ] ) } iex&gt; MultiPoint . new ( [ ] ) % MultiPoint { points : MapSet . new ( ) }","ref":"Geometry.MultiPoint.html#new/1","title":"Geometry.MultiPoint.new/1","type":"function"},{"doc":"Returns the number of elements in MultiPoint . Examples iex&gt; MultiPoint . size ( ...&gt; MultiPoint . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 21 , 22 ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.MultiPoint.html#size/1","title":"Geometry.MultiPoint.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiPoint . There are no guarantees about the order of points in the returned coordinates . Examples MultiPoint . to_geo_json ( MultiPoint . new ( [ Point . new ( - 1.1 , - 2.2 ) , Point . new ( 1.1 , 2.2 ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiPoint&quot;, # &quot;coordinates&quot; =&gt; [ # [-1.1, -2.2], # [1.1, 2.2] # ] # }","ref":"Geometry.MultiPoint.html#to_geo_json/1","title":"Geometry.MultiPoint.to_geo_json/1","type":"function"},{"doc":"Converts MultiPoint to a list. Examples iex&gt; MultiPoint . to_list ( ...&gt; MultiPoint . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 21 , 22 ) ...&gt; ] ) ...&gt; ) [ [ 11 , 12 ] , [ 21 , 22 ] ]","ref":"Geometry.MultiPoint.html#to_list/1","title":"Geometry.MultiPoint.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiPoint . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.Point.to_wkb/1 function.","ref":"Geometry.MultiPoint.html#to_wkb/2","title":"Geometry.MultiPoint.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiPoint . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of points in the returned WKT-string. Examples MultiPoint . to_wkt ( MultiPoint . new ( ) ) # =&gt; &quot;MultiPoint EMPTY&quot; MultiPoint . to_wkt ( MultiPoint . new ( [ Point . new ( 7.1 , 8.1 ) , Point . new ( 9.2 , 5.2 ) ] ) # =&gt; &quot;MultiPoint (7.1 8.1, 9.2 5.2)&quot; MultiPoint . to_wkt ( MultiPoint . new ( [ Point . new ( 7.1 , 8.1 ) , Point . new ( 9.2 , 5.2 ) ] ) , srid : 123 ) # =&gt; &quot;SRID=123;MultiPoint (7.1 8.1, 9.2 5.2)&quot;","ref":"Geometry.MultiPoint.html#to_wkt/2","title":"Geometry.MultiPoint.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiPoint.html#t:t/0","title":"Geometry.MultiPoint.t/0","type":"type"},{"doc":"A set of points from type Geometry.PointM . MultiPointM implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiPointM . new ( [ ...&gt; PointM . new ( 1 , 2 , 4 ) , ...&gt; PointM . new ( 3 , 4 , 6 ) ...&gt; ] ) , ...&gt; fn [ x , _y , _m ] -&gt; x end ...&gt; ) [ 1 , 3 ] iex&gt; Enum . into ( [ PointM . new ( 1 , 2 , 4 ) ] , MultiPointM . new ( ) ) % MultiPointM { points : MapSet . new ( [ [ 1 , 2 , 4 ] ] ) }","ref":"Geometry.MultiPointM.html","title":"Geometry.MultiPointM","type":"module"},{"doc":"Returns true if the given MultiPointM is empty. Examples iex&gt; MultiPointM . empty? ( MultiPointM . new ( ) ) true iex&gt; MultiPointM . empty? ( ...&gt; MultiPointM . new ( ...&gt; [ PointM . new ( 1 , 2 , 4 ) , PointM . new ( 3 , 4 , 6 ) ] ...&gt; ) ...&gt; ) false","ref":"Geometry.MultiPointM.html#empty?/1","title":"Geometry.MultiPointM.empty?/1","type":"function"},{"doc":"Creates a MultiPointM from the given coordinates. Examples iex&gt; MultiPointM . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ...&gt; ) % MultiPointM { points : MapSet . new ( [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ) } iex&gt; MultiPointM . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ...&gt; ) % MultiPointM { points : MapSet . new ( [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ) }","ref":"Geometry.MultiPointM.html#from_coordinates/1","title":"Geometry.MultiPointM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiPoint&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [1.1, 1.2, 1.4], ...&gt; [20.1, 20.2, 20.4] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; MultiPointM . from_geo_json ( ) { :ok , % MultiPointM { points : MapSet . new ( [ [ 1.1 , 1.2 , 1.4 ] , [ 20.1 , 20.2 , 20.4 ] ] ) } }","ref":"Geometry.MultiPointM.html#from_geo_json/1","title":"Geometry.MultiPointM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointM.html#from_geo_json!/1","title":"Geometry.MultiPointM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointM.from_wkb/2 function.","ref":"Geometry.MultiPointM.html#from_wkb/2","title":"Geometry.MultiPointM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointM.html#from_wkb!/2","title":"Geometry.MultiPointM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiPointM . from_wkt ( ...&gt; &quot;MultiPoint M (-5.1 7.8 1, 0.1 0.2 2)&quot; ...&gt; ) { :ok , % MultiPointM { points : MapSet . new ( [ [ - 5.1 , 7.8 , 1 ] , [ 0.1 , 0.2 , 2 ] ] ) } } iex&gt; MultiPointM . from_wkt ( ...&gt; &quot;SRID=7219;MultiPoint M (-5.1 7.8 1, 0.1 0.2 2)&quot; ...&gt; ) { :ok , { % MultiPointM { points : MapSet . new ( [ [ - 5.1 , 7.8 , 1 ] , [ 0.1 , 0.2 , 2 ] ] ) } , 7219 } } iex&gt; MultiPointM . from_wkt ( &quot;MultiPoint M EMPTY&quot; ) ...&gt; { :ok , % MultiPointM { } }","ref":"Geometry.MultiPointM.html#from_wkt/1","title":"Geometry.MultiPointM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointM.html#from_wkt!/1","title":"Geometry.MultiPointM.from_wkt!/1","type":"function"},{"doc":"Checks if MulitPointM contains point . Examples iex&gt; MultiPointM . member? ( ...&gt; MultiPointM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 21 , 22 , 24 ) ...&gt; ] ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ) true iex&gt; MultiPointM . member? ( ...&gt; MultiPointM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 21 , 22 , 24 ) ...&gt; ] ) , ...&gt; PointM . new ( 1 , 2 , 4 ) ...&gt; ) false","ref":"Geometry.MultiPointM.html#member?/2","title":"Geometry.MultiPointM.member?/2","type":"function"},{"doc":"Creates an empty MultiPointM . Examples iex&gt; MultiPointM . new ( ) % MultiPointM { points : MapSet . new ( ) }","ref":"Geometry.MultiPointM.html#new/0","title":"Geometry.MultiPointM.new/0","type":"function"},{"doc":"Creates a MultiPointM from the given Geometry.PointM s. Examples iex&gt; MultiPointM . new ( [ ...&gt; PointM . new ( 1 , 2 , 4 ) , ...&gt; PointM . new ( 1 , 2 , 4 ) , ...&gt; PointM . new ( 3 , 4 , 6 ) ...&gt; ] ) % MultiPointM { points : MapSet . new ( [ [ 1 , 2 , 4 ] , [ 3 , 4 , 6 ] ] ) } iex&gt; MultiPointM . new ( [ ] ) % MultiPointM { points : MapSet . new ( ) }","ref":"Geometry.MultiPointM.html#new/1","title":"Geometry.MultiPointM.new/1","type":"function"},{"doc":"Returns the number of elements in MultiPointM . Examples iex&gt; MultiPointM . size ( ...&gt; MultiPointM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 21 , 22 , 24 ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.MultiPointM.html#size/1","title":"Geometry.MultiPointM.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiPointM . There are no guarantees about the order of points in the returned coordinates . Examples MultiPointM . to_geo_json ( MultiPointM . new ( [ PointM . new ( - 1.1 , - 2.2 , - 4.4 ) , PointM . new ( 1.1 , 2.2 , 4.4 ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiPoint&quot;, # &quot;coordinates&quot; =&gt; [ # [-1.1, -2.2, -4.4], # [1.1, 2.2, 4.4] # ] # }","ref":"Geometry.MultiPointM.html#to_geo_json/1","title":"Geometry.MultiPointM.to_geo_json/1","type":"function"},{"doc":"Converts MultiPointM to a list. Examples iex&gt; MultiPointM . to_list ( ...&gt; MultiPointM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 21 , 22 , 24 ) ...&gt; ] ) ...&gt; ) [ [ 11 , 12 , 14 ] , [ 21 , 22 , 24 ] ]","ref":"Geometry.MultiPointM.html#to_list/1","title":"Geometry.MultiPointM.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiPointM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointM.to_wkb/1 function.","ref":"Geometry.MultiPointM.html#to_wkb/2","title":"Geometry.MultiPointM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiPointM . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of points in the returned WKT-string. Examples MultiPointM . to_wkt ( MultiPointM . new ( ) ) # =&gt; &quot;MultiPoint M EMPTY&quot; MultiPointM . to_wkt ( MultiPointM . new ( [ PointM . new ( 7.1 , 8.1 , 1 ) , PointM . new ( 9.2 , 5.2 , 2 ) ] ) # =&gt; &quot;MultiPoint M (7.1 8.1 1, 9.2 5.2 2)&quot; MultiPointM . to_wkt ( MultiPointM . new ( [ PointM . new ( 7.1 , 8.1 , 1 ) , PointM . new ( 9.2 , 5.2 , 2 ) ] ) , srid : 123 ) # =&gt; &quot;SRID=123;MultiPoint M (7.1 8.1 1, 9.2 5.2 2)&quot;","ref":"Geometry.MultiPointM.html#to_wkt/2","title":"Geometry.MultiPointM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiPointM.html#t:t/0","title":"Geometry.MultiPointM.t/0","type":"type"},{"doc":"A set of polygons from type Geometry.Polygon MultiPoint implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiPolygon . new ( [ ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 11 , 22 ) , ...&gt; Point . new ( 31 , 22 ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) , ...&gt; ] ) , ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 35 , 10 ) , ...&gt; Point . new ( 45 , 45 ) , ...&gt; Point . new ( 10 , 20 ) , ...&gt; Point . new ( 35 , 10 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 20 , 30 ) , ...&gt; Point . new ( 35 , 35 ) , ...&gt; Point . new ( 30 , 20 ) , ...&gt; Point . new ( 20 , 30 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn polygon -&gt; length ( polygon ) == 1 end ...&gt; ) [ true , false ] iex&gt; Enum . into ( ...&gt; [ ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 11 , 22 ) , ...&gt; Point . new ( 31 , 22 ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] , ...&gt; MultiPolygon . new ( ) ) % MultiPolygon { polygons : MapSet . new ( [ [ [ [ 11 , 12 ] , [ 11 , 22 ] , [ 31 , 22 ] , [ 11 , 12 ] ] ] ] ) }","ref":"Geometry.MultiPolygon.html","title":"Geometry.MultiPolygon","type":"module"},{"doc":"Returns true if the given MultiPolygon is empty. Examples iex&gt; MultiPolygon . empty? ( MultiPolygon . new ( ) ) true iex&gt; MultiPolygon . empty? ( ...&gt; MultiPolygon . new ( [ ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 1 , 1 ) , ...&gt; Point . new ( 1 , 5 ) , ...&gt; Point . new ( 5 , 4 ) , ...&gt; Point . new ( 1 , 1 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiPolygon.html#empty?/1","title":"Geometry.MultiPolygon.empty?/1","type":"function"},{"doc":"Creates a MultiPolygon from the given coordinates. Examples iex&gt; MultiPolygon . from_coordinates ( [ ...&gt; [ ...&gt; [ [ 6 , 2 ] , [ 8 , 2 ] , [ 8 , 4 ] , [ 6 , 2 ] ] ...&gt; ] , [ ...&gt; [ [ 1 , 1 ] , [ 9 , 1 ] , [ 9 , 8 ] , [ 1 , 1 ] ] , ...&gt; [ [ 6 , 2 ] , [ 7 , 2 ] , [ 7 , 3 ] , [ 6 , 2 ] ] ...&gt; ] ...&gt; ] ) % MultiPolygon { polygons : MapSet . new ( [ [ [ [ 6 , 2 ] , [ 8 , 2 ] , [ 8 , 4 ] , [ 6 , 2 ] ] , ] , [ [ [ 1 , 1 ] , [ 9 , 1 ] , [ 9 , 8 ] , [ 1 , 1 ] ] , [ [ 6 , 2 ] , [ 7 , 2 ] , [ 7 , 3 ] , [ 6 , 2 ] ] ] ] ) }","ref":"Geometry.MultiPolygon.html#from_coordinates/1","title":"Geometry.MultiPolygon.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygon from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiPolygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [ ...&gt; [[6, 2], [8, 2], [8, 4], [6, 2]] ...&gt; ], [ ...&gt; [[1, 1], [9, 1], [9, 8], [1, 1]], ...&gt; [[6, 2], [7, 2], [7, 3], [6, 2]] ...&gt; ] ...&gt; ] ...&gt; } ...&gt; ) ...&gt; |&gt; Jason . decode! ( ) ...&gt; |&gt; MultiPolygon . from_geo_json ( ) { :ok , % MultiPolygon { polygons : MapSet . new ( [ [ [ [ 1 , 1 ] , [ 9 , 1 ] , [ 9 , 8 ] , [ 1 , 1 ] ] , [ [ 6 , 2 ] , [ 7 , 2 ] , [ 7 , 3 ] , [ 6 , 2 ] ] ] , [ [ [ 6 , 2 ] , [ 8 , 2 ] , [ 8 , 4 ] , [ 6 , 2 ] ] ] ] ) } }","ref":"Geometry.MultiPolygon.html#from_geo_json/1","title":"Geometry.MultiPolygon.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygon.html#from_geo_json!/1","title":"Geometry.MultiPolygon.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygon from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.Point.from_wkb/2 function.","ref":"Geometry.MultiPolygon.html#from_wkb/2","title":"Geometry.MultiPolygon.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygon.html#from_wkb!/2","title":"Geometry.MultiPolygon.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygon from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiPolygon . from_wkt ( &quot; ...&gt; SRID=1234;MULTIPOLYGON ( ...&gt; ( ...&gt; (40 40, 20 45, 45 30, 40 40) ...&gt; ), ( ...&gt; (20 35, 10 30, 10 10, 30 5, 45 20, 20 35), ...&gt; (30 20, 20 15, 20 25, 30 20) ...&gt; ) ...&gt; ) ...&gt; &quot; ) { :ok , { % MultiPolygon { polygons : MapSet . new ( [ [ [ [ 20 , 35 ] , [ 10 , 30 ] , [ 10 , 10 ] , [ 30 , 5 ] , [ 45 , 20 ] , [ 20 , 35 ] ] , [ [ 30 , 20 ] , [ 20 , 15 ] , [ 20 , 25 ] , [ 30 , 20 ] ] ] , [ [ [ 40 , 40 ] , [ 20 , 45 ] , [ 45 , 30 ] , [ 40 , 40 ] ] ] ] ) } , 1234 } } iex&gt; MultiPolygon . from_wkt ( &quot;MultiPolygon EMPTY&quot; ) { :ok , % MultiPolygon { } }","ref":"Geometry.MultiPolygon.html#from_wkt/1","title":"Geometry.MultiPolygon.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygon.html#from_wkt!/1","title":"Geometry.MultiPolygon.from_wkt!/1","type":"function"},{"doc":"Checks if MultiPolygon contains point . Examples iex&gt; MultiPolygon . member? ( ...&gt; MultiPolygon . new ( [ ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 11 , 22 ) , ...&gt; Point . new ( 31 , 22 ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 11 , 22 ) , ...&gt; Point . new ( 31 , 22 ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) true iex&gt; MultiPolygon . member? ( ...&gt; MultiPolygon . new ( [ ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 11 , 22 ) , ...&gt; Point . new ( 31 , 22 ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 11 , 22 ) , ...&gt; Point . new ( 33 , 22 ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiPolygon.html#member?/2","title":"Geometry.MultiPolygon.member?/2","type":"function"},{"doc":"Creates an empty MultiPolygon . Examples iex&gt; MultiPolygon . new ( ) % MultiPolygon { polygons : MapSet . new ( ) }","ref":"Geometry.MultiPolygon.html#new/0","title":"Geometry.MultiPolygon.new/0","type":"function"},{"doc":"Creates a MultiPolygon from the given Geometry.MultiPolygon s. Examples iex&gt; MultiPolygon . new ( [ ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 6 , 2 ) , ...&gt; Point . new ( 8 , 2 ) , ...&gt; Point . new ( 8 , 4 ) , ...&gt; Point . new ( 6 , 2 ) ...&gt; ] ) , ...&gt; ] ) , ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 1 , 1 ) , ...&gt; Point . new ( 9 , 1 ) , ...&gt; Point . new ( 9 , 8 ) , ...&gt; Point . new ( 1 , 1 ) ...&gt; ] ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 6 , 2 ) , ...&gt; Point . new ( 7 , 2 ) , ...&gt; Point . new ( 7 , 3 ) , ...&gt; Point . new ( 6 , 2 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) % MultiPolygon { polygons : MapSet . new ( [ [ [ [ 1 , 1 ] , [ 9 , 1 ] , [ 9 , 8 ] , [ 1 , 1 ] ] , [ [ 6 , 2 ] , [ 7 , 2 ] , [ 7 , 3 ] , [ 6 , 2 ] ] ] , [ [ [ 6 , 2 ] , [ 8 , 2 ] , [ 8 , 4 ] , [ 6 , 2 ] ] ] ] ) } iex&gt; MultiPolygon . new ( [ ] ) % MultiPolygon { }","ref":"Geometry.MultiPolygon.html#new/1","title":"Geometry.MultiPolygon.new/1","type":"function"},{"doc":"Returns the number of elements in MultiPolygon . Examples iex&gt; MultiPolygon . size ( ...&gt; MultiPolygon . new ( [ ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 11 , 22 ) , ...&gt; Point . new ( 31 , 22 ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 1","ref":"Geometry.MultiPolygon.html#size/1","title":"Geometry.MultiPolygon.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiPolygon . There are no guarantees about the order of polygons in the returned coordinates . Examples MultiPolygon . to_list ( MultiPolygon . new ( [ Polygon . new ( [ LineString . new ( [ Point . new ( 111 , 112 ) , Point . new ( 111 , 122 ) , Point . new ( 131 , 122 ) , Point . new ( 111 , 112 ) ] ) ] ) , Polygon . new ( [ LineString . new ( [ Point . new ( 211 , 212 ) , Point . new ( 211 , 222 ) , Point . new ( 231 , 222 ) , Point . new ( 211 , 212 ) ] ) ] ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiPolygon&quot;, # &quot;coordinates&quot; =&gt; [ # [ # [ # [11, 12], # [11, 22], # [31, 22], # [11, 12] # ] # ], [ # [ # [21, 22], # [21, 22], # [21, 22], # [21, 22] # ] # ] # ] # }","ref":"Geometry.MultiPolygon.html#to_geo_json/1","title":"Geometry.MultiPolygon.to_geo_json/1","type":"function"},{"doc":"Converts MultiPolygon to a list. Examples iex&gt; MultiPolygon . to_list ( ...&gt; MultiPolygon . new ( [ ...&gt; Polygon . new ( [ ...&gt; LineString . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; Point . new ( 11 , 22 ) , ...&gt; Point . new ( 31 , 22 ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) [ [ [ [ 11 , 12 ] , [ 11 , 22 ] , [ 31 , 22 ] , [ 11 , 12 ] ] ] ]","ref":"Geometry.MultiPolygon.html#to_list/1","title":"Geometry.MultiPolygon.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiPolygon . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.Point.to_wkb/1 function.","ref":"Geometry.MultiPolygon.html#to_wkb/2","title":"Geometry.MultiPolygon.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiPolygon . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of polygons in the returned WKT-string. Examples MultiPolygon . to_wkt ( MultiPolygon . new ( [ Polygon . new ( [ LineStrinZM . new ( [ Point . new ( 20 , 35 ) , Point . new ( 10 , 30 ) , Point . new ( 10 , 10 ) , Point . new ( 30 , 5 ) , Point . new ( 45 , 20 ) , Point . new ( 20 , 35 ) ] ) , LineString . new ( [ Point . new ( 30 , 20 ) , Point . new ( 20 , 15 ) , Point . new ( 20 , 25 ) , Point . new ( 30 , 20 ) ] ) ] ) , Polygon . new ( [ LineString . new ( [ Point . new ( 40 , 40 ) , Point . new ( 20 , 45 ) , Point . new ( 45 , 30 ) , Point . new ( 40 , 40 ) ] ) ] ) ] ) ) # Returns a string without any \\n or extra spaces (formatted just for readability): # SRID=478;MultiPolygon ( # ( # (20 35, 10 30, 10 10, 30 5, 45 20, 20 35), # (30 20, 20 15, 20 25, 30 20) # ), ( # (40 40, 20 45, 45 30, 40 40) # ) # )","ref":"Geometry.MultiPolygon.html#to_wkt/2","title":"Geometry.MultiPolygon.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiPolygon.html#t:t/0","title":"Geometry.MultiPolygon.t/0","type":"type"},{"doc":"A set of polygons from type Geometry.PolygonM MultiPointM implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiPolygonM . new ( [ ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 11 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 22 , 34 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) , ...&gt; ] ) , ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 35 , 10 , 14 ) , ...&gt; PointM . new ( 45 , 45 , 24 ) , ...&gt; PointM . new ( 10 , 20 , 34 ) , ...&gt; PointM . new ( 35 , 10 , 14 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 20 , 30 , 14 ) , ...&gt; PointM . new ( 35 , 35 , 24 ) , ...&gt; PointM . new ( 30 , 20 , 34 ) , ...&gt; PointM . new ( 20 , 30 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn polygon -&gt; length ( polygon ) == 1 end ...&gt; ) [ true , false ] iex&gt; Enum . into ( ...&gt; [ ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 11 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 22 , 34 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] , ...&gt; MultiPolygonM . new ( ) ) % MultiPolygonM { polygons : MapSet . new ( [ [ [ [ 11 , 12 , 14 ] , [ 11 , 22 , 24 ] , [ 31 , 22 , 34 ] , [ 11 , 12 , 14 ] ] ] ] ) }","ref":"Geometry.MultiPolygonM.html","title":"Geometry.MultiPolygonM","type":"module"},{"doc":"Returns true if the given MultiPolygonM is empty. Examples iex&gt; MultiPolygonM . empty? ( MultiPolygonM . new ( ) ) true iex&gt; MultiPolygonM . empty? ( ...&gt; MultiPolygonM . new ( [ ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 1 , 1 , 4 ) , ...&gt; PointM . new ( 1 , 5 , 8 ) , ...&gt; PointM . new ( 5 , 4 , 6 ) , ...&gt; PointM . new ( 1 , 1 , 4 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiPolygonM.html#empty?/1","title":"Geometry.MultiPolygonM.empty?/1","type":"function"},{"doc":"Creates a MultiPolygonM from the given coordinates. Examples iex&gt; MultiPolygonM . from_coordinates ( [ ...&gt; [ ...&gt; [ [ 6 , 2 , 4 ] , [ 8 , 2 , 5 ] , [ 8 , 4 , 6 ] , [ 6 , 2 , 4 ] ] ...&gt; ] , [ ...&gt; [ [ 1 , 1 , 4 ] , [ 9 , 1 , 5 ] , [ 9 , 8 , 6 ] , [ 1 , 1 , 4 ] ] , ...&gt; [ [ 6 , 2 , 3 ] , [ 7 , 2 , 7 ] , [ 7 , 3 , 4 ] , [ 6 , 2 , 3 ] ] ...&gt; ] ...&gt; ] ) % MultiPolygonM { polygons : MapSet . new ( [ [ [ [ 6 , 2 , 4 ] , [ 8 , 2 , 5 ] , [ 8 , 4 , 6 ] , [ 6 , 2 , 4 ] ] , ] , [ [ [ 1 , 1 , 4 ] , [ 9 , 1 , 5 ] , [ 9 , 8 , 6 ] , [ 1 , 1 , 4 ] ] , [ [ 6 , 2 , 3 ] , [ 7 , 2 , 7 ] , [ 7 , 3 , 4 ] , [ 6 , 2 , 3 ] ] ] ] ) }","ref":"Geometry.MultiPolygonM.html#from_coordinates/1","title":"Geometry.MultiPolygonM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiPolygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [ ...&gt; [[6, 2, 4], [8, 2, 5], [8, 4, 6], [6, 2, 4]] ...&gt; ], [ ...&gt; [[1, 1, 4], [9, 1, 5], [9, 8, 6], [1, 1, 4]], ...&gt; [[6, 2, 3], [7, 2, 7], [7, 3, 4], [6, 2, 3]] ...&gt; ] ...&gt; ] ...&gt; } ...&gt; ) ...&gt; |&gt; Jason . decode! ( ) ...&gt; |&gt; MultiPolygonM . from_geo_json ( ) { :ok , % MultiPolygonM { polygons : MapSet . new ( [ [ [ [ 1 , 1 , 4 ] , [ 9 , 1 , 5 ] , [ 9 , 8 , 6 ] , [ 1 , 1 , 4 ] ] , [ [ 6 , 2 , 3 ] , [ 7 , 2 , 7 ] , [ 7 , 3 , 4 ] , [ 6 , 2 , 3 ] ] ] , [ [ [ 6 , 2 , 4 ] , [ 8 , 2 , 5 ] , [ 8 , 4 , 6 ] , [ 6 , 2 , 4 ] ] ] ] ) } }","ref":"Geometry.MultiPolygonM.html#from_geo_json/1","title":"Geometry.MultiPolygonM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonM.html#from_geo_json!/1","title":"Geometry.MultiPolygonM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointM.from_wkb/2 function.","ref":"Geometry.MultiPolygonM.html#from_wkb/2","title":"Geometry.MultiPolygonM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonM.html#from_wkb!/2","title":"Geometry.MultiPolygonM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiPolygonM . from_wkt ( &quot; ...&gt; SRID=1234;MULTIPOLYGON M ( ...&gt; ( ...&gt; (40 40 20, 20 45 10, 45 30 30, 40 40 20) ...&gt; ), ( ...&gt; (20 35 10, 10 30 20, 10 10 15, 30 5 15, 45 20 16, 20 35 10), ...&gt; (30 20 15, 20 15 10, 20 25 25, 30 20 15) ...&gt; ) ...&gt; ) ...&gt; &quot; ) { :ok , { % MultiPolygonM { polygons : MapSet . new ( [ [ [ [ 20 , 35 , 10 ] , [ 10 , 30 , 20 ] , [ 10 , 10 , 15 ] , [ 30 , 5 , 15 ] , [ 45 , 20 , 16 ] , [ 20 , 35 , 10 ] ] , [ [ 30 , 20 , 15 ] , [ 20 , 15 , 10 ] , [ 20 , 25 , 25 ] , [ 30 , 20 , 15 ] ] ] , [ [ [ 40 , 40 , 20 ] , [ 20 , 45 , 10 ] , [ 45 , 30 , 30 ] , [ 40 , 40 , 20 ] ] ] ] ) } , 1234 } } iex&gt; MultiPolygonM . from_wkt ( &quot;MultiPolygon M EMPTY&quot; ) { :ok , % MultiPolygonM { } }","ref":"Geometry.MultiPolygonM.html#from_wkt/1","title":"Geometry.MultiPolygonM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonM.html#from_wkt!/1","title":"Geometry.MultiPolygonM.from_wkt!/1","type":"function"},{"doc":"Checks if MultiPolygonM contains point . Examples iex&gt; MultiPolygonM . member? ( ...&gt; MultiPolygonM . new ( [ ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 11 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 22 , 34 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 11 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 22 , 34 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) true iex&gt; MultiPolygonM . member? ( ...&gt; MultiPolygonM . new ( [ ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 11 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 22 , 34 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 11 , 22 , 24 ) , ...&gt; PointM . new ( 33 , 22 , 34 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiPolygonM.html#member?/2","title":"Geometry.MultiPolygonM.member?/2","type":"function"},{"doc":"Creates an empty MultiPolygonM . Examples iex&gt; MultiPolygonM . new ( ) % MultiPolygonM { polygons : MapSet . new ( ) }","ref":"Geometry.MultiPolygonM.html#new/0","title":"Geometry.MultiPolygonM.new/0","type":"function"},{"doc":"Creates a MultiPolygonM from the given Geometry.MultiPolygonM s. Examples iex&gt; MultiPolygonM . new ( [ ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 6 , 2 , 4 ) , ...&gt; PointM . new ( 8 , 2 , 5 ) , ...&gt; PointM . new ( 8 , 4 , 6 ) , ...&gt; PointM . new ( 6 , 2 , 4 ) ...&gt; ] ) , ...&gt; ] ) , ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 1 , 1 , 4 ) , ...&gt; PointM . new ( 9 , 1 , 5 ) , ...&gt; PointM . new ( 9 , 8 , 6 ) , ...&gt; PointM . new ( 1 , 1 , 4 ) ...&gt; ] ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 6 , 2 , 4 ) , ...&gt; PointM . new ( 7 , 2 , 5 ) , ...&gt; PointM . new ( 7 , 3 , 6 ) , ...&gt; PointM . new ( 6 , 2 , 4 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) % MultiPolygonM { polygons : MapSet . new ( [ [ [ [ 1 , 1 , 4 ] , [ 9 , 1 , 5 ] , [ 9 , 8 , 6 ] , [ 1 , 1 , 4 ] ] , [ [ 6 , 2 , 4 ] , [ 7 , 2 , 5 ] , [ 7 , 3 , 6 ] , [ 6 , 2 , 4 ] ] ] , [ [ [ 6 , 2 , 4 ] , [ 8 , 2 , 5 ] , [ 8 , 4 , 6 ] , [ 6 , 2 , 4 ] ] ] ] ) } iex&gt; MultiPolygonM . new ( [ ] ) % MultiPolygonM { }","ref":"Geometry.MultiPolygonM.html#new/1","title":"Geometry.MultiPolygonM.new/1","type":"function"},{"doc":"Returns the number of elements in MultiPolygonM . Examples iex&gt; MultiPolygonM . size ( ...&gt; MultiPolygonM . new ( [ ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 11 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 22 , 34 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 1","ref":"Geometry.MultiPolygonM.html#size/1","title":"Geometry.MultiPolygonM.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiPolygonM . There are no guarantees about the order of polygons in the returned coordinates . Examples MultiPolygonM . to_list ( MultiPolygonM . new ( [ PolygonM . new ( [ LineStringM . new ( [ PointM . new ( 111 , 112 , 114 ) , PointM . new ( 111 , 122 , 124 ) , PointM . new ( 131 , 122 , 134 ) , PointM . new ( 111 , 112 , 114 ) ] ) ] ) , PolygonM . new ( [ LineStringM . new ( [ PointM . new ( 211 , 212 , 214 ) , PointM . new ( 211 , 222 , 224 ) , PointM . new ( 231 , 222 , 234 ) , PointM . new ( 211 , 212 , 214 ) ] ) ] ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiPolygon&quot;, # &quot;coordinates&quot; =&gt; [ # [ # [ # [11, 12, 14], # [11, 22, 24], # [31, 22, 34], # [11, 12, 14] # ] # ], [ # [ # [21, 22, 24], # [21, 22, 24], # [21, 22, 24], # [21, 22, 24] # ] # ] # ] # }","ref":"Geometry.MultiPolygonM.html#to_geo_json/1","title":"Geometry.MultiPolygonM.to_geo_json/1","type":"function"},{"doc":"Converts MultiPolygonM to a list. Examples iex&gt; MultiPolygonM . to_list ( ...&gt; MultiPolygonM . new ( [ ...&gt; PolygonM . new ( [ ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; PointM . new ( 11 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 22 , 34 ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) [ [ [ [ 11 , 12 , 14 ] , [ 11 , 22 , 24 ] , [ 31 , 22 , 34 ] , [ 11 , 12 , 14 ] ] ] ]","ref":"Geometry.MultiPolygonM.html#to_list/1","title":"Geometry.MultiPolygonM.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiPolygonM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointM.to_wkb/1 function.","ref":"Geometry.MultiPolygonM.html#to_wkb/2","title":"Geometry.MultiPolygonM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiPolygonM . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of polygons in the returned WKT-string. Examples MultiPolygonM . to_wkt ( MultiPolygonM . new ( [ PolygonM . new ( [ LineStrinZM . new ( [ PointM . new ( 20 , 35 , 10 ) , PointM . new ( 10 , 30 , 20 ) , PointM . new ( 10 , 10 , 15 ) , PointM . new ( 30 , 5 , 15 ) , PointM . new ( 45 , 20 , 16 ) , PointM . new ( 20 , 35 , 10 ) ] ) , LineStringM . new ( [ PointM . new ( 30 , 20 , 15 ) , PointM . new ( 20 , 15 , 10 ) , PointM . new ( 20 , 25 , 25 ) , PointM . new ( 30 , 20 , 15 ) ] ) ] ) , PolygonM . new ( [ LineStringM . new ( [ PointM . new ( 40 , 40 , 20 ) , PointM . new ( 20 , 45 , 10 ) , PointM . new ( 45 , 30 , 30 ) , PointM . new ( 40 , 40 , 20 ) ] ) ] ) ] ) ) # Returns a string without any \\n or extra spaces (formatted just for readability): # SRID=478;MultiPolygon M ( # ( # (20 35 10, 10 30 20, 10 10 15, 30 5 15, 45 20 16, 20 35 10), # (30 20 15, 20 15 10, 20 25 25, 30 20 15) # ), ( # (40 40 20, 20 45 10, 45 30 30, 40 40 20) # ) # )","ref":"Geometry.MultiPolygonM.html#to_wkt/2","title":"Geometry.MultiPolygonM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiPolygonM.html#t:t/0","title":"Geometry.MultiPolygonM.t/0","type":"type"},{"doc":"A set of line-strings from type Geometry.LineStringZ MultiLineStringMZ implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiLineStringZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 1 , 2 , 3 ) , ...&gt; PointZ . new ( 3 , 4 , 5 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 1 , 2 , 3 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 13 , 14 , 15 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn line_string -&gt; length line_string end ...&gt; ) [ 2 , 3 ] iex&gt; Enum . into ( ...&gt; [ LineStringZ . new ( [ PointZ . new ( 1 , 2 , 3 ) , PointZ . new ( 5 , 6 , 7 ) ] ) ] , ...&gt; MultiLineStringZ . new ( ) ) % MultiLineStringZ { line_strings : MapSet . new ( [ [ [ 1 , 2 , 3 ] , [ 5 , 6 , 7 ] ] ] ) }","ref":"Geometry.MultiLineStringZ.html","title":"Geometry.MultiLineStringZ","type":"module"},{"doc":"Returns true if the given MultiLineStringZ is empty. Examples iex&gt; MultiLineStringZ . empty? ( MultiLineStringZ . new ( ) ) true iex&gt; MultiLineStringZ . empty? ( ...&gt; MultiLineStringZ . new ( [ ...&gt; LineStringZ . new ( [ PointZ . new ( 1 , 2 , 3 ) , PointZ . new ( 3 , 4 , 5 ) ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiLineStringZ.html#empty?/1","title":"Geometry.MultiLineStringZ.empty?/1","type":"function"},{"doc":"Creates a MultiLineStringZ from the given coordinates. Examples iex&gt; MultiLineStringZ . from_coordinates ( [ ...&gt; [ [ - 1 , 1 , 1 ] , [ 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] , ...&gt; [ [ - 10 , 10 , 10 ] , [ - 20 , 20 , 20 ] ] ...&gt; ] ) % MultiLineStringZ { line_strings : MapSet . new ( [ [ [ - 1 , 1 , 1 ] , [ 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] , [ [ - 10 , 10 , 10 ] , [ - 20 , 20 , 20 ] ] ] ) }","ref":"Geometry.MultiLineStringZ.html#from_coordinates/1","title":"Geometry.MultiLineStringZ.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringZ from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiLineString&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[-1, 1, 1], [2, 2, 2], [-3, 3, 3]], ...&gt; [[-10, 10, 10], [-20, 20, 20]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; MultiLineStringZ . from_geo_json ( ) { :ok , % Geometry.MultiLineStringZ { line_strings : MapSet . new ( [ [ [ - 10 , 10 , 10 ] , [ - 20 , 20 , 20 ] ] , [ [ - 1 , 1 , 1 ] , [ 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ] ) } }","ref":"Geometry.MultiLineStringZ.html#from_geo_json/1","title":"Geometry.MultiLineStringZ.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringZ.html#from_geo_json!/1","title":"Geometry.MultiLineStringZ.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringZ from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointZ.from_wkb/2 function.","ref":"Geometry.MultiLineStringZ.html#from_wkb/2","title":"Geometry.MultiLineStringZ.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringZ.html#from_wkb!/2","title":"Geometry.MultiLineStringZ.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringZ from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiLineStringZ . from_wkt ( &quot; ...&gt; SRID=1234;MultiLineString Z ( ...&gt; (10 20 10, 20 10 35, 20 40 10), ...&gt; (40 30 10, 30 30 25) ...&gt; ) ...&gt; &quot; ) { :ok , { % MultiLineStringZ { line_strings : MapSet . new ( [ [ [ 10 , 20 , 10 ] , [ 20 , 10 , 35 ] , [ 20 , 40 , 10 ] ] , [ [ 40 , 30 , 10 ] , [ 30 , 30 , 25 ] ] ] ) } , 1234 } } iex&gt; MultiLineStringZ . from_wkt ( &quot;MultiLineString Z EMPTY&quot; ) { :ok , % MultiLineStringZ { } }","ref":"Geometry.MultiLineStringZ.html#from_wkt/1","title":"Geometry.MultiLineStringZ.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringZ.html#from_wkt!/1","title":"Geometry.MultiLineStringZ.from_wkt!/1","type":"function"},{"doc":"Checks if MultiLineStringZ contains line_string . Examples iex&gt; MultiLineStringZ . member? ( ...&gt; MultiLineStringZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 21 , 22 , 23 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 31 , 32 , 33 ) , ...&gt; PointZ . new ( 41 , 42 , 43 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 31 , 32 , 33 ) , ...&gt; PointZ . new ( 41 , 42 , 43 ) ...&gt; ] ) ...&gt; ) true iex&gt; MultiLineStringZ . member? ( ...&gt; MultiLineStringZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 21 , 22 , 23 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 31 , 32 , 33 ) , ...&gt; PointZ . new ( 41 , 42 , 43 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 41 , 42 , 43 ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiLineStringZ.html#member?/2","title":"Geometry.MultiLineStringZ.member?/2","type":"function"},{"doc":"Creates an empty MultiLineStringZ . Examples iex&gt; MultiLineStringZ . new ( ) % MultiLineStringZ { line_strings : MapSet . new ( ) }","ref":"Geometry.MultiLineStringZ.html#new/0","title":"Geometry.MultiLineStringZ.new/0","type":"function"},{"doc":"Creates a MultiLineStringZ from the given Geometry.MultiLineStringZ s. Examples iex&gt; MultiLineStringZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 1 , 2 , 3 ) , ...&gt; PointZ . new ( 2 , 3 , 4 ) , ...&gt; PointZ . new ( 3 , 4 , 5 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 10 , 20 , 30 ) , ...&gt; PointZ . new ( 30 , 40 , 50 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 10 , 20 , 30 ) , ...&gt; PointZ . new ( 30 , 40 , 50 ) ...&gt; ] ) ...&gt; ] ) % Geometry.MultiLineStringZ { line_strings : MapSet . new ( [ [ [ 1 , 2 , 3 ] , [ 2 , 3 , 4 ] , [ 3 , 4 , 5 ] ] , [ [ 10 , 20 , 30 ] , [ 30 , 40 , 50 ] ] ] ) } iex&gt; MultiLineStringZ . new ( [ ] ) % MultiLineStringZ { line_strings : MapSet . new ( ) }","ref":"Geometry.MultiLineStringZ.html#new/1","title":"Geometry.MultiLineStringZ.new/1","type":"function"},{"doc":"Returns the number of elements in MultiLineStringZ . Examples iex&gt; MultiLineStringZ . size ( ...&gt; MultiLineStringZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 21 , 22 , 23 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 31 , 32 , 33 ) , ...&gt; PointZ . new ( 41 , 42 , 43 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.MultiLineStringZ.html#size/1","title":"Geometry.MultiLineStringZ.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiLineStringZ . There are no guarantees about the order of line-strings in the returned coordinates . Examples [ [ [ - 1 , 1 , 1 ] , [ 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] , [ [ - 10 , 10 , 10 ] , [ - 20 , 20 , 20 ] ] ] |&gt; MultiLineStringZ . from_coordinates ( ) MultiLineStringZ . to_geo_json ( MultiLineStringZ . new ( [ LineStringZ . new ( [ PointZ . new ( - 1 , 1 , 1 ) , PointZ . new ( 2 , 2 , 2 ) , PointZ . new ( - 3 , 3 , 3 ) ] ) , LineStringZ . new ( [ PointZ . new ( - 10 , 10 , 10 ) , PointZ . new ( - 20 , 20 , 20 ) ] ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiLineString&quot;, # &quot;coordinates&quot; =&gt; [ # [[-1, 1, 1], [2, 2, 2], [-3, 3, 3]], # [[-10, 10, 10], [-20, 20, 20]] # ] # }","ref":"Geometry.MultiLineStringZ.html#to_geo_json/1","title":"Geometry.MultiLineStringZ.to_geo_json/1","type":"function"},{"doc":"Converts MultiLineStringZ to a list.","ref":"Geometry.MultiLineStringZ.html#to_list/1","title":"Geometry.MultiLineStringZ.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiLineStringZ . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZ.to_wkb/1 function.","ref":"Geometry.MultiLineStringZ.html#to_wkb/2","title":"Geometry.MultiLineStringZ.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiLineStringZ . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of line-strings in the returned WKT-string. Examples MultiLineStringZ . to_wkt ( MultiLineStringZ . new ( ) ) # =&gt; &quot;MultiLineString Z EMPTY&quot; MultiLineStringZ . to_wkt ( MultiLineStringZ . new ( [ LineStringZ ( [ PointZ . new ( 7.1 , 8.1 , 1.1 ) , PointZ . new ( 9.2 , 5.2 , 2.2 ) ] ) , LineStringZ ( [ PointZ . new ( 5.5 , 9.2 , 3.1 ) , PointZ . new ( 1.2 , 3.2 , 4.2 ) ] ) ] ) ) # Returns a string without any \\n or extra spaces (formatted just for readability): # MultiLineString Z ( # (5.5 9.2 3.1, 1.2 3.2 4.2), # (7.1 8.1 1.1, 9.2 5.2 2.2) # ) MultiLineStringZ . to_wkt ( MultiLineStringZ . new ( [ LineStringZ ( [ PointZ . new ( 7.1 , 8.1 , 1.1 ) , PointZ . new ( 9.2 , 5.2 , 2.2 ) ] ) , LineStringZ ( [ PointZ . new ( 5.5 , 9.2 , 3.1 ) , PointZ . new ( 1.2 , 3.2 , 4.2 ) ] ) ] ) , srid : 555 ) # Returns a string without any \\n or extra spaces (formatted just for readability): # SRID=555;MultiLineString Z ( # (5.5 9.2 3.1, 1.2 3.2 4.2), # (7.1 8.1 1.1, 9.2 5.2 2.2) # )","ref":"Geometry.MultiLineStringZ.html#to_wkt/2","title":"Geometry.MultiLineStringZ.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiLineStringZ.html#t:t/0","title":"Geometry.MultiLineStringZ.t/0","type":"type"},{"doc":"A set of line-strings from type Geometry.LineStringZM MultiLineStringMZ implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiLineStringZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) , ...&gt; PointZM . new ( 3 , 4 , 5 , 6 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 13 , 14 , 15 , 16 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn line_string -&gt; length line_string end ...&gt; ) [ 2 , 3 ] iex&gt; Enum . into ( ...&gt; [ LineStringZM . new ( [ PointZM . new ( 1 , 2 , 3 , 4 ) , PointZM . new ( 5 , 6 , 7 , 8 ) ] ) ] , ...&gt; MultiLineStringZM . new ( ) ) % MultiLineStringZM { line_strings : MapSet . new ( [ [ [ 1 , 2 , 3 , 4 ] , [ 5 , 6 , 7 , 8 ] ] ] ) }","ref":"Geometry.MultiLineStringZM.html","title":"Geometry.MultiLineStringZM","type":"module"},{"doc":"Returns true if the given MultiLineStringZM is empty. Examples iex&gt; MultiLineStringZM . empty? ( MultiLineStringZM . new ( ) ) true iex&gt; MultiLineStringZM . empty? ( ...&gt; MultiLineStringZM . new ( [ ...&gt; LineStringZM . new ( [ PointZM . new ( 1 , 2 , 3 , 4 ) , PointZM . new ( 3 , 4 , 5 , 6 ) ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiLineStringZM.html#empty?/1","title":"Geometry.MultiLineStringZM.empty?/1","type":"function"},{"doc":"Creates a MultiLineStringZM from the given coordinates. Examples iex&gt; MultiLineStringZM . from_coordinates ( [ ...&gt; [ [ - 1 , 1 , 1 , 1 ] , [ 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] , ...&gt; [ [ - 10 , 10 , 10 , 10 ] , [ - 20 , 20 , 20 , 20 ] ] ...&gt; ] ) % MultiLineStringZM { line_strings : MapSet . new ( [ [ [ - 1 , 1 , 1 , 1 ] , [ 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] , [ [ - 10 , 10 , 10 , 10 ] , [ - 20 , 20 , 20 , 20 ] ] ] ) }","ref":"Geometry.MultiLineStringZM.html#from_coordinates/1","title":"Geometry.MultiLineStringZM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringZM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiLineString&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [[-1, 1, 1, 1], [2, 2, 2, 2], [-3, 3, 3, 3]], ...&gt; [[-10, 10, 10, 10], [-20, 20, 20, 20]] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; MultiLineStringZM . from_geo_json ( ) { :ok , % Geometry.MultiLineStringZM { line_strings : MapSet . new ( [ [ [ - 10 , 10 , 10 , 10 ] , [ - 20 , 20 , 20 , 20 ] ] , [ [ - 1 , 1 , 1 , 1 ] , [ 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] ] ) } }","ref":"Geometry.MultiLineStringZM.html#from_geo_json/1","title":"Geometry.MultiLineStringZM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringZM.html#from_geo_json!/1","title":"Geometry.MultiLineStringZM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringZM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointZM.from_wkb/2 function.","ref":"Geometry.MultiLineStringZM.html#from_wkb/2","title":"Geometry.MultiLineStringZM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringZM.html#from_wkb!/2","title":"Geometry.MultiLineStringZM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiLineStringZM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiLineStringZM . from_wkt ( &quot; ...&gt; SRID=1234;MultiLineString ZM ( ...&gt; (10 20 10 45, 20 10 35 15, 20 40 10 15), ...&gt; (40 30 10 20, 30 30 25 30) ...&gt; ) ...&gt; &quot; ) { :ok , { % MultiLineStringZM { line_strings : MapSet . new ( [ [ [ 10 , 20 , 10 , 45 ] , [ 20 , 10 , 35 , 15 ] , [ 20 , 40 , 10 , 15 ] ] , [ [ 40 , 30 , 10 , 20 ] , [ 30 , 30 , 25 , 30 ] ] ] ) } , 1234 } } iex&gt; MultiLineStringZM . from_wkt ( &quot;MultiLineString ZM EMPTY&quot; ) { :ok , % MultiLineStringZM { } }","ref":"Geometry.MultiLineStringZM.html#from_wkt/1","title":"Geometry.MultiLineStringZM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiLineStringZM.html#from_wkt!/1","title":"Geometry.MultiLineStringZM.from_wkt!/1","type":"function"},{"doc":"Checks if MultiLineStringZM contains line_string . Examples iex&gt; MultiLineStringZM . member? ( ...&gt; MultiLineStringZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 31 , 32 , 33 , 34 ) , ...&gt; PointZM . new ( 41 , 42 , 43 , 44 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 31 , 32 , 33 , 34 ) , ...&gt; PointZM . new ( 41 , 42 , 43 , 44 ) ...&gt; ] ) ...&gt; ) true iex&gt; MultiLineStringZM . member? ( ...&gt; MultiLineStringZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 31 , 32 , 33 , 34 ) , ...&gt; PointZM . new ( 41 , 42 , 43 , 44 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 41 , 42 , 43 , 44 ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiLineStringZM.html#member?/2","title":"Geometry.MultiLineStringZM.member?/2","type":"function"},{"doc":"Creates an empty MultiLineStringZM . Examples iex&gt; MultiLineStringZM . new ( ) % MultiLineStringZM { line_strings : MapSet . new ( ) }","ref":"Geometry.MultiLineStringZM.html#new/0","title":"Geometry.MultiLineStringZM.new/0","type":"function"},{"doc":"Creates a MultiLineStringZM from the given Geometry.MultiLineStringZM s. Examples iex&gt; MultiLineStringZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) , ...&gt; PointZM . new ( 2 , 3 , 4 , 5 ) , ...&gt; PointZM . new ( 3 , 4 , 5 , 6 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 10 , 20 , 30 , 40 ) , ...&gt; PointZM . new ( 30 , 40 , 50 , 60 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 10 , 20 , 30 , 40 ) , ...&gt; PointZM . new ( 30 , 40 , 50 , 60 ) ...&gt; ] ) ...&gt; ] ) % Geometry.MultiLineStringZM { line_strings : MapSet . new ( [ [ [ 1 , 2 , 3 , 4 ] , [ 2 , 3 , 4 , 5 ] , [ 3 , 4 , 5 , 6 ] ] , [ [ 10 , 20 , 30 , 40 ] , [ 30 , 40 , 50 , 60 ] ] ] ) } iex&gt; MultiLineStringZM . new ( [ ] ) % MultiLineStringZM { line_strings : MapSet . new ( ) }","ref":"Geometry.MultiLineStringZM.html#new/1","title":"Geometry.MultiLineStringZM.new/1","type":"function"},{"doc":"Returns the number of elements in MultiLineStringZM . Examples iex&gt; MultiLineStringZM . size ( ...&gt; MultiLineStringZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 31 , 32 , 33 , 34 ) , ...&gt; PointZM . new ( 41 , 42 , 43 , 44 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.MultiLineStringZM.html#size/1","title":"Geometry.MultiLineStringZM.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiLineStringZM . There are no guarantees about the order of line-strings in the returned coordinates . Examples [ [ [ - 1 , 1 , 1 , 1 ] , [ 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] , [ [ - 10 , 10 , 10 , 10 ] , [ - 20 , 20 , 20 , 20 ] ] ] |&gt; MultiLineStringZM . from_coordinates ( ) MultiLineStringZM . to_geo_json ( MultiLineStringZM . new ( [ LineStringZM . new ( [ PointZM . new ( - 1 , 1 , 1 , 1 ) , PointZM . new ( 2 , 2 , 2 , 2 ) , PointZM . new ( - 3 , 3 , 3 , 3 ) ] ) , LineStringZM . new ( [ PointZM . new ( - 10 , 10 , 10 , 10 ) , PointZM . new ( - 20 , 20 , 20 , 20 ) ] ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiLineString&quot;, # &quot;coordinates&quot; =&gt; [ # [[-1, 1, 1, 1], [2, 2, 2, 2], [-3, 3, 3, 3]], # [[-10, 10, 10, 10], [-20, 20, 20, 20]] # ] # }","ref":"Geometry.MultiLineStringZM.html#to_geo_json/1","title":"Geometry.MultiLineStringZM.to_geo_json/1","type":"function"},{"doc":"Converts MultiLineStringZM to a list.","ref":"Geometry.MultiLineStringZM.html#to_list/1","title":"Geometry.MultiLineStringZM.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiLineStringZM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZM.to_wkb/1 function.","ref":"Geometry.MultiLineStringZM.html#to_wkb/2","title":"Geometry.MultiLineStringZM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiLineStringZM . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of line-strings in the returned WKT-string. Examples MultiLineStringZM . to_wkt ( MultiLineStringZM . new ( ) ) # =&gt; &quot;MultiLineString ZM EMPTY&quot; MultiLineStringZM . to_wkt ( MultiLineStringZM . new ( [ LineStringZM ( [ PointZM . new ( 7.1 , 8.1 , 1.1 , 1 ) , PointZM . new ( 9.2 , 5.2 , 2.2 , 2 ) ] ) , LineStringZM ( [ PointZM . new ( 5.5 , 9.2 , 3.1 , 1 ) , PointZM . new ( 1.2 , 3.2 , 4.2 , 2 ) ] ) ] ) ) # Returns a string without any \\n or extra spaces (formatted just for readability): # MultiLineString ZM ( # (5.5 9.2 3.1 1, 1.2 3.2 4.2 2), # (7.1 8.1 1.1 1, 9.2 5.2 2.2 2) # ) MultiLineStringZM . to_wkt ( MultiLineStringZM . new ( [ LineStringZM ( [ PointZM . new ( 7.1 , 8.1 , 1.1 , 1 ) , PointZM . new ( 9.2 , 5.2 , 2.2 , 2 ) ] ) , LineStringZM ( [ PointZM . new ( 5.5 , 9.2 , 3.1 , 1 ) , PointZM . new ( 1.2 , 3.2 , 4.2 , 2 ) ] ) ] ) , srid : 555 ) # Returns a string without any \\n or extra spaces (formatted just for readability): # SRID=555;MultiLineString ZM ( # (5.5 9.2 3.1 1, 1.2 3.2 4.2 2), # (7.1 8.1 1.1 1, 9.2 5.2 2.2 2) # )","ref":"Geometry.MultiLineStringZM.html#to_wkt/2","title":"Geometry.MultiLineStringZM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiLineStringZM.html#t:t/0","title":"Geometry.MultiLineStringZM.t/0","type":"type"},{"doc":"A set of points from type Geometry.PointZ . MultiPointZ implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiPointZ . new ( [ ...&gt; PointZ . new ( 1 , 2 , 3 ) , ...&gt; PointZ . new ( 3 , 4 , 5 ) ...&gt; ] ) , ...&gt; fn [ x , _y , _z ] -&gt; x end ...&gt; ) [ 1 , 3 ] iex&gt; Enum . into ( [ PointZ . new ( 1 , 2 , 3 ) ] , MultiPointZ . new ( ) ) % MultiPointZ { points : MapSet . new ( [ [ 1 , 2 , 3 ] ] ) }","ref":"Geometry.MultiPointZ.html","title":"Geometry.MultiPointZ","type":"module"},{"doc":"Returns true if the given MultiPointZ is empty. Examples iex&gt; MultiPointZ . empty? ( MultiPointZ . new ( ) ) true iex&gt; MultiPointZ . empty? ( ...&gt; MultiPointZ . new ( ...&gt; [ PointZ . new ( 1 , 2 , 3 ) , PointZ . new ( 3 , 4 , 5 ) ] ...&gt; ) ...&gt; ) false","ref":"Geometry.MultiPointZ.html#empty?/1","title":"Geometry.MultiPointZ.empty?/1","type":"function"},{"doc":"Creates a MultiPointZ from the given coordinates. Examples iex&gt; MultiPointZ . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ...&gt; ) % MultiPointZ { points : MapSet . new ( [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ) } iex&gt; MultiPointZ . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ...&gt; ) % MultiPointZ { points : MapSet . new ( [ [ - 1 , 1 , 1 ] , [ - 2 , 2 , 2 ] , [ - 3 , 3 , 3 ] ] ) }","ref":"Geometry.MultiPointZ.html#from_coordinates/1","title":"Geometry.MultiPointZ.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointZ from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiPoint&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [1.1, 1.2, 1.3], ...&gt; [20.1, 20.2, 20.3] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; MultiPointZ . from_geo_json ( ) { :ok , % MultiPointZ { points : MapSet . new ( [ [ 1.1 , 1.2 , 1.3 ] , [ 20.1 , 20.2 , 20.3 ] ] ) } }","ref":"Geometry.MultiPointZ.html#from_geo_json/1","title":"Geometry.MultiPointZ.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointZ.html#from_geo_json!/1","title":"Geometry.MultiPointZ.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointZ from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointZ.from_wkb/2 function.","ref":"Geometry.MultiPointZ.html#from_wkb/2","title":"Geometry.MultiPointZ.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointZ.html#from_wkb!/2","title":"Geometry.MultiPointZ.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointZ from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiPointZ . from_wkt ( ...&gt; &quot;MultiPoint Z (-5.1 7.8 1.1, 0.1 0.2 2.2)&quot; ...&gt; ) { :ok , % MultiPointZ { points : MapSet . new ( [ [ - 5.1 , 7.8 , 1.1 ] , [ 0.1 , 0.2 , 2.2 ] ] ) } } iex&gt; MultiPointZ . from_wkt ( ...&gt; &quot;SRID=7219;MultiPoint Z (-5.1 7.8 1.1, 0.1 0.2 2.2)&quot; ...&gt; ) { :ok , { % MultiPointZ { points : MapSet . new ( [ [ - 5.1 , 7.8 , 1.1 ] , [ 0.1 , 0.2 , 2.2 ] ] ) } , 7219 } } iex&gt; MultiPointZ . from_wkt ( &quot;MultiPoint Z EMPTY&quot; ) ...&gt; { :ok , % MultiPointZ { } }","ref":"Geometry.MultiPointZ.html#from_wkt/1","title":"Geometry.MultiPointZ.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointZ.html#from_wkt!/1","title":"Geometry.MultiPointZ.from_wkt!/1","type":"function"},{"doc":"Checks if MulitPointZ contains point . Examples iex&gt; MultiPointZ . member? ( ...&gt; MultiPointZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 21 , 22 , 23 ) ...&gt; ] ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ) true iex&gt; MultiPointZ . member? ( ...&gt; MultiPointZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 21 , 22 , 23 ) ...&gt; ] ) , ...&gt; PointZ . new ( 1 , 2 , 3 ) ...&gt; ) false","ref":"Geometry.MultiPointZ.html#member?/2","title":"Geometry.MultiPointZ.member?/2","type":"function"},{"doc":"Creates an empty MultiPointZ . Examples iex&gt; MultiPointZ . new ( ) % MultiPointZ { points : MapSet . new ( ) }","ref":"Geometry.MultiPointZ.html#new/0","title":"Geometry.MultiPointZ.new/0","type":"function"},{"doc":"Creates a MultiPointZ from the given Geometry.PointZ s. Examples iex&gt; MultiPointZ . new ( [ ...&gt; PointZ . new ( 1 , 2 , 3 ) , ...&gt; PointZ . new ( 1 , 2 , 3 ) , ...&gt; PointZ . new ( 3 , 4 , 5 ) ...&gt; ] ) % MultiPointZ { points : MapSet . new ( [ [ 1 , 2 , 3 ] , [ 3 , 4 , 5 ] ] ) } iex&gt; MultiPointZ . new ( [ ] ) % MultiPointZ { points : MapSet . new ( ) }","ref":"Geometry.MultiPointZ.html#new/1","title":"Geometry.MultiPointZ.new/1","type":"function"},{"doc":"Returns the number of elements in MultiPointZ . Examples iex&gt; MultiPointZ . size ( ...&gt; MultiPointZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 21 , 22 , 23 ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.MultiPointZ.html#size/1","title":"Geometry.MultiPointZ.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiPointZ . There are no guarantees about the order of points in the returned coordinates . Examples MultiPointZ . to_geo_json ( MultiPointZ . new ( [ PointZ . new ( - 1.1 , - 2.2 , - 3.3 ) , PointZ . new ( 1.1 , 2.2 , 3.3 ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiPoint&quot;, # &quot;coordinates&quot; =&gt; [ # [-1.1, -2.2, -3.3], # [1.1, 2.2, 3.3] # ] # }","ref":"Geometry.MultiPointZ.html#to_geo_json/1","title":"Geometry.MultiPointZ.to_geo_json/1","type":"function"},{"doc":"Converts MultiPointZ to a list. Examples iex&gt; MultiPointZ . to_list ( ...&gt; MultiPointZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 21 , 22 , 23 ) ...&gt; ] ) ...&gt; ) [ [ 11 , 12 , 13 ] , [ 21 , 22 , 23 ] ]","ref":"Geometry.MultiPointZ.html#to_list/1","title":"Geometry.MultiPointZ.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiPointZ . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZ.to_wkb/1 function.","ref":"Geometry.MultiPointZ.html#to_wkb/2","title":"Geometry.MultiPointZ.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiPointZ . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of points in the returned WKT-string. Examples MultiPointZ . to_wkt ( MultiPointZ . new ( ) ) # =&gt; &quot;MultiPoint Z EMPTY&quot; MultiPointZ . to_wkt ( MultiPointZ . new ( [ PointZ . new ( 7.1 , 8.1 , 1.1 ) , PointZ . new ( 9.2 , 5.2 , 2.2 ) ] ) # =&gt; &quot;MultiPoint Z (7.1 8.1 1.1, 9.2 5.2 2.2)&quot; MultiPointZ . to_wkt ( MultiPointZ . new ( [ PointZ . new ( 7.1 , 8.1 , 1.1 ) , PointZ . new ( 9.2 , 5.2 , 2.2 ) ] ) , srid : 123 ) # =&gt; &quot;SRID=123;MultiPoint Z (7.1 8.1 1.1, 9.2 5.2 2.2)&quot;","ref":"Geometry.MultiPointZ.html#to_wkt/2","title":"Geometry.MultiPointZ.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiPointZ.html#t:t/0","title":"Geometry.MultiPointZ.t/0","type":"type"},{"doc":"A set of points from type Geometry.PointZM . MultiPointZM implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiPointZM . new ( [ ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) , ...&gt; PointZM . new ( 3 , 4 , 5 , 6 ) ...&gt; ] ) , ...&gt; fn [ x , _y , _z , _m ] -&gt; x end ...&gt; ) [ 1 , 3 ] iex&gt; Enum . into ( [ PointZM . new ( 1 , 2 , 3 , 4 ) ] , MultiPointZM . new ( ) ) % MultiPointZM { points : MapSet . new ( [ [ 1 , 2 , 3 , 4 ] ] ) }","ref":"Geometry.MultiPointZM.html","title":"Geometry.MultiPointZM","type":"module"},{"doc":"Returns true if the given MultiPointZM is empty. Examples iex&gt; MultiPointZM . empty? ( MultiPointZM . new ( ) ) true iex&gt; MultiPointZM . empty? ( ...&gt; MultiPointZM . new ( ...&gt; [ PointZM . new ( 1 , 2 , 3 , 4 ) , PointZM . new ( 3 , 4 , 5 , 6 ) ] ...&gt; ) ...&gt; ) false","ref":"Geometry.MultiPointZM.html#empty?/1","title":"Geometry.MultiPointZM.empty?/1","type":"function"},{"doc":"Creates a MultiPointZM from the given coordinates. Examples iex&gt; MultiPointZM . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 , 1 ] , [ - 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] ...&gt; ) % MultiPointZM { points : MapSet . new ( [ [ - 1 , 1 , 1 , 1 ] , [ - 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] ) } iex&gt; MultiPointZM . from_coordinates ( ...&gt; [ [ - 1 , 1 , 1 , 1 ] , [ - 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] ...&gt; ) % MultiPointZM { points : MapSet . new ( [ [ - 1 , 1 , 1 , 1 ] , [ - 2 , 2 , 2 , 2 ] , [ - 3 , 3 , 3 , 3 ] ] ) }","ref":"Geometry.MultiPointZM.html#from_coordinates/1","title":"Geometry.MultiPointZM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointZM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiPoint&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [1.1, 1.2, 1.3, 1.4], ...&gt; [20.1, 20.2, 20.3, 20.4] ...&gt; ] ...&gt; } ...&gt; ) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; MultiPointZM . from_geo_json ( ) { :ok , % MultiPointZM { points : MapSet . new ( [ [ 1.1 , 1.2 , 1.3 , 1.4 ] , [ 20.1 , 20.2 , 20.3 , 20.4 ] ] ) } }","ref":"Geometry.MultiPointZM.html#from_geo_json/1","title":"Geometry.MultiPointZM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointZM.html#from_geo_json!/1","title":"Geometry.MultiPointZM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointZM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointZM.from_wkb/2 function.","ref":"Geometry.MultiPointZM.html#from_wkb/2","title":"Geometry.MultiPointZM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointZM.html#from_wkb!/2","title":"Geometry.MultiPointZM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiPointZM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiPointZM . from_wkt ( ...&gt; &quot;MultiPoint ZM (-5.1 7.8 1.1 1, 0.1 0.2 2.2 2)&quot; ...&gt; ) { :ok , % MultiPointZM { points : MapSet . new ( [ [ - 5.1 , 7.8 , 1.1 , 1 ] , [ 0.1 , 0.2 , 2.2 , 2 ] ] ) } } iex&gt; MultiPointZM . from_wkt ( ...&gt; &quot;SRID=7219;MultiPoint ZM (-5.1 7.8 1.1 1, 0.1 0.2 2.2 2)&quot; ...&gt; ) { :ok , { % MultiPointZM { points : MapSet . new ( [ [ - 5.1 , 7.8 , 1.1 , 1 ] , [ 0.1 , 0.2 , 2.2 , 2 ] ] ) } , 7219 } } iex&gt; MultiPointZM . from_wkt ( &quot;MultiPoint ZM EMPTY&quot; ) ...&gt; { :ok , % MultiPointZM { } }","ref":"Geometry.MultiPointZM.html#from_wkt/1","title":"Geometry.MultiPointZM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPointZM.html#from_wkt!/1","title":"Geometry.MultiPointZM.from_wkt!/1","type":"function"},{"doc":"Checks if MulitPointZM contains point . Examples iex&gt; MultiPointZM . member? ( ...&gt; MultiPointZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) ...&gt; ] ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ) true iex&gt; MultiPointZM . member? ( ...&gt; MultiPointZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) ...&gt; ] ) , ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) ...&gt; ) false","ref":"Geometry.MultiPointZM.html#member?/2","title":"Geometry.MultiPointZM.member?/2","type":"function"},{"doc":"Creates an empty MultiPointZM . Examples iex&gt; MultiPointZM . new ( ) % MultiPointZM { points : MapSet . new ( ) }","ref":"Geometry.MultiPointZM.html#new/0","title":"Geometry.MultiPointZM.new/0","type":"function"},{"doc":"Creates a MultiPointZM from the given Geometry.PointZM s. Examples iex&gt; MultiPointZM . new ( [ ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) , ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) , ...&gt; PointZM . new ( 3 , 4 , 5 , 6 ) ...&gt; ] ) % MultiPointZM { points : MapSet . new ( [ [ 1 , 2 , 3 , 4 ] , [ 3 , 4 , 5 , 6 ] ] ) } iex&gt; MultiPointZM . new ( [ ] ) % MultiPointZM { points : MapSet . new ( ) }","ref":"Geometry.MultiPointZM.html#new/1","title":"Geometry.MultiPointZM.new/1","type":"function"},{"doc":"Returns the number of elements in MultiPointZM . Examples iex&gt; MultiPointZM . size ( ...&gt; MultiPointZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.MultiPointZM.html#size/1","title":"Geometry.MultiPointZM.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiPointZM . There are no guarantees about the order of points in the returned coordinates . Examples MultiPointZM . to_geo_json ( MultiPointZM . new ( [ PointZM . new ( - 1.1 , - 2.2 , - 3.3 , - 4.4 ) , PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiPoint&quot;, # &quot;coordinates&quot; =&gt; [ # [-1.1, -2.2, -3.3, -4.4], # [1.1, 2.2, 3.3, 4.4] # ] # }","ref":"Geometry.MultiPointZM.html#to_geo_json/1","title":"Geometry.MultiPointZM.to_geo_json/1","type":"function"},{"doc":"Converts MultiPointZM to a list. Examples iex&gt; MultiPointZM . to_list ( ...&gt; MultiPointZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) ...&gt; ] ) ...&gt; ) [ [ 11 , 12 , 13 , 14 ] , [ 21 , 22 , 23 , 24 ] ]","ref":"Geometry.MultiPointZM.html#to_list/1","title":"Geometry.MultiPointZM.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiPointZM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZM.to_wkb/1 function.","ref":"Geometry.MultiPointZM.html#to_wkb/2","title":"Geometry.MultiPointZM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiPointZM . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of points in the returned WKT-string. Examples MultiPointZM . to_wkt ( MultiPointZM . new ( ) ) # =&gt; &quot;MultiPoint ZM EMPTY&quot; MultiPointZM . to_wkt ( MultiPointZM . new ( [ PointZM . new ( 7.1 , 8.1 , 1.1 , 1 ) , PointZM . new ( 9.2 , 5.2 , 2.2 , 2 ) ] ) # =&gt; &quot;MultiPoint ZM (7.1 8.1 1.1 1, 9.2 5.2 2.2 2)&quot; MultiPointZM . to_wkt ( MultiPointZM . new ( [ PointZM . new ( 7.1 , 8.1 , 1.1 , 1 ) , PointZM . new ( 9.2 , 5.2 , 2.2 , 2 ) ] ) , srid : 123 ) # =&gt; &quot;SRID=123;MultiPoint ZM (7.1 8.1 1.1 1, 9.2 5.2 2.2 2)&quot;","ref":"Geometry.MultiPointZM.html#to_wkt/2","title":"Geometry.MultiPointZM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiPointZM.html#t:t/0","title":"Geometry.MultiPointZM.t/0","type":"type"},{"doc":"A set of polygons from type Geometry.PolygonZ MultiPointZ implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiPolygonZ . new ( [ ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 11 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 22 , 33 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) , ...&gt; ] ) , ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 35 , 10 , 13 ) , ...&gt; PointZ . new ( 45 , 45 , 23 ) , ...&gt; PointZ . new ( 10 , 20 , 33 ) , ...&gt; PointZ . new ( 35 , 10 , 13 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 20 , 30 , 13 ) , ...&gt; PointZ . new ( 35 , 35 , 23 ) , ...&gt; PointZ . new ( 30 , 20 , 33 ) , ...&gt; PointZ . new ( 20 , 30 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn polygon -&gt; length ( polygon ) == 1 end ...&gt; ) [ true , false ] iex&gt; Enum . into ( ...&gt; [ ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 11 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 22 , 33 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] , ...&gt; MultiPolygonZ . new ( ) ) % MultiPolygonZ { polygons : MapSet . new ( [ [ [ [ 11 , 12 , 13 ] , [ 11 , 22 , 23 ] , [ 31 , 22 , 33 ] , [ 11 , 12 , 13 ] ] ] ] ) }","ref":"Geometry.MultiPolygonZ.html","title":"Geometry.MultiPolygonZ","type":"module"},{"doc":"Returns true if the given MultiPolygonZ is empty. Examples iex&gt; MultiPolygonZ . empty? ( MultiPolygonZ . new ( ) ) true iex&gt; MultiPolygonZ . empty? ( ...&gt; MultiPolygonZ . new ( [ ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 1 , 1 , 3 ) , ...&gt; PointZ . new ( 1 , 5 , 4 ) , ...&gt; PointZ . new ( 5 , 4 , 2 ) , ...&gt; PointZ . new ( 1 , 1 , 3 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiPolygonZ.html#empty?/1","title":"Geometry.MultiPolygonZ.empty?/1","type":"function"},{"doc":"Creates a MultiPolygonZ from the given coordinates. Examples iex&gt; MultiPolygonZ . from_coordinates ( [ ...&gt; [ ...&gt; [ [ 6 , 2 , 3 ] , [ 8 , 2 , 4 ] , [ 8 , 4 , 5 ] , [ 6 , 2 , 3 ] ] ...&gt; ] , [ ...&gt; [ [ 1 , 1 , 3 ] , [ 9 , 1 , 4 ] , [ 9 , 8 , 5 ] , [ 1 , 1 , 3 ] ] , ...&gt; [ [ 6 , 2 , 4 ] , [ 7 , 2 , 6 ] , [ 7 , 3 , 3 ] , [ 6 , 2 , 4 ] ] ...&gt; ] ...&gt; ] ) % MultiPolygonZ { polygons : MapSet . new ( [ [ [ [ 6 , 2 , 3 ] , [ 8 , 2 , 4 ] , [ 8 , 4 , 5 ] , [ 6 , 2 , 3 ] ] , ] , [ [ [ 1 , 1 , 3 ] , [ 9 , 1 , 4 ] , [ 9 , 8 , 5 ] , [ 1 , 1 , 3 ] ] , [ [ 6 , 2 , 4 ] , [ 7 , 2 , 6 ] , [ 7 , 3 , 3 ] , [ 6 , 2 , 4 ] ] ] ] ) }","ref":"Geometry.MultiPolygonZ.html#from_coordinates/1","title":"Geometry.MultiPolygonZ.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonZ from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiPolygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [ ...&gt; [[6, 2, 3], [8, 2, 4], [8, 4, 5], [6, 2, 3]] ...&gt; ], [ ...&gt; [[1, 1, 3], [9, 1, 4], [9, 8, 5], [1, 1, 3]], ...&gt; [[6, 2, 4], [7, 2, 6], [7, 3, 3], [6, 2, 4]] ...&gt; ] ...&gt; ] ...&gt; } ...&gt; ) ...&gt; |&gt; Jason . decode! ( ) ...&gt; |&gt; MultiPolygonZ . from_geo_json ( ) { :ok , % MultiPolygonZ { polygons : MapSet . new ( [ [ [ [ 1 , 1 , 3 ] , [ 9 , 1 , 4 ] , [ 9 , 8 , 5 ] , [ 1 , 1 , 3 ] ] , [ [ 6 , 2 , 4 ] , [ 7 , 2 , 6 ] , [ 7 , 3 , 3 ] , [ 6 , 2 , 4 ] ] ] , [ [ [ 6 , 2 , 3 ] , [ 8 , 2 , 4 ] , [ 8 , 4 , 5 ] , [ 6 , 2 , 3 ] ] ] ] ) } }","ref":"Geometry.MultiPolygonZ.html#from_geo_json/1","title":"Geometry.MultiPolygonZ.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonZ.html#from_geo_json!/1","title":"Geometry.MultiPolygonZ.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonZ from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointZ.from_wkb/2 function.","ref":"Geometry.MultiPolygonZ.html#from_wkb/2","title":"Geometry.MultiPolygonZ.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonZ.html#from_wkb!/2","title":"Geometry.MultiPolygonZ.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonZ from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiPolygonZ . from_wkt ( &quot; ...&gt; SRID=1234;MULTIPOLYGON Z ( ...&gt; ( ...&gt; (40 40 10, 20 45 20, 45 30 15, 40 40 10) ...&gt; ), ( ...&gt; (20 35 20, 10 30 10, 10 10 30, 30 5 10, 45 20 10, 20 35 20), ...&gt; (30 20 10, 20 15 20, 20 25 15, 30 20 10) ...&gt; ) ...&gt; ) ...&gt; &quot; ) { :ok , { % MultiPolygonZ { polygons : MapSet . new ( [ [ [ [ 20 , 35 , 20 ] , [ 10 , 30 , 10 ] , [ 10 , 10 , 30 ] , [ 30 , 5 , 10 ] , [ 45 , 20 , 10 ] , [ 20 , 35 , 20 ] ] , [ [ 30 , 20 , 10 ] , [ 20 , 15 , 20 ] , [ 20 , 25 , 15 ] , [ 30 , 20 , 10 ] ] ] , [ [ [ 40 , 40 , 10 ] , [ 20 , 45 , 20 ] , [ 45 , 30 , 15 ] , [ 40 , 40 , 10 ] ] ] ] ) } , 1234 } } iex&gt; MultiPolygonZ . from_wkt ( &quot;MultiPolygon Z EMPTY&quot; ) { :ok , % MultiPolygonZ { } }","ref":"Geometry.MultiPolygonZ.html#from_wkt/1","title":"Geometry.MultiPolygonZ.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonZ.html#from_wkt!/1","title":"Geometry.MultiPolygonZ.from_wkt!/1","type":"function"},{"doc":"Checks if MultiPolygonZ contains point . Examples iex&gt; MultiPolygonZ . member? ( ...&gt; MultiPolygonZ . new ( [ ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 11 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 22 , 33 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 11 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 22 , 33 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) true iex&gt; MultiPolygonZ . member? ( ...&gt; MultiPolygonZ . new ( [ ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 11 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 22 , 33 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 11 , 22 , 23 ) , ...&gt; PointZ . new ( 33 , 22 , 33 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiPolygonZ.html#member?/2","title":"Geometry.MultiPolygonZ.member?/2","type":"function"},{"doc":"Creates an empty MultiPolygonZ . Examples iex&gt; MultiPolygonZ . new ( ) % MultiPolygonZ { polygons : MapSet . new ( ) }","ref":"Geometry.MultiPolygonZ.html#new/0","title":"Geometry.MultiPolygonZ.new/0","type":"function"},{"doc":"Creates a MultiPolygonZ from the given Geometry.MultiPolygonZ s. Examples iex&gt; MultiPolygonZ . new ( [ ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 6 , 2 , 3 ) , ...&gt; PointZ . new ( 8 , 2 , 4 ) , ...&gt; PointZ . new ( 8 , 4 , 5 ) , ...&gt; PointZ . new ( 6 , 2 , 3 ) ...&gt; ] ) , ...&gt; ] ) , ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 1 , 1 , 3 ) , ...&gt; PointZ . new ( 9 , 1 , 4 ) , ...&gt; PointZ . new ( 9 , 8 , 5 ) , ...&gt; PointZ . new ( 1 , 1 , 3 ) ...&gt; ] ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 6 , 2 , 3 ) , ...&gt; PointZ . new ( 7 , 2 , 4 ) , ...&gt; PointZ . new ( 7 , 3 , 5 ) , ...&gt; PointZ . new ( 6 , 2 , 3 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) % MultiPolygonZ { polygons : MapSet . new ( [ [ [ [ 1 , 1 , 3 ] , [ 9 , 1 , 4 ] , [ 9 , 8 , 5 ] , [ 1 , 1 , 3 ] ] , [ [ 6 , 2 , 3 ] , [ 7 , 2 , 4 ] , [ 7 , 3 , 5 ] , [ 6 , 2 , 3 ] ] ] , [ [ [ 6 , 2 , 3 ] , [ 8 , 2 , 4 ] , [ 8 , 4 , 5 ] , [ 6 , 2 , 3 ] ] ] ] ) } iex&gt; MultiPolygonZ . new ( [ ] ) % MultiPolygonZ { }","ref":"Geometry.MultiPolygonZ.html#new/1","title":"Geometry.MultiPolygonZ.new/1","type":"function"},{"doc":"Returns the number of elements in MultiPolygonZ . Examples iex&gt; MultiPolygonZ . size ( ...&gt; MultiPolygonZ . new ( [ ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 11 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 22 , 33 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 1","ref":"Geometry.MultiPolygonZ.html#size/1","title":"Geometry.MultiPolygonZ.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiPolygonZ . There are no guarantees about the order of polygons in the returned coordinates . Examples MultiPolygonZ . to_list ( MultiPolygonZ . new ( [ PolygonZ . new ( [ LineStringZ . new ( [ PointZ . new ( 111 , 112 , 113 ) , PointZ . new ( 111 , 122 , 123 ) , PointZ . new ( 131 , 122 , 133 ) , PointZ . new ( 111 , 112 , 113 ) ] ) ] ) , PolygonZ . new ( [ LineStringZ . new ( [ PointZ . new ( 211 , 212 , 213 ) , PointZ . new ( 211 , 222 , 223 ) , PointZ . new ( 231 , 222 , 233 ) , PointZ . new ( 211 , 212 , 213 ) ] ) ] ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiPolygon&quot;, # &quot;coordinates&quot; =&gt; [ # [ # [ # [11, 12, 13], # [11, 22, 23], # [31, 22, 33], # [11, 12, 13] # ] # ], [ # [ # [21, 22, 23], # [21, 22, 23], # [21, 22, 23], # [21, 22, 23] # ] # ] # ] # }","ref":"Geometry.MultiPolygonZ.html#to_geo_json/1","title":"Geometry.MultiPolygonZ.to_geo_json/1","type":"function"},{"doc":"Converts MultiPolygonZ to a list. Examples iex&gt; MultiPolygonZ . to_list ( ...&gt; MultiPolygonZ . new ( [ ...&gt; PolygonZ . new ( [ ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; PointZ . new ( 11 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 22 , 33 ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) [ [ [ [ 11 , 12 , 13 ] , [ 11 , 22 , 23 ] , [ 31 , 22 , 33 ] , [ 11 , 12 , 13 ] ] ] ]","ref":"Geometry.MultiPolygonZ.html#to_list/1","title":"Geometry.MultiPolygonZ.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiPolygonZ . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZ.to_wkb/1 function.","ref":"Geometry.MultiPolygonZ.html#to_wkb/2","title":"Geometry.MultiPolygonZ.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiPolygonZ . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of polygons in the returned WKT-string. Examples MultiPolygonZ . to_wkt ( MultiPolygonZ . new ( [ PolygonZ . new ( [ LineStrinZM . new ( [ PointZ . new ( 20 , 35 , 20 ) , PointZ . new ( 10 , 30 , 10 ) , PointZ . new ( 10 , 10 , 30 ) , PointZ . new ( 30 , 5 , 10 ) , PointZ . new ( 45 , 20 , 10 ) , PointZ . new ( 20 , 35 , 20 ) ] ) , LineStringZ . new ( [ PointZ . new ( 30 , 20 , 10 ) , PointZ . new ( 20 , 15 , 20 ) , PointZ . new ( 20 , 25 , 15 ) , PointZ . new ( 30 , 20 , 10 ) ] ) ] ) , PolygonZ . new ( [ LineStringZ . new ( [ PointZ . new ( 40 , 40 , 10 ) , PointZ . new ( 20 , 45 , 20 ) , PointZ . new ( 45 , 30 , 15 ) , PointZ . new ( 40 , 40 , 10 ) ] ) ] ) ] ) ) # Returns a string without any \\n or extra spaces (formatted just for readability): # SRID=478;MultiPolygon Z ( # ( # (20 35 20, 10 30 10, 10 10 30, 30 5 10, 45 20 10, 20 35 20), # (30 20 10, 20 15 20, 20 25 15, 30 20 10) # ), ( # (40 40 10, 20 45 20, 45 30 15, 40 40 10) # ) # )","ref":"Geometry.MultiPolygonZ.html#to_wkt/2","title":"Geometry.MultiPolygonZ.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiPolygonZ.html#t:t/0","title":"Geometry.MultiPolygonZ.t/0","type":"type"},{"doc":"A set of polygons from type Geometry.PolygonZM MultiPointZM implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; MultiPolygonZM . new ( [ ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 11 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 22 , 33 , 34 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) , ...&gt; ] ) , ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) , ...&gt; PointZM . new ( 45 , 45 , 23 , 24 ) , ...&gt; PointZM . new ( 10 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 35 , 10 , 13 , 14 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 20 , 30 , 13 , 14 ) , ...&gt; PointZM . new ( 35 , 35 , 23 , 24 ) , ...&gt; PointZM . new ( 30 , 20 , 33 , 34 ) , ...&gt; PointZM . new ( 20 , 30 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn polygon -&gt; length ( polygon ) == 1 end ...&gt; ) [ true , false ] iex&gt; Enum . into ( ...&gt; [ ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 11 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 22 , 33 , 34 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] , ...&gt; MultiPolygonZM . new ( ) ) % MultiPolygonZM { polygons : MapSet . new ( [ [ [ [ 11 , 12 , 13 , 14 ] , [ 11 , 22 , 23 , 24 ] , [ 31 , 22 , 33 , 34 ] , [ 11 , 12 , 13 , 14 ] ] ] ] ) }","ref":"Geometry.MultiPolygonZM.html","title":"Geometry.MultiPolygonZM","type":"module"},{"doc":"Returns true if the given MultiPolygonZM is empty. Examples iex&gt; MultiPolygonZM . empty? ( MultiPolygonZM . new ( ) ) true iex&gt; MultiPolygonZM . empty? ( ...&gt; MultiPolygonZM . new ( [ ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 1 , 1 , 3 , 4 ) , ...&gt; PointZM . new ( 1 , 5 , 4 , 8 ) , ...&gt; PointZM . new ( 5 , 4 , 2 , 6 ) , ...&gt; PointZM . new ( 1 , 1 , 3 , 4 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiPolygonZM.html#empty?/1","title":"Geometry.MultiPolygonZM.empty?/1","type":"function"},{"doc":"Creates a MultiPolygonZM from the given coordinates. Examples iex&gt; MultiPolygonZM . from_coordinates ( [ ...&gt; [ ...&gt; [ [ 6 , 2 , 3 , 4 ] , [ 8 , 2 , 4 , 5 ] , [ 8 , 4 , 5 , 6 ] , [ 6 , 2 , 3 , 4 ] ] ...&gt; ] , [ ...&gt; [ [ 1 , 1 , 3 , 4 ] , [ 9 , 1 , 4 , 5 ] , [ 9 , 8 , 5 , 6 ] , [ 1 , 1 , 3 , 4 ] ] , ...&gt; [ [ 6 , 2 , 4 , 3 ] , [ 7 , 2 , 6 , 7 ] , [ 7 , 3 , 3 , 4 ] , [ 6 , 2 , 4 , 3 ] ] ...&gt; ] ...&gt; ] ) % MultiPolygonZM { polygons : MapSet . new ( [ [ [ [ 6 , 2 , 3 , 4 ] , [ 8 , 2 , 4 , 5 ] , [ 8 , 4 , 5 , 6 ] , [ 6 , 2 , 3 , 4 ] ] , ] , [ [ [ 1 , 1 , 3 , 4 ] , [ 9 , 1 , 4 , 5 ] , [ 9 , 8 , 5 , 6 ] , [ 1 , 1 , 3 , 4 ] ] , [ [ 6 , 2 , 4 , 3 ] , [ 7 , 2 , 6 , 7 ] , [ 7 , 3 , 3 , 4 ] , [ 6 , 2 , 4 , 3 ] ] ] ] ) }","ref":"Geometry.MultiPolygonZM.html#from_coordinates/1","title":"Geometry.MultiPolygonZM.from_coordinates/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonZM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s( ...&gt; { ...&gt; &quot;type&quot;: &quot;MultiPolygon&quot;, ...&gt; &quot;coordinates&quot;: [ ...&gt; [ ...&gt; [[6, 2, 3, 4], [8, 2, 4, 5], [8, 4, 5, 6], [6, 2, 3, 4]] ...&gt; ], [ ...&gt; [[1, 1, 3, 4], [9, 1, 4, 5], [9, 8, 5, 6], [1, 1, 3, 4]], ...&gt; [[6, 2, 4, 3], [7, 2, 6, 7], [7, 3, 3, 4], [6, 2, 4, 3]] ...&gt; ] ...&gt; ] ...&gt; } ...&gt; ) ...&gt; |&gt; Jason . decode! ( ) ...&gt; |&gt; MultiPolygonZM . from_geo_json ( ) { :ok , % MultiPolygonZM { polygons : MapSet . new ( [ [ [ [ 1 , 1 , 3 , 4 ] , [ 9 , 1 , 4 , 5 ] , [ 9 , 8 , 5 , 6 ] , [ 1 , 1 , 3 , 4 ] ] , [ [ 6 , 2 , 4 , 3 ] , [ 7 , 2 , 6 , 7 ] , [ 7 , 3 , 3 , 4 ] , [ 6 , 2 , 4 , 3 ] ] ] , [ [ [ 6 , 2 , 3 , 4 ] , [ 8 , 2 , 4 , 5 ] , [ 8 , 4 , 5 , 6 ] , [ 6 , 2 , 3 , 4 ] ] ] ] ) } }","ref":"Geometry.MultiPolygonZM.html#from_geo_json/1","title":"Geometry.MultiPolygonZM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonZM.html#from_geo_json!/1","title":"Geometry.MultiPolygonZM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonZM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointZM.from_wkb/2 function.","ref":"Geometry.MultiPolygonZM.html#from_wkb/2","title":"Geometry.MultiPolygonZM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonZM.html#from_wkb!/2","title":"Geometry.MultiPolygonZM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the MultiPolygonZM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; MultiPolygonZM . from_wkt ( &quot; ...&gt; SRID=1234;MULTIPOLYGON ZM ( ...&gt; ( ...&gt; (40 40 10 20, 20 45 20 10, 45 30 15 30, 40 40 10 20) ...&gt; ), ( ...&gt; (20 35 20 10, 10 30 10 20, 10 10 30 15, 30 5 10 15, 45 20 10 16, 20 35 20 10), ...&gt; (30 20 10 15, 20 15 20 10, 20 25 15 25, 30 20 10 15) ...&gt; ) ...&gt; ) ...&gt; &quot; ) { :ok , { % MultiPolygonZM { polygons : MapSet . new ( [ [ [ [ 20 , 35 , 20 , 10 ] , [ 10 , 30 , 10 , 20 ] , [ 10 , 10 , 30 , 15 ] , [ 30 , 5 , 10 , 15 ] , [ 45 , 20 , 10 , 16 ] , [ 20 , 35 , 20 , 10 ] ] , [ [ 30 , 20 , 10 , 15 ] , [ 20 , 15 , 20 , 10 ] , [ 20 , 25 , 15 , 25 ] , [ 30 , 20 , 10 , 15 ] ] ] , [ [ [ 40 , 40 , 10 , 20 ] , [ 20 , 45 , 20 , 10 ] , [ 45 , 30 , 15 , 30 ] , [ 40 , 40 , 10 , 20 ] ] ] ] ) } , 1234 } } iex&gt; MultiPolygonZM . from_wkt ( &quot;MultiPolygon ZM EMPTY&quot; ) { :ok , % MultiPolygonZM { } }","ref":"Geometry.MultiPolygonZM.html#from_wkt/1","title":"Geometry.MultiPolygonZM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.MultiPolygonZM.html#from_wkt!/1","title":"Geometry.MultiPolygonZM.from_wkt!/1","type":"function"},{"doc":"Checks if MultiPolygonZM contains point . Examples iex&gt; MultiPolygonZM . member? ( ...&gt; MultiPolygonZM . new ( [ ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 11 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 22 , 33 , 34 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 11 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 22 , 33 , 34 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) true iex&gt; MultiPolygonZM . member? ( ...&gt; MultiPolygonZM . new ( [ ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 11 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 22 , 33 , 34 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 11 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 33 , 22 , 33 , 34 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) false","ref":"Geometry.MultiPolygonZM.html#member?/2","title":"Geometry.MultiPolygonZM.member?/2","type":"function"},{"doc":"Creates an empty MultiPolygonZM . Examples iex&gt; MultiPolygonZM . new ( ) % MultiPolygonZM { polygons : MapSet . new ( ) }","ref":"Geometry.MultiPolygonZM.html#new/0","title":"Geometry.MultiPolygonZM.new/0","type":"function"},{"doc":"Creates a MultiPolygonZM from the given Geometry.MultiPolygonZM s. Examples iex&gt; MultiPolygonZM . new ( [ ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 6 , 2 , 3 , 4 ) , ...&gt; PointZM . new ( 8 , 2 , 4 , 5 ) , ...&gt; PointZM . new ( 8 , 4 , 5 , 6 ) , ...&gt; PointZM . new ( 6 , 2 , 3 , 4 ) ...&gt; ] ) , ...&gt; ] ) , ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 1 , 1 , 3 , 4 ) , ...&gt; PointZM . new ( 9 , 1 , 4 , 5 ) , ...&gt; PointZM . new ( 9 , 8 , 5 , 6 ) , ...&gt; PointZM . new ( 1 , 1 , 3 , 4 ) ...&gt; ] ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 6 , 2 , 3 , 4 ) , ...&gt; PointZM . new ( 7 , 2 , 4 , 5 ) , ...&gt; PointZM . new ( 7 , 3 , 5 , 6 ) , ...&gt; PointZM . new ( 6 , 2 , 3 , 4 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) % MultiPolygonZM { polygons : MapSet . new ( [ [ [ [ 1 , 1 , 3 , 4 ] , [ 9 , 1 , 4 , 5 ] , [ 9 , 8 , 5 , 6 ] , [ 1 , 1 , 3 , 4 ] ] , [ [ 6 , 2 , 3 , 4 ] , [ 7 , 2 , 4 , 5 ] , [ 7 , 3 , 5 , 6 ] , [ 6 , 2 , 3 , 4 ] ] ] , [ [ [ 6 , 2 , 3 , 4 ] , [ 8 , 2 , 4 , 5 ] , [ 8 , 4 , 5 , 6 ] , [ 6 , 2 , 3 , 4 ] ] ] ] ) } iex&gt; MultiPolygonZM . new ( [ ] ) % MultiPolygonZM { }","ref":"Geometry.MultiPolygonZM.html#new/1","title":"Geometry.MultiPolygonZM.new/1","type":"function"},{"doc":"Returns the number of elements in MultiPolygonZM . Examples iex&gt; MultiPolygonZM . size ( ...&gt; MultiPolygonZM . new ( [ ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 11 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 22 , 33 , 34 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 1","ref":"Geometry.MultiPolygonZM.html#size/1","title":"Geometry.MultiPolygonZM.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a MultiPolygonZM . There are no guarantees about the order of polygons in the returned coordinates . Examples MultiPolygonZM . to_list ( MultiPolygonZM . new ( [ PolygonZM . new ( [ LineStringZM . new ( [ PointZM . new ( 111 , 112 , 113 , 114 ) , PointZM . new ( 111 , 122 , 123 , 124 ) , PointZM . new ( 131 , 122 , 133 , 134 ) , PointZM . new ( 111 , 112 , 113 , 114 ) ] ) ] ) , PolygonZM . new ( [ LineStringZM . new ( [ PointZM . new ( 211 , 212 , 213 , 214 ) , PointZM . new ( 211 , 222 , 223 , 224 ) , PointZM . new ( 231 , 222 , 233 , 234 ) , PointZM . new ( 211 , 212 , 213 , 214 ) ] ) ] ) ] ) ) # =&gt; # %{ # &quot;type&quot; =&gt; &quot;MultiPolygon&quot;, # &quot;coordinates&quot; =&gt; [ # [ # [ # [11, 12, 13, 14], # [11, 22, 23, 24], # [31, 22, 33, 34], # [11, 12, 13, 14] # ] # ], [ # [ # [21, 22, 23, 24], # [21, 22, 23, 24], # [21, 22, 23, 24], # [21, 22, 23, 24] # ] # ] # ] # }","ref":"Geometry.MultiPolygonZM.html#to_geo_json/1","title":"Geometry.MultiPolygonZM.to_geo_json/1","type":"function"},{"doc":"Converts MultiPolygonZM to a list. Examples iex&gt; MultiPolygonZM . to_list ( ...&gt; MultiPolygonZM . new ( [ ...&gt; PolygonZM . new ( [ ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; PointZM . new ( 11 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 22 , 33 , 34 ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) [ [ [ [ 11 , 12 , 13 , 14 ] , [ 11 , 22 , 23 , 24 ] , [ 31 , 22 , 33 , 34 ] , [ 11 , 12 , 13 , 14 ] ] ] ]","ref":"Geometry.MultiPolygonZM.html#to_list/1","title":"Geometry.MultiPolygonZM.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a MultiPolygonZM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :xdr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZM.to_wkb/1 function.","ref":"Geometry.MultiPolygonZM.html#to_wkb/2","title":"Geometry.MultiPolygonZM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a MultiPolygonZM . With option :srid an EWKT representation with the SRID is returned. There are no guarantees about the order of polygons in the returned WKT-string. Examples MultiPolygonZM . to_wkt ( MultiPolygonZM . new ( [ PolygonZM . new ( [ LineStrinZM . new ( [ PointZM . new ( 20 , 35 , 20 , 10 ) , PointZM . new ( 10 , 30 , 10 , 20 ) , PointZM . new ( 10 , 10 , 30 , 15 ) , PointZM . new ( 30 , 5 , 10 , 15 ) , PointZM . new ( 45 , 20 , 10 , 16 ) , PointZM . new ( 20 , 35 , 20 , 10 ) ] ) , LineStringZM . new ( [ PointZM . new ( 30 , 20 , 10 , 15 ) , PointZM . new ( 20 , 15 , 20 , 10 ) , PointZM . new ( 20 , 25 , 15 , 25 ) , PointZM . new ( 30 , 20 , 10 , 15 ) ] ) ] ) , PolygonZM . new ( [ LineStringZM . new ( [ PointZM . new ( 40 , 40 , 10 , 20 ) , PointZM . new ( 20 , 45 , 20 , 10 ) , PointZM . new ( 45 , 30 , 15 , 30 ) , PointZM . new ( 40 , 40 , 10 , 20 ) ] ) ] ) ] ) ) # Returns a string without any \\n or extra spaces (formatted just for readability): # SRID=478;MultiPolygon ZM ( # ( # (20 35 20 10, 10 30 10 20, 10 10 30 15, 30 5 10 15, 45 20 10 16, 20 35 20 10), # (30 20 10 15, 20 15 20 10, 20 25 15 25, 30 20 10 15) # ), ( # (40 40 10 20, 20 45 20 10, 45 30 15 30, 40 40 10 20) # ) # )","ref":"Geometry.MultiPolygonZM.html#to_wkt/2","title":"Geometry.MultiPolygonZM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.MultiPolygonZM.html#t:t/0","title":"Geometry.MultiPolygonZM.t/0","type":"type"},{"doc":"A collection set of 2D geometries. GeometryCollection implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; GeometryCollection . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 21 , 22 ) , ...&gt; Point . new ( 31 , 32 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn ...&gt; % Point { } -&gt; :point ...&gt; % LineString { } -&gt; :line_string ...&gt; end ...&gt; ) |&gt; Enum . sort ( ) [ :line_string , :point ] iex&gt; Enum . into ( [ Point . new ( 1 , 2 ) ] , GeometryCollection . new ( ) ) % GeometryCollection { geometries : MapSet . new ( [ % Point { coordinate : [ 1 , 2 ] } ] ) }","ref":"Geometry.GeometryCollection.html","title":"Geometry.GeometryCollection","type":"module"},{"doc":"Returns true if the given GeometryCollection is empty. Examples iex&gt; GeometryCollection . empty? ( GeometryCollection . new ( ) ) true iex&gt; GeometryCollection . empty? ( GeometryCollection . new ( [ Point . new ( 1 , 2 ) ] ) ) false","ref":"Geometry.GeometryCollection.html#empty?/1","title":"Geometry.GeometryCollection.empty?/1","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollection from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;GeometryCollection&quot;, ...&gt; &quot;geometries&quot;: [ ...&gt; {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1.1, 2.2]} ...&gt; ] ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; GeometryCollection . from_geo_json ( ) { :ok , % GeometryCollection { geometries : MapSet . new ( [ % Point { coordinate : [ 1.1 , 2.2 ] } ] ) } }","ref":"Geometry.GeometryCollection.html#from_geo_json/1","title":"Geometry.GeometryCollection.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollection.html#from_geo_json!/1","title":"Geometry.GeometryCollection.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollection from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.Point.from_wkb/2 function.","ref":"Geometry.GeometryCollection.html#from_wkb/2","title":"Geometry.GeometryCollection.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollection.html#from_wkb!/2","title":"Geometry.GeometryCollection.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollection from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; GeometryCollection . from_wkt ( ...&gt; &quot;GeometryCollection (Point (1.1 2.2))&quot; ) { :ok , % GeometryCollection { geometries : MapSet . new ( [ % Point { coordinate : [ 1.1 , 2.2 ] } ] ) } } iex&gt; GeometryCollection . from_wkt ( ...&gt; &quot;SRID=123;GeometryCollection (Point (1.1 2.2))&quot; ) { :ok , { % GeometryCollection { geometries : MapSet . new ( [ % Point { coordinate : [ 1.1 , 2.2 ] } ] ) } , 123 } } iex&gt; GeometryCollection . from_wkt ( &quot;GeometryCollection EMPTY&quot; ) { :ok , % GeometryCollection { } }","ref":"Geometry.GeometryCollection.html#from_wkt/1","title":"Geometry.GeometryCollection.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollection.html#from_wkt!/1","title":"Geometry.GeometryCollection.from_wkt!/1","type":"function"},{"doc":"Checks if GeometryCollection contains geometry . Examples iex&gt; GeometryCollection . member? ( ...&gt; GeometryCollection . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 21 , 22 ) , ...&gt; Point . new ( 31 , 32 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; Point . new ( 11 , 12 ) ...&gt; ) true iex&gt; GeometryCollection . member? ( ...&gt; GeometryCollection . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 21 , 22 ) , ...&gt; Point . new ( 31 , 32 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; Point . new ( 1 , 2 ) ...&gt; ) false","ref":"Geometry.GeometryCollection.html#member?/2","title":"Geometry.GeometryCollection.member?/2","type":"function"},{"doc":"Creates an empty GeometryCollection . Examples iex&gt; GeometryCollection . new ( ) % GeometryCollection { geometries : MapSet . new ( ) }","ref":"Geometry.GeometryCollection.html#new/0","title":"Geometry.GeometryCollection.new/0","type":"function"},{"doc":"Creates an empty GeometryCollection . Examples iex&gt; GeometryCollection . new ( [ ...&gt; Point . new ( 1 , 2 ) , ...&gt; LineString . new ( [ Point . new ( 1 , 1 ) , Point . new ( 2 , 2 ) ] ) ...&gt; ] ) % GeometryCollection { geometries : MapSet . new ( [ % Point { coordinate : [ 1 , 2 ] } , % LineString { points : [ [ 1 , 1 ] , [ 2 , 2 ] ] } ] ) }","ref":"Geometry.GeometryCollection.html#new/1","title":"Geometry.GeometryCollection.new/1","type":"function"},{"doc":"Returns the number of elements in GeometryCollection . Examples iex&gt; GeometryCollection . size ( ...&gt; GeometryCollection . new ( [ ...&gt; Point . new ( 11 , 12 ) , ...&gt; LineString . new ( [ ...&gt; Point . new ( 21 , 22 ) , ...&gt; Point . new ( 31 , 32 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.GeometryCollection.html#size/1","title":"Geometry.GeometryCollection.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a GeometryCollection . Examples iex&gt; GeometryCollection . to_geo_json ( ...&gt; GeometryCollection . new ( [ Point . new ( 1.1 , 2.2 ) ] ) ) %{ &quot;type&quot; =&gt; &quot;GeometryCollection&quot; , &quot;geometries&quot; =&gt; [ %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1.1 , 2.2 ] } ] }","ref":"Geometry.GeometryCollection.html#to_geo_json/1","title":"Geometry.GeometryCollection.to_geo_json/1","type":"function"},{"doc":"Converts GeometryCollection to a list. Examples iex&gt; GeometryCollection . to_list ( ...&gt; GeometryCollection . new ( [ ...&gt; Point . new ( 11 , 12 ) ...&gt; ] ) ...&gt; ) [ % Point { coordinate : [ 11 , 12 ] } ]","ref":"Geometry.GeometryCollection.html#to_list/1","title":"Geometry.GeometryCollection.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a GeometryCollection . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :ndr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.Point.to_wkb/1 function.","ref":"Geometry.GeometryCollection.html#to_wkb/2","title":"Geometry.GeometryCollection.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a GeometryCollection . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; GeometryCollection . to_wkt ( GeometryCollection . new ( ) ) &quot;GeometryCollection EMPTY&quot; iex&gt; GeometryCollection . to_wkt ( ...&gt; GeometryCollection . new ( [ ...&gt; Point . new ( 1.1 , 1.2 ) , ...&gt; Point . new ( 2.1 , 2.2 ) ...&gt; ] ) ...&gt; ) &quot;GeometryCollection (Point (1.1 1.2), Point (2.1 2.2))&quot; iex&gt; GeometryCollection . to_wkt ( ...&gt; GeometryCollection . new ( [ Point . new ( 1.1 , 2.2 ) ] ) , ...&gt; srid : 4711 ) &quot;SRID=4711;GeometryCollection (Point (1.1 2.2))&quot;","ref":"Geometry.GeometryCollection.html#to_wkt/2","title":"Geometry.GeometryCollection.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.GeometryCollection.html#t:t/0","title":"Geometry.GeometryCollection.t/0","type":"type"},{"doc":"A collection set of 2D geometries with a measurement. GeometryCollectionM implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; GeometryCollectionM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 21 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 32 , 34 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn ...&gt; % PointM { } -&gt; :point ...&gt; % LineStringM { } -&gt; :line_string ...&gt; end ...&gt; ) |&gt; Enum . sort ( ) [ :line_string , :point ] iex&gt; Enum . into ( [ PointM . new ( 1 , 2 , 4 ) ] , GeometryCollectionM . new ( ) ) % GeometryCollectionM { geometries : MapSet . new ( [ % PointM { coordinate : [ 1 , 2 , 4 ] } ] ) }","ref":"Geometry.GeometryCollectionM.html","title":"Geometry.GeometryCollectionM","type":"module"},{"doc":"Returns true if the given GeometryCollectionM is empty. Examples iex&gt; GeometryCollectionM . empty? ( GeometryCollectionM . new ( ) ) true iex&gt; GeometryCollectionM . empty? ( GeometryCollectionM . new ( [ PointM . new ( 1 , 2 , 4 ) ] ) ) false","ref":"Geometry.GeometryCollectionM.html#empty?/1","title":"Geometry.GeometryCollectionM.empty?/1","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;GeometryCollection&quot;, ...&gt; &quot;geometries&quot;: [ ...&gt; {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1.1, 2.2, 4.4]} ...&gt; ] ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; GeometryCollectionM . from_geo_json ( ) { :ok , % GeometryCollectionM { geometries : MapSet . new ( [ % PointM { coordinate : [ 1.1 , 2.2 , 4.4 ] } ] ) } }","ref":"Geometry.GeometryCollectionM.html#from_geo_json/1","title":"Geometry.GeometryCollectionM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionM.html#from_geo_json!/1","title":"Geometry.GeometryCollectionM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointM.from_wkb/2 function.","ref":"Geometry.GeometryCollectionM.html#from_wkb/2","title":"Geometry.GeometryCollectionM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionM.html#from_wkb!/2","title":"Geometry.GeometryCollectionM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; GeometryCollectionM . from_wkt ( ...&gt; &quot;GeometryCollection M (Point M (1.1 2.2 4.4))&quot; ) { :ok , % GeometryCollectionM { geometries : MapSet . new ( [ % PointM { coordinate : [ 1.1 , 2.2 , 4.4 ] } ] ) } } iex&gt; GeometryCollectionM . from_wkt ( ...&gt; &quot;SRID=123;GeometryCollection M (Point M (1.1 2.2 4.4))&quot; ) { :ok , { % GeometryCollectionM { geometries : MapSet . new ( [ % PointM { coordinate : [ 1.1 , 2.2 , 4.4 ] } ] ) } , 123 } } iex&gt; GeometryCollectionM . from_wkt ( &quot;GeometryCollection M EMPTY&quot; ) { :ok , % GeometryCollectionM { } }","ref":"Geometry.GeometryCollectionM.html#from_wkt/1","title":"Geometry.GeometryCollectionM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionM.html#from_wkt!/1","title":"Geometry.GeometryCollectionM.from_wkt!/1","type":"function"},{"doc":"Checks if GeometryCollectionM contains geometry . Examples iex&gt; GeometryCollectionM . member? ( ...&gt; GeometryCollectionM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 21 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 32 , 34 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ) true iex&gt; GeometryCollectionM . member? ( ...&gt; GeometryCollectionM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 21 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 32 , 34 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PointM . new ( 1 , 2 , 4 ) ...&gt; ) false","ref":"Geometry.GeometryCollectionM.html#member?/2","title":"Geometry.GeometryCollectionM.member?/2","type":"function"},{"doc":"Creates an empty GeometryCollectionM . Examples iex&gt; GeometryCollectionM . new ( ) % GeometryCollectionM { geometries : MapSet . new ( ) }","ref":"Geometry.GeometryCollectionM.html#new/0","title":"Geometry.GeometryCollectionM.new/0","type":"function"},{"doc":"Creates an empty GeometryCollectionM . Examples iex&gt; GeometryCollectionM . new ( [ ...&gt; PointM . new ( 1 , 2 , 4 ) , ...&gt; LineStringM . new ( [ PointM . new ( 1 , 1 , 1 ) , PointM . new ( 2 , 2 , 2 ) ] ) ...&gt; ] ) % GeometryCollectionM { geometries : MapSet . new ( [ % PointM { coordinate : [ 1 , 2 , 4 ] } , % LineStringM { points : [ [ 1 , 1 , 1 ] , [ 2 , 2 , 2 ] ] } ] ) }","ref":"Geometry.GeometryCollectionM.html#new/1","title":"Geometry.GeometryCollectionM.new/1","type":"function"},{"doc":"Returns the number of elements in GeometryCollectionM . Examples iex&gt; GeometryCollectionM . size ( ...&gt; GeometryCollectionM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) , ...&gt; LineStringM . new ( [ ...&gt; PointM . new ( 21 , 22 , 24 ) , ...&gt; PointM . new ( 31 , 32 , 34 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.GeometryCollectionM.html#size/1","title":"Geometry.GeometryCollectionM.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a GeometryCollectionM . Examples iex&gt; GeometryCollectionM . to_geo_json ( ...&gt; GeometryCollectionM . new ( [ PointM . new ( 1.1 , 2.2 , 4.4 ) ] ) ) %{ &quot;type&quot; =&gt; &quot;GeometryCollection&quot; , &quot;geometries&quot; =&gt; [ %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1.1 , 2.2 , 4.4 ] } ] }","ref":"Geometry.GeometryCollectionM.html#to_geo_json/1","title":"Geometry.GeometryCollectionM.to_geo_json/1","type":"function"},{"doc":"Converts GeometryCollectionM to a list. Examples iex&gt; GeometryCollectionM . to_list ( ...&gt; GeometryCollectionM . new ( [ ...&gt; PointM . new ( 11 , 12 , 14 ) ...&gt; ] ) ...&gt; ) [ % PointM { coordinate : [ 11 , 12 , 14 ] } ]","ref":"Geometry.GeometryCollectionM.html#to_list/1","title":"Geometry.GeometryCollectionM.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a GeometryCollectionM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :ndr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointM.to_wkb/1 function.","ref":"Geometry.GeometryCollectionM.html#to_wkb/2","title":"Geometry.GeometryCollectionM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a GeometryCollectionM . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; GeometryCollectionM . to_wkt ( GeometryCollectionM . new ( ) ) &quot;GeometryCollection M EMPTY&quot; iex&gt; GeometryCollectionM . to_wkt ( ...&gt; GeometryCollectionM . new ( [ ...&gt; PointM . new ( 1.1 , 1.2 , 1.4 ) , ...&gt; PointM . new ( 2.1 , 2.2 , 2.4 ) ...&gt; ] ) ...&gt; ) &quot;GeometryCollection M (Point M (1.1 1.2 1.4), Point M (2.1 2.2 2.4))&quot; iex&gt; GeometryCollectionM . to_wkt ( ...&gt; GeometryCollectionM . new ( [ PointM . new ( 1.1 , 2.2 , 4.4 ) ] ) , ...&gt; srid : 4711 ) &quot;SRID=4711;GeometryCollection M (Point M (1.1 2.2 4.4))&quot;","ref":"Geometry.GeometryCollectionM.html#to_wkt/2","title":"Geometry.GeometryCollectionM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.GeometryCollectionM.html#t:t/0","title":"Geometry.GeometryCollectionM.t/0","type":"type"},{"doc":"A collection set of 3D geometries. GeometryCollectionZ implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; GeometryCollectionZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 21 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 32 , 33 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn ...&gt; % PointZ { } -&gt; :point ...&gt; % LineStringZ { } -&gt; :line_string ...&gt; end ...&gt; ) |&gt; Enum . sort ( ) [ :line_string , :point ] iex&gt; Enum . into ( [ PointZ . new ( 1 , 2 , 3 ) ] , GeometryCollectionZ . new ( ) ) % GeometryCollectionZ { geometries : MapSet . new ( [ % PointZ { coordinate : [ 1 , 2 , 3 ] } ] ) }","ref":"Geometry.GeometryCollectionZ.html","title":"Geometry.GeometryCollectionZ","type":"module"},{"doc":"Returns true if the given GeometryCollectionZ is empty. Examples iex&gt; GeometryCollectionZ . empty? ( GeometryCollectionZ . new ( ) ) true iex&gt; GeometryCollectionZ . empty? ( GeometryCollectionZ . new ( [ PointZ . new ( 1 , 2 , 3 ) ] ) ) false","ref":"Geometry.GeometryCollectionZ.html#empty?/1","title":"Geometry.GeometryCollectionZ.empty?/1","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionZ from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;GeometryCollection&quot;, ...&gt; &quot;geometries&quot;: [ ...&gt; {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1.1, 2.2, 3.3]} ...&gt; ] ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; GeometryCollectionZ . from_geo_json ( ) { :ok , % GeometryCollectionZ { geometries : MapSet . new ( [ % PointZ { coordinate : [ 1.1 , 2.2 , 3.3 ] } ] ) } }","ref":"Geometry.GeometryCollectionZ.html#from_geo_json/1","title":"Geometry.GeometryCollectionZ.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionZ.html#from_geo_json!/1","title":"Geometry.GeometryCollectionZ.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionZ from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointZ.from_wkb/2 function.","ref":"Geometry.GeometryCollectionZ.html#from_wkb/2","title":"Geometry.GeometryCollectionZ.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionZ.html#from_wkb!/2","title":"Geometry.GeometryCollectionZ.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionZ from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; GeometryCollectionZ . from_wkt ( ...&gt; &quot;GeometryCollection Z (Point Z (1.1 2.2 3.3))&quot; ) { :ok , % GeometryCollectionZ { geometries : MapSet . new ( [ % PointZ { coordinate : [ 1.1 , 2.2 , 3.3 ] } ] ) } } iex&gt; GeometryCollectionZ . from_wkt ( ...&gt; &quot;SRID=123;GeometryCollection Z (Point Z (1.1 2.2 3.3))&quot; ) { :ok , { % GeometryCollectionZ { geometries : MapSet . new ( [ % PointZ { coordinate : [ 1.1 , 2.2 , 3.3 ] } ] ) } , 123 } } iex&gt; GeometryCollectionZ . from_wkt ( &quot;GeometryCollection Z EMPTY&quot; ) { :ok , % GeometryCollectionZ { } }","ref":"Geometry.GeometryCollectionZ.html#from_wkt/1","title":"Geometry.GeometryCollectionZ.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionZ.html#from_wkt!/1","title":"Geometry.GeometryCollectionZ.from_wkt!/1","type":"function"},{"doc":"Checks if GeometryCollectionZ contains geometry . Examples iex&gt; GeometryCollectionZ . member? ( ...&gt; GeometryCollectionZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 21 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 32 , 33 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ) true iex&gt; GeometryCollectionZ . member? ( ...&gt; GeometryCollectionZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 21 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 32 , 33 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PointZ . new ( 1 , 2 , 3 ) ...&gt; ) false","ref":"Geometry.GeometryCollectionZ.html#member?/2","title":"Geometry.GeometryCollectionZ.member?/2","type":"function"},{"doc":"Creates an empty GeometryCollectionZ . Examples iex&gt; GeometryCollectionZ . new ( ) % GeometryCollectionZ { geometries : MapSet . new ( ) }","ref":"Geometry.GeometryCollectionZ.html#new/0","title":"Geometry.GeometryCollectionZ.new/0","type":"function"},{"doc":"Creates an empty GeometryCollectionZ . Examples iex&gt; GeometryCollectionZ . new ( [ ...&gt; PointZ . new ( 1 , 2 , 3 ) , ...&gt; LineStringZ . new ( [ PointZ . new ( 1 , 1 , 1 ) , PointZ . new ( 2 , 2 , 2 ) ] ) ...&gt; ] ) % GeometryCollectionZ { geometries : MapSet . new ( [ % PointZ { coordinate : [ 1 , 2 , 3 ] } , % LineStringZ { points : [ [ 1 , 1 , 1 ] , [ 2 , 2 , 2 ] ] } ] ) }","ref":"Geometry.GeometryCollectionZ.html#new/1","title":"Geometry.GeometryCollectionZ.new/1","type":"function"},{"doc":"Returns the number of elements in GeometryCollectionZ . Examples iex&gt; GeometryCollectionZ . size ( ...&gt; GeometryCollectionZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) , ...&gt; LineStringZ . new ( [ ...&gt; PointZ . new ( 21 , 22 , 23 ) , ...&gt; PointZ . new ( 31 , 32 , 33 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.GeometryCollectionZ.html#size/1","title":"Geometry.GeometryCollectionZ.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a GeometryCollectionZ . Examples iex&gt; GeometryCollectionZ . to_geo_json ( ...&gt; GeometryCollectionZ . new ( [ PointZ . new ( 1.1 , 2.2 , 3.3 ) ] ) ) %{ &quot;type&quot; =&gt; &quot;GeometryCollection&quot; , &quot;geometries&quot; =&gt; [ %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1.1 , 2.2 , 3.3 ] } ] }","ref":"Geometry.GeometryCollectionZ.html#to_geo_json/1","title":"Geometry.GeometryCollectionZ.to_geo_json/1","type":"function"},{"doc":"Converts GeometryCollectionZ to a list. Examples iex&gt; GeometryCollectionZ . to_list ( ...&gt; GeometryCollectionZ . new ( [ ...&gt; PointZ . new ( 11 , 12 , 13 ) ...&gt; ] ) ...&gt; ) [ % PointZ { coordinate : [ 11 , 12 , 13 ] } ]","ref":"Geometry.GeometryCollectionZ.html#to_list/1","title":"Geometry.GeometryCollectionZ.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a GeometryCollectionZ . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :ndr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZ.to_wkb/1 function.","ref":"Geometry.GeometryCollectionZ.html#to_wkb/2","title":"Geometry.GeometryCollectionZ.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a GeometryCollectionZ . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; GeometryCollectionZ . to_wkt ( GeometryCollectionZ . new ( ) ) &quot;GeometryCollection Z EMPTY&quot; iex&gt; GeometryCollectionZ . to_wkt ( ...&gt; GeometryCollectionZ . new ( [ ...&gt; PointZ . new ( 1.1 , 1.2 , 1.3 ) , ...&gt; PointZ . new ( 2.1 , 2.2 , 2.3 ) ...&gt; ] ) ...&gt; ) &quot;GeometryCollection Z (Point Z (1.1 1.2 1.3), Point Z (2.1 2.2 2.3))&quot; iex&gt; GeometryCollectionZ . to_wkt ( ...&gt; GeometryCollectionZ . new ( [ PointZ . new ( 1.1 , 2.2 , 3.3 ) ] ) , ...&gt; srid : 4711 ) &quot;SRID=4711;GeometryCollection Z (Point Z (1.1 2.2 3.3))&quot;","ref":"Geometry.GeometryCollectionZ.html#to_wkt/2","title":"Geometry.GeometryCollectionZ.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.GeometryCollectionZ.html#t:t/0","title":"Geometry.GeometryCollectionZ.t/0","type":"type"},{"doc":"A collection set of 3D geometries with a measurement. GeometryCollectionZM implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . map ( ...&gt; GeometryCollectionZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 32 , 33 , 34 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; fn ...&gt; % PointZM { } -&gt; :point ...&gt; % LineStringZM { } -&gt; :line_string ...&gt; end ...&gt; ) |&gt; Enum . sort ( ) [ :line_string , :point ] iex&gt; Enum . into ( [ PointZM . new ( 1 , 2 , 3 , 4 ) ] , GeometryCollectionZM . new ( ) ) % GeometryCollectionZM { geometries : MapSet . new ( [ % PointZM { coordinate : [ 1 , 2 , 3 , 4 ] } ] ) }","ref":"Geometry.GeometryCollectionZM.html","title":"Geometry.GeometryCollectionZM","type":"module"},{"doc":"Returns true if the given GeometryCollectionZM is empty. Examples iex&gt; GeometryCollectionZM . empty? ( GeometryCollectionZM . new ( ) ) true iex&gt; GeometryCollectionZM . empty? ( GeometryCollectionZM . new ( [ PointZM . new ( 1 , 2 , 3 , 4 ) ] ) ) false","ref":"Geometry.GeometryCollectionZM.html#empty?/1","title":"Geometry.GeometryCollectionZM.empty?/1","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionZM from the given GeoJSON term. Otherwise returns an :error tuple. Examples iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;GeometryCollection&quot;, ...&gt; &quot;geometries&quot;: [ ...&gt; {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1.1, 2.2, 3.3, 4.4]} ...&gt; ] ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; GeometryCollectionZM . from_geo_json ( ) { :ok , % GeometryCollectionZM { geometries : MapSet . new ( [ % PointZM { coordinate : [ 1.1 , 2.2 , 3.3 , 4.4 ] } ] ) } }","ref":"Geometry.GeometryCollectionZM.html#from_geo_json/1","title":"Geometry.GeometryCollectionZM.from_geo_json/1","type":"function"},{"doc":"The same as from_geo_json/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionZM.html#from_geo_json!/1","title":"Geometry.GeometryCollectionZM.from_geo_json!/1","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionZM from the given WKB string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. An example of a simpler geometry can be found in the description for the Geometry.PointZM.from_wkb/2 function.","ref":"Geometry.GeometryCollectionZM.html#from_wkb/2","title":"Geometry.GeometryCollectionZM.from_wkb/2","type":"function"},{"doc":"The same as from_wkb/2 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionZM.html#from_wkb!/2","title":"Geometry.GeometryCollectionZM.from_wkb!/2","type":"function"},{"doc":"Returns an :ok tuple with the GeometryCollectionZM from the given WKT string. Otherwise returns an :error tuple. If the geometry contains a SRID the id is added to the tuple. Examples iex&gt; GeometryCollectionZM . from_wkt ( ...&gt; &quot;GeometryCollection ZM (Point ZM (1.1 2.2 3.3 4.4))&quot; ) { :ok , % GeometryCollectionZM { geometries : MapSet . new ( [ % PointZM { coordinate : [ 1.1 , 2.2 , 3.3 , 4.4 ] } ] ) } } iex&gt; GeometryCollectionZM . from_wkt ( ...&gt; &quot;SRID=123;GeometryCollection ZM (Point ZM (1.1 2.2 3.3 4.4))&quot; ) { :ok , { % GeometryCollectionZM { geometries : MapSet . new ( [ % PointZM { coordinate : [ 1.1 , 2.2 , 3.3 , 4.4 ] } ] ) } , 123 } } iex&gt; GeometryCollectionZM . from_wkt ( &quot;GeometryCollection ZM EMPTY&quot; ) { :ok , % GeometryCollectionZM { } }","ref":"Geometry.GeometryCollectionZM.html#from_wkt/1","title":"Geometry.GeometryCollectionZM.from_wkt/1","type":"function"},{"doc":"The same as from_wkt/1 , but raises a Geometry.Error exception if it fails.","ref":"Geometry.GeometryCollectionZM.html#from_wkt!/1","title":"Geometry.GeometryCollectionZM.from_wkt!/1","type":"function"},{"doc":"Checks if GeometryCollectionZM contains geometry . Examples iex&gt; GeometryCollectionZM . member? ( ...&gt; GeometryCollectionZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 32 , 33 , 34 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ) true iex&gt; GeometryCollectionZM . member? ( ...&gt; GeometryCollectionZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 32 , 33 , 34 ) ...&gt; ] ) ...&gt; ] ) , ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) ...&gt; ) false","ref":"Geometry.GeometryCollectionZM.html#member?/2","title":"Geometry.GeometryCollectionZM.member?/2","type":"function"},{"doc":"Creates an empty GeometryCollectionZM . Examples iex&gt; GeometryCollectionZM . new ( ) % GeometryCollectionZM { geometries : MapSet . new ( ) }","ref":"Geometry.GeometryCollectionZM.html#new/0","title":"Geometry.GeometryCollectionZM.new/0","type":"function"},{"doc":"Creates an empty GeometryCollectionZM . Examples iex&gt; GeometryCollectionZM . new ( [ ...&gt; PointZM . new ( 1 , 2 , 3 , 4 ) , ...&gt; LineStringZM . new ( [ PointZM . new ( 1 , 1 , 1 , 1 ) , PointZM . new ( 2 , 2 , 2 , 2 ) ] ) ...&gt; ] ) % GeometryCollectionZM { geometries : MapSet . new ( [ % PointZM { coordinate : [ 1 , 2 , 3 , 4 ] } , % LineStringZM { points : [ [ 1 , 1 , 1 , 1 ] , [ 2 , 2 , 2 , 2 ] ] } ] ) }","ref":"Geometry.GeometryCollectionZM.html#new/1","title":"Geometry.GeometryCollectionZM.new/1","type":"function"},{"doc":"Returns the number of elements in GeometryCollectionZM . Examples iex&gt; GeometryCollectionZM . size ( ...&gt; GeometryCollectionZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) , ...&gt; LineStringZM . new ( [ ...&gt; PointZM . new ( 21 , 22 , 23 , 24 ) , ...&gt; PointZM . new ( 31 , 32 , 33 , 34 ) ...&gt; ] ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.GeometryCollectionZM.html#size/1","title":"Geometry.GeometryCollectionZM.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a GeometryCollectionZM . Examples iex&gt; GeometryCollectionZM . to_geo_json ( ...&gt; GeometryCollectionZM . new ( [ PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) ] ) ) %{ &quot;type&quot; =&gt; &quot;GeometryCollection&quot; , &quot;geometries&quot; =&gt; [ %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1.1 , 2.2 , 3.3 , 4.4 ] } ] }","ref":"Geometry.GeometryCollectionZM.html#to_geo_json/1","title":"Geometry.GeometryCollectionZM.to_geo_json/1","type":"function"},{"doc":"Converts GeometryCollectionZM to a list. Examples iex&gt; GeometryCollectionZM . to_list ( ...&gt; GeometryCollectionZM . new ( [ ...&gt; PointZM . new ( 11 , 12 , 13 , 14 ) ...&gt; ] ) ...&gt; ) [ % PointZM { coordinate : [ 11 , 12 , 13 , 14 ] } ]","ref":"Geometry.GeometryCollectionZM.html#to_list/1","title":"Geometry.GeometryCollectionZM.to_list/1","type":"function"},{"doc":"Returns the WKB representation for a GeometryCollectionZM . With option :srid an EWKB representation with the SRID is returned. The option endian indicates whether :xdr big endian or :ndr little endian is returned. The default is :ndr . The :mode determines whether a hex-string or binary is returned. The default is :binary . An example of a simpler geometry can be found in the description for the Geometry.PointZM.to_wkb/1 function.","ref":"Geometry.GeometryCollectionZM.html#to_wkb/2","title":"Geometry.GeometryCollectionZM.to_wkb/2","type":"function"},{"doc":"Returns the WKT representation for a GeometryCollectionZM . With option :srid an EWKT representation with the SRID is returned. Examples iex&gt; GeometryCollectionZM . to_wkt ( GeometryCollectionZM . new ( ) ) &quot;GeometryCollection ZM EMPTY&quot; iex&gt; GeometryCollectionZM . to_wkt ( ...&gt; GeometryCollectionZM . new ( [ ...&gt; PointZM . new ( 1.1 , 1.2 , 1.3 , 1.4 ) , ...&gt; PointZM . new ( 2.1 , 2.2 , 2.3 , 2.4 ) ...&gt; ] ) ...&gt; ) &quot;GeometryCollection ZM (Point ZM (1.1 1.2 1.3 1.4), Point ZM (2.1 2.2 2.3 2.4))&quot; iex&gt; GeometryCollectionZM . to_wkt ( ...&gt; GeometryCollectionZM . new ( [ PointZM . new ( 1.1 , 2.2 , 3.3 , 4.4 ) ] ) , ...&gt; srid : 4711 ) &quot;SRID=4711;GeometryCollection ZM (Point ZM (1.1 2.2 3.3 4.4))&quot;","ref":"Geometry.GeometryCollectionZM.html#to_wkt/2","title":"Geometry.GeometryCollectionZM.to_wkt/2","type":"function"},{"doc":"","ref":"Geometry.GeometryCollectionZM.html#t:t/0","title":"Geometry.GeometryCollectionZM.t/0","type":"type"},{"doc":"A combination of a geometry and properties .","ref":"Geometry.Feature.html","title":"Geometry.Feature","type":"module"},{"doc":"Returns true for an empty Feature . Examples iex&gt; Feature . empty? ( Feature . new ( ) ) true iex&gt; Feature . empty? ( Feature . new ( geometry : Point . new ( 1 , 2 ) ) ) false","ref":"Geometry.Feature.html#empty?/1","title":"Geometry.Feature.empty?/1","type":"function"},{"doc":"Returns an :ok tuple with the Feature from the given GeoJSON term. Otherwise returns an :error tuple. The :type option specifies which type is expected. The possible values are :z , :m , and :zm . Examples iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;Feature&quot;, ...&gt; &quot;geometry&quot;: {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1, 2, 3]}, ...&gt; &quot;properties&quot;: {&quot;facility&quot;: &quot;Hotel&quot;} ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; Feature . from_geo_json ( type : :z ) { :ok , % Feature { geometry : % PointZ { coordinate : [ 1 , 2 , 3 ] } , properties : %{ &quot;facility&quot; =&gt; &quot;Hotel&quot; } } } iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;Feature&quot;, ...&gt; &quot;geometry&quot;: {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1, 2]}, ...&gt; &quot;properties&quot;: {&quot;facility&quot;: &quot;Hotel&quot;} ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; Feature . from_geo_json ( ) { :ok , % Feature { geometry : % Point { coordinate : [ 1 , 2 ] } , properties : %{ &quot;facility&quot; =&gt; &quot;Hotel&quot; } } }","ref":"Geometry.Feature.html#from_geo_json/2","title":"Geometry.Feature.from_geo_json/2","type":"function"},{"doc":"The same as from_geo_josn/1 , but raises a Geometry.Error exception if it fails. Examples iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;Feature&quot;, ...&gt; &quot;geometry&quot;: {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1, 2, 3]}, ...&gt; &quot;properties&quot;: {&quot;facility&quot;: &quot;Hotel&quot;} ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; Feature . from_geo_json! ( type : :m ) % Feature { geometry : % PointM { coordinate : [ 1 , 2 , 3 ] } , properties : %{ &quot;facility&quot; =&gt; &quot;Hotel&quot; } }","ref":"Geometry.Feature.html#from_geo_json!/2","title":"Geometry.Feature.from_geo_json!/2","type":"function"},{"doc":"Creates a new empty Feature . Examples iex&gt; Feature . new ( ) % Feature { }","ref":"Geometry.Feature.html#new/0","title":"Geometry.Feature.new/0","type":"function"},{"doc":"Creates a new Feature . Examples iex&gt; Feature . new ( ...&gt; geometry : Point . new ( 1 , 2 ) , ...&gt; properties : %{ facility : :hotel } ...&gt; ) % Feature { geometry : % Point { coordinate : [ 1 , 2 ] } , properties : %{ facility : :hotel } }","ref":"Geometry.Feature.html#new/1","title":"Geometry.Feature.new/1","type":"function"},{"doc":"Returns the GeoJSON term of a Feature . Examples iex&gt; Feature . to_geo_json ( Feature . new ( ...&gt; geometry : Point . new ( 1 , 2 ) , ...&gt; properties : %{ facility : :hotel } ...&gt; ) ) %{ &quot;type&quot; =&gt; &quot;Feature&quot; , &quot;geometry&quot; =&gt; %{ &quot;type&quot; =&gt; &quot;Point&quot; , &quot;coordinates&quot; =&gt; [ 1 , 2 ] } , &quot;properties&quot; =&gt; %{ facility : :hotel } }","ref":"Geometry.Feature.html#to_geo_json/1","title":"Geometry.Feature.to_geo_json/1","type":"function"},{"doc":"","ref":"Geometry.Feature.html#t:t/0","title":"Geometry.Feature.t/0","type":"type"},{"doc":"A collection of Geometry.Featre s. GeometryCollectionZM implements the protocols Enumerable and Collectable . Examples iex&gt; Enum . filter ( ...&gt; FeatureCollection . new ( [ ...&gt; Feature . new ( ...&gt; geometry : Point . new ( 11 , 12 ) , ...&gt; properties : %{ &quot;facility&quot; =&gt; &quot;Hotel&quot; } ...&gt; ) , ...&gt; Feature . new ( ...&gt; geometry : Point . new ( 55 , 55 ) , ...&gt; properties : %{ &quot;facility&quot; =&gt; &quot;Tower&quot; } ...&gt; ) ...&gt; ] ) , ...&gt; fn % Feature { properties : properties } -&gt; ...&gt; Map . get ( properties , &quot;facility&quot; ) == &quot;Hotel&quot; ...&gt; end ...&gt; ) [ % Feature { geometry : % Point { coordinate : [ 11 , 12 ] } , properties : %{ &quot;facility&quot; =&gt; &quot;Hotel&quot; } } ] iex&gt; Enum . into ( ...&gt; [ Feature . new ( geometry : Point . new ( 5 , 1 ) , properties : %{ &quot;area&quot; =&gt; 51 } ) ] , ...&gt; FeatureCollection . new ( [ ...&gt; Feature . new ( geometry : Point . new ( 4 , 2 ) , properties : %{ &quot;area&quot; =&gt; 42 } ) ...&gt; ] ) ...&gt; ) % FeatureCollection { features : MapSet . new ( [ % Feature { geometry : % Point { coordinate : [ 4 , 2 ] } , properties : %{ &quot;area&quot; =&gt; 42 } } , % Feature { geometry : % Point { coordinate : [ 5 , 1 ] } , properties : %{ &quot;area&quot; =&gt; 51 } } ] ) }","ref":"Geometry.FeatureCollection.html","title":"Geometry.FeatureCollection","type":"module"},{"doc":"Returns true for an empty FeatureCollection . Examples iex&gt; FeatureCollection . empty? ( FeatureCollection . new ( ) ) true","ref":"Geometry.FeatureCollection.html#empty?/1","title":"Geometry.FeatureCollection.empty?/1","type":"function"},{"doc":"Returns an :ok tuple with the FeatureCollection from the given GeoJSON term. Otherwise returns an :error tuple. The :type option specifies which type is expected. The possible values are :z , :m , and :zm . Examples iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;FeatureCollection&quot;, ...&gt; &quot;features&quot;: [ ...&gt; { ...&gt; &quot;type&quot;: &quot;Feature&quot;, ...&gt; &quot;geometry&quot;: {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1, 2, 3]}, ...&gt; &quot;properties&quot;: {&quot;facility&quot;: &quot;Hotel&quot;} ...&gt; }, { ...&gt; &quot;type&quot;: &quot;Feature&quot;, ...&gt; &quot;geometry&quot;: {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [4, 3, 2]}, ...&gt; &quot;properties&quot;: {&quot;facility&quot;: &quot;School&quot;} ...&gt; } ...&gt; ] ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; FeatureCollection . from_geo_json ( type : :z ) { :ok , % FeatureCollection { features : MapSet . new ( [ % Feature { geometry : % PointZ { coordinate : [ 1 , 2 , 3 ] } , properties : %{ &quot;facility&quot; =&gt; &quot;Hotel&quot; } } , % Feature { geometry : % PointZ { coordinate : [ 4 , 3 , 2 ] } , properties : %{ &quot;facility&quot; =&gt; &quot;School&quot; } } ] ) } }","ref":"Geometry.FeatureCollection.html#from_geo_json/2","title":"Geometry.FeatureCollection.from_geo_json/2","type":"function"},{"doc":"The same as from_geo_josn/1 , but raises a Geometry.Error exception if it fails. Examples iex&gt; ~s({ ...&gt; &quot;type&quot;: &quot;FeatureCollection&quot;, ...&gt; &quot;features&quot;: [ ...&gt; { ...&gt; &quot;type&quot;: &quot;Feature&quot;, ...&gt; &quot;geometry&quot;: {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [1, 2, 3]}, ...&gt; &quot;properties&quot;: {&quot;facility&quot;: &quot;Hotel&quot;} ...&gt; }, { ...&gt; &quot;type&quot;: &quot;Feature&quot;, ...&gt; &quot;geometry&quot;: {&quot;type&quot;: &quot;Point&quot;, &quot;coordinates&quot;: [4, 3, 2]}, ...&gt; &quot;properties&quot;: {&quot;facility&quot;: &quot;School&quot;} ...&gt; } ...&gt; ] ...&gt; }) iex&gt; |&gt; Jason . decode! ( ) iex&gt; |&gt; FeatureCollection . from_geo_json! ( type : :m ) % FeatureCollection { features : MapSet . new ( [ % Feature { geometry : % PointM { coordinate : [ 1 , 2 , 3 ] } , properties : %{ &quot;facility&quot; =&gt; &quot;Hotel&quot; } } , % Feature { geometry : % PointM { coordinate : [ 4 , 3 , 2 ] } , properties : %{ &quot;facility&quot; =&gt; &quot;School&quot; } } ] ) }","ref":"Geometry.FeatureCollection.html#from_geo_json!/2","title":"Geometry.FeatureCollection.from_geo_json!/2","type":"function"},{"doc":"Checks if FeatureCollection contains geometry . Examples iex&gt; FeatureCollection . member? ( ...&gt; FeatureCollection . new ( [ ...&gt; Feature . new ( geometry : Point . new ( 11 , 12 ) ) , ...&gt; Feature . new ( geometry : ...&gt; LineString . new ( [ ...&gt; Point . new ( 21 , 22 ) , ...&gt; Point . new ( 31 , 32 ) ...&gt; ] ) ...&gt; ) ...&gt; ] ) , ...&gt; Feature . new ( geometry : Point . new ( 11 , 12 ) ) ...&gt; ) true iex&gt; FeatureCollection . member? ( ...&gt; FeatureCollection . new ( [ ...&gt; Feature . new ( geometry : Point . new ( 11 , 12 ) ) , ...&gt; Feature . new ( geometry : ...&gt; LineString . new ( [ ...&gt; Point . new ( 21 , 22 ) , ...&gt; Point . new ( 31 , 32 ) ...&gt; ] ) ...&gt; ) ...&gt; ] ) , ...&gt; Feature . new ( geometry : Point . new ( 1 , 2 ) ) ...&gt; ) false","ref":"Geometry.FeatureCollection.html#member?/2","title":"Geometry.FeatureCollection.member?/2","type":"function"},{"doc":"Creates an empty FeatureCollection . Examples iex&gt; FeatureCollection . new ( ) % FeatureCollection { }","ref":"Geometry.FeatureCollection.html#new/0","title":"Geometry.FeatureCollection.new/0","type":"function"},{"doc":"Creates a FeatureCollection . Examples iex&gt; FeatureCollection . new ( [ ...&gt; Feature . new ( ...&gt; geometry : Point . new ( 1 , 2 ) , ...&gt; properties : %{ facility : :hotel } ...&gt; ) , ...&gt; Feature . new ( ...&gt; geometry : Point . new ( 3 , 4 ) , ...&gt; properties : %{ facility : :school } ...&gt; ) ...&gt; ] ) % FeatureCollection { features : MapSet . new ( [ % Feature { geometry : % Point { coordinate : [ 1 , 2 ] } , properties : %{ facility : :hotel } } , % Feature { geometry : % Point { coordinate : [ 3 , 4 ] } , properties : %{ facility : :school } } ] ) }","ref":"Geometry.FeatureCollection.html#new/1","title":"Geometry.FeatureCollection.new/1","type":"function"},{"doc":"Returns the number of elements in FeatureCollection . Examples iex&gt; FeatureCollection . size ( ...&gt; FeatureCollection . new ( [ ...&gt; Feature . new ( geometry : Point . new ( 11 , 12 ) ) , ...&gt; Feature . new ( geometry : ...&gt; LineString . new ( [ ...&gt; Point . new ( 21 , 22 ) , ...&gt; Point . new ( 31 , 32 ) ...&gt; ] ) ...&gt; ) ...&gt; ] ) ...&gt; ) 2","ref":"Geometry.FeatureCollection.html#size/1","title":"Geometry.FeatureCollection.size/1","type":"function"},{"doc":"Returns the GeoJSON term of a FeatureCollection . Examples iex&gt; FeatureCollection . to_geo_json ( FeatureCollection . new ( [ ...&gt; Feature . new ( ...&gt; geometry : Point . new ( 1 , 2 ) , ...&gt; properties : %{ facility : :hotel } ...&gt; ) ...&gt; ] ) ) %{ &quot;type&quot; =&gt; &quot;FeatureCollection&quot; , &quot;features&quot; =&gt; [ %{ &quot;type&quot; =&gt; &quot;Feature&quot; , &quot;geometry&quot; =&gt; %{ &quot;coordinates&quot; =&gt; [ 1 , 2 ] , &quot;type&quot; =&gt; &quot;Point&quot; } , &quot;properties&quot; =&gt; %{ facility : :hotel } } ] }","ref":"Geometry.FeatureCollection.html#to_geo_json/1","title":"Geometry.FeatureCollection.to_geo_json/1","type":"function"},{"doc":"Converts FeatureCollection to a list. Examples iex&gt; FeatureCollection . to_list ( ...&gt; FeatureCollection . new ( [ ...&gt; Feature . new ( geometry : Point . new ( 11 , 12 ) ) ...&gt; ] ) ...&gt; ) [ % Feature { geometry : % Point { coordinate : [ 11 , 12 ] } , properties : %{ } } ]","ref":"Geometry.FeatureCollection.html#to_list/1","title":"Geometry.FeatureCollection.to_list/1","type":"function"},{"doc":"","ref":"Geometry.FeatureCollection.html#t:t/0","title":"Geometry.FeatureCollection.t/0","type":"type"},{"doc":"Raised when the creation of a geometry fails.","ref":"Geometry.Error.html","title":"Geometry.Error","type":"exception"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Refactor slice implementations. Add recode package.","ref":"changelog.html#0-3-2-2022-12-11","title":"Changelog - 0.3.2 - 2022/12/11","type":"extras"},{"doc":"Use Base.encode16/1 and Base.decode16!/1 Add dep :prove Require Elixir version ~&gt; 1.11","ref":"changelog.html#0-3-1-2022-01-30","title":"Changelog - 0.3.1 - 2022/01/30","type":"extras"},{"doc":"","ref":"changelog.html#0-3-0-2020-11-26","title":"Changelog - 0.3.0 - 2020/11/26","type":"extras"},{"doc":"Change return value for from_wkb and from_wkt .","ref":"changelog.html#breaking-changes","title":"Changelog - Breaking changes","type":"extras"},{"doc":"","ref":"changelog.html#0-2-0-2020-11-02","title":"Changelog - 0.2.0 - 2020/11/02","type":"extras"},{"doc":"Add mode ( :hex / :binary ) to from_wkb/2 and from_wkb!/2.","ref":"changelog.html#breaking-changes","title":"Changelog - Breaking changes","type":"extras"},{"doc":"The very first version.","ref":"changelog.html#0-1-0-2020-10-18","title":"Changelog - 0.1.0 - 2020/10/18","type":"extras"}]